@@ -36,18 +36,19 @@
   #:use-module (gnu packages gettext)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages tcl)
-  #:use-module ((gnu packages base)
-                #:select (tar))
-  #:use-module ((gnu packages compression)
-                #:select (gzip))
-  #:use-module ((gnu packages openssl)
-                #:renamer (symbol-prefix-proc 'o:))
+  #:use-module ((gnu packages compression) #:prefix c:)
+  #:use-module ((gnu packages openssl) #:prefix o:)
   #:use-module (gnu packages bison)
   #:use-module (gnu packages flex)
   #:use-module (gnu packages glib)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages popt)
   #:use-module (gnu packages texinfo)
   #:use-module (gnu packages groff)
+  #:use-module (gnu packages pciutils)
+  #:use-module (gnu packages libusb)
+  #:use-module (gnu packages libftdi)
+  #:use-module (gnu packages image)
   #:use-module (gnu packages xorg))
 
 (define-public dmd
@@ -273,15 +274,15 @@ allow automatic login and starting any app.")
 (define-public net-base
   (package
     (name "net-base")
-    (version "5.2")
+    (version "5.3")
     (source (origin
              (method url-fetch)
              (uri (string-append
                    "mirror://debian/pool/main/n/netbase/netbase_"
-                   version ".tar.gz"))
+                   version ".tar.xz"))
              (sha256
               (base32
-               "01rkvqrg7krkx8b432nz6bpi8w3s4cm5q5r891k23cdrc9nsaayn"))))
+               "12xqjwg3p4rzmmh2iib6sigm9l29y3dgk74mmnw64k84jnbwdxl1"))))
     (build-system trivial-build-system)
     (arguments
      `(#:modules ((guix build utils))
@@ -291,10 +292,10 @@ allow automatic login and starting any app.")
 
                    (let* ((source (assoc-ref %build-inputs "source"))
                           (tar    (assoc-ref %build-inputs "tar"))
-                          (gzip   (assoc-ref %build-inputs "gzip"))
+                          (xz     (assoc-ref %build-inputs "xz"))
                           (output (assoc-ref %outputs "out"))
                           (etc    (string-append output "/etc")))
-                     (setenv "PATH" (string-append gzip "/bin"))
+                     (setenv "PATH" (string-append xz "/bin"))
                      (system* (string-append tar "/bin/tar") "xvf"
                               source)
                      (chdir ,(string-append "netbase-" version))
@@ -305,7 +306,7 @@ allow automatic login and starting any app.")
                                     '("services" "protocols" "rpc")))
                      #t))))
     (native-inputs `(("tar" ,tar)
-                     ("gzip" ,gzip)))
+                     ("xz" ,c:xz)))
     (synopsis "IANA protocol, port, and RPC number assignments")
     (description
      "This package provides the /etc/services, /etc/protocols, and /etc/rpc
@@ -339,7 +340,7 @@ ONC RPC numbers")
      "Netcat is a featured networking utility which reads and writes data
 across network connections, using the TCP/IP protocol.  It is designed to be a
 reliable \"back-end\" tool that can be used directly or easily driven by other
-programs and scripts. At the same time, it is a feature-rich network debugging
+programs and scripts.  At the same time, it is a feature-rich network debugging
 and exploration tool, since it can create almost any kind of connection you
 would need and has several interesting built-in capabilities.")
     (license gpl2+)))
@@ -630,7 +631,7 @@ system administrator.")
                 "002l6h27pnhb77b65frhazbhknsxvrsnkpi43j7i0qw1lrgi7nkf"))))
     (build-system gnu-build-system)
     (arguments
-     '(#:configure-flags '("--with-logpath=/var/log/sudo.log")
+     `(#:configure-flags '("--with-logpath=/var/log/sudo.log")
        #:phases (alist-cons-before
                  'configure 'pre-configure
                  (lambda _
@@ -762,3 +763,187 @@ This package provides the 'wpa_supplicant' daemon and the 'wpa_cli' command.")
      "WakeLan broadcasts a properly formatted UDP packet across the local area
 network, which causes enabled computers to power on.")
     (license gpl2+)))
+
+(define-public dmidecode
+  (package
+    (name "dmidecode")
+    (version "2.12")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "mirror://savannah/dmidecode/dmidecode-"
+                    version ".tar.bz2"))
+              (sha256
+               (base32
+                "122hgaw8mpqdfra159lfl6pyk3837giqx6vq42j64fjnbl2z6gwi"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases (alist-delete 'configure %standard-phases)
+       #:tests? #f                                ; no 'check' target
+       #:make-flags (list (string-append "prefix="
+                                         (assoc-ref %outputs "out")))))
+    (home-page "http://www.nongnu.org/dmidecode/")
+    (synopsis "Read hardware information from the BIOS")
+    (description
+     "Dmidecode reports information about your system's hardware as described
+in your system BIOS according to the SMBIOS/DMI standard.  This typically
+includes system manufacturer, model name, serial number, BIOS version, asset
+tag as well as a lot of other details of varying level of interest and
+reliability depending on the manufacturer.  This will often include usage
+status for the CPU sockets, expansion slots (e.g. AGP, PCI, ISA) and memory
+module slots, and the list of I/O ports (e.g. serial, parallel, USB).")
+    (license gpl2+)))
+
+(define-public acpica
+  (package
+    (name "acpica")
+    (version "20140724")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "https://acpica.org/sites/acpica/files/acpica-unix2-"
+                    version ".tar.gz"))
+              (sha256
+               (base32
+                "01vdgrh7dsxrrvg5yd8sxm63cw8210pnsi5qg9g15ac53gn243ac"))))
+    (build-system gnu-build-system)
+    (native-inputs `(("flex" ,flex)
+                     ("bison" ,bison)))
+    (arguments
+     '(#:make-flags (list (string-append "PREFIX=" %output)
+                          "HOST=_LINUX"
+                          "OPT_CFLAGS=-Wall -fno-strict-aliasing")
+       #:tests? #f  ; no 'check' target.
+       #:phases (alist-delete 'configure %standard-phases)))
+    (home-page "http://acpica.org/")
+    (synopsis "Tools for the development and debug of ACPI tables")
+    (description
+     "The ACPI Component Architecture (ACPICA) project provides an
+OS-independent reference implementation of the Advanced Configuration and
+Power Interface Specification (ACPI).  ACPICA code contains those portions of
+ACPI meant to be directly integrated into the host OS as a kernel-resident
+subsystem, and a small set of tools to assist in developing and debugging ACPI
+tables.  This package contains only the user-space tools needed for ACPI table
+development, not the kernel implementation of ACPI.")
+    (license gpl2)))  ; Dual GPLv2/ACPICA Licence
+
+(define-public stress
+  (package
+    (name "stress")
+    (version "1.0.1")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://debian/pool/main/s/stress/stress_"
+                                  version ".orig.tar.gz"))
+              (sha256
+               (base32
+                "1v9vnzlihqfjsxa93hdbrq72pqqk00dkylmlg8jpxhm7s1w9qfl1"))))
+    (build-system gnu-build-system)
+    (home-page "http://packages.debian.org/wheezy/stress")
+    (synopsis "Impose load on and stress test a computer system")
+    (description
+     "Stress is a tool that imposes a configurable amount of CPU, memory, I/O,
+or disk stress on a POSIX-compliant operating system and reports any errors it
+detects.
+
+Stress is not a benchmark.  It is a tool used by system administrators to
+evaluate how well their systems will scale, by kernel programmers to evaluate
+perceived performance characteristics, and by systems programmers to expose
+the classes of bugs which only or more frequently manifest themselves when the
+system is under heavy load.")
+    (license gpl2+)))
+
+(define-public detox
+  (package
+    (name "detox")
+    (version "1.2.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/detox/detox-"
+                                  version ".tar.bz2"))
+              (sha256
+               (base32
+                "1y6vvjqsg54kl49cry73jbfhr04s7wjs779vrr9zrq6kww7dkymb"))))
+    (build-system gnu-build-system)
+    ;; Both flex and popt are used in this case for their runtime libraries
+    ;; (libfl and libpopt).
+    (inputs
+     `(("flex" ,flex)
+       ("popt" ,popt)))
+    (arguments
+     `(#:configure-flags `(,(string-append "--with-popt="
+                                           (assoc-ref %build-inputs "popt")))
+       #:tests? #f))                    ;no 'check' target
+    (home-page "http://detox.sourceforge.net")
+    (synopsis "Clean up filenames")
+    (description
+     "Detox is a program that renames files to make them easier to work with
+under Unix and related operating systems.  Spaces and various other unsafe
+characters (such as \"$\") get replaced with \"_\".  ISO 8859-1 (Latin-1)
+characters can be replaced as well, as can UTF-8 characters.")
+    (license bsd-3)))
+
+(define-public testdisk
+  (package
+    (name "testdisk")
+    (version "6.14")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "http://www.cgsecurity.org/testdisk-"
+                                  version ".tar.bz2"))
+              (sha256
+               (base32
+                "0v1jap83f5h99zv01v3qmqm160d36n4ysi0gyq7xzb3mqgmw75x5"))))
+    (build-system gnu-build-system)
+    (inputs
+     `(;; ("ntfs" ,ntfs)
+       ("util-linux" ,util-linux)
+       ("openssl" ,o:openssl)
+       ("zlib" ,c:zlib)
+       ("e2fsprogs" ,e2fsprogs)
+       ("libjpeg" ,libjpeg)
+       ("ncurses" ,ncurses)))
+    (home-page "http://www.cgsecurity.org/wiki/TestDisk")
+    (synopsis "Data recovery tool")
+    (description
+     "TestDisk is a program for data recovery, primarily designed to help
+recover lost partitions and/or make non-booting disks bootable again.")
+    (license gpl2+)))
+
+(define-public direvent
+  (package
+    (name "direvent")
+    (version "5.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnu/direvent/direvent-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "1i14131y6m8wvirz6piw4zxz2q1kbpl0lniv5kl55rx4k372dg8z"))
+              (modules '((guix build utils)))
+              (snippet '(substitute* "tests/testsuite"
+                          (("#![[:blank:]]?/bin/sh")
+                           "#!$SHELL")))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases (alist-cons-before
+                 'build 'patch-/bin/sh
+                 (lambda* (#:key inputs #:allow-other-keys)
+                   ;; Use the right shell when executing the watcher.
+                   (let ((bash (assoc-ref inputs "bash")))
+                     (substitute* "src/direvent.c"
+                       (("\"/bin/sh\"")
+                        (string-append "\"" bash "/bin/sh\"")))))
+                 %standard-phases)))
+    (home-page "http://www.gnu.org/software/direvent/")
+    (synopsis "Daemon to monitor directories for events such as file removal")
+    (description
+     "A daemon that monitors directories for events, such as creating,
+deleting or modifying files.  It can monitor different sets of directories for
+different events.  When an event is detected, direvent calls a specified
+external program with information about the event, such as the location
+within the file system where it occurred.  Thus, \"direvent\" provides an
+easy way to react immediately if given files undergo changes, for example, to
+track changes in important system configuration files.")
+    (license gpl3+)))
