@@ -48,14 +48,13 @@
    (inputs `(("gmp" ,gmp)
              ("mpfr" ,mpfr)
              ("mpc"  ,mpc)))
-   (synopsis "mpfrcx, a library for the arithmetic of univariate polynomials
-over arbitrary precision real or complex numbers")
+   (synopsis "Arithmetic of polynomials over arbitrary precision numbers")
    (description
-    "mpfrcx is a library for the arithmetic of univariate polynomials over
+    "Mpfrcx is a library for the arithmetic of univariate polynomials over
 arbitrary precision real (mpfr) or complex (mpc) numbers, without control
-on the rounding. For the time being, only the few functions needed to
+on the rounding.  For the time being, only the few functions needed to
 implement the floating point approach to complex multiplication are
-implemented. On the other hand, these comprise asymptotically fast
+implemented.  On the other hand, these comprise asymptotically fast
 multiplication routines such as Toom–Cook and the FFT. ")
    (license lgpl2.1+)
    (home-page "http://mpfrcx.multiprecision.org/")))
@@ -74,9 +73,9 @@ multiplication routines such as Toom–Cook and the FFT. ")
    (build-system gnu-build-system)
    (inputs `(("gmp" ,gmp)
              ("mpfr" ,mpfr)))
-   (synopsis "fplll, a library for LLL-reduction of euclidean lattices")
+   (synopsis "Library for LLL-reduction of euclidean lattices")
    (description
-    "fplll LLL-reduces euclidean lattices. Since version 3, it can also
+    "fplll LLL-reduces euclidean lattices.  Since version 3, it can also
 solve the shortest vector problem.")
    (license lgpl2.1+)
    (home-page "http://perso.ens-lyon.fr/damien.stehle/fplll/")))
@@ -154,6 +153,100 @@ GP2C, the GP to C compiler, translates GP scripts to PARI programs.")
    (license gpl2)
    (home-page "http://pari.math.u-bordeaux.fr/")))
 
+(define-public flint
+  (package
+   (name "flint")
+   (version "2.4.4")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append
+                  "http://flintlib.org/flint-"
+                  version ".tar.gz"))
+            (sha256 (base32
+                     "1isv1sfv8sg3qvf0d99apdfi3jnql95xfzszcawdf1pgjj9rwyf4"))))
+   (build-system gnu-build-system)
+   (inputs
+    `(("gmp" ,gmp)
+      ("mpfr" ,mpfr)))
+   (arguments
+    `(#:phases
+        (alist-replace
+         'configure
+         (lambda* (#:key inputs outputs #:allow-other-keys)
+           (let ((out (assoc-ref outputs "out"))
+                 (gmp (assoc-ref inputs "gmp"))
+                 (mpfr (assoc-ref inputs "mpfr")))
+             ;; Drop test failing with gmp-6 due to changed invertibility
+             ;; of 0 in Z/1 Z, which according to the flint authors has no
+             ;; impact on flint.
+             ;; FIXME: Drop with later version.
+             (delete-file "fmpz/test/t-invmod.c")
+             ;; do not pass "--enable-fast-install", which makes the
+             ;; homebrew configure process fail
+             (zero? (system*
+                     "./configure"
+                     (string-append "--prefix=" out)
+                     (string-append "--with-gmp=" gmp)
+                     (string-append "--with-mpfr=" mpfr)))))
+         %standard-phases)))
+   (synopsis "Fast library for number theory")
+   (description
+    "FLINT is a C library for number theory.  It supports arithmetic
+with numbers, polynomials, power series and matrices over many base
+rings, including multiprecision integers and rationals, integers
+modulo n, p-adic numbers, finite fields (prime and non-prime order)
+and real and complex numbers (via the Arb extension library).
+
+Operations that can be performed include conversions, arithmetic,
+GCDs, factoring, solving linear systems, and evaluating special
+functions.  In addition, FLINT provides various low-level routines for
+fast arithmetic.")
+   (license gpl2+)
+   (home-page "http://flintlib.org/")))
+
+(define-public arb
+  (package
+   (name "arb")
+   (version "2.2.0")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append
+                  "https://github.com/fredrik-johansson/arb/archive/"
+                  version ".tar.gz"))
+            (sha256 (base32
+                     "0a8cgzznkmr59ngj4di9a37b5h4i00gbnixnxlwd34bcbflvjzyr"))))
+   (build-system gnu-build-system)
+   (inputs
+    `(("flint" ,flint)
+      ("gmp" ,gmp)
+      ("mpfr" ,mpfr)))
+   (arguments
+    `(#:phases
+        (alist-replace
+         'configure
+         (lambda* (#:key inputs outputs #:allow-other-keys)
+           (let ((out (assoc-ref outputs "out"))
+                 (flint (assoc-ref inputs "flint"))
+                 (gmp (assoc-ref inputs "gmp"))
+                 (mpfr (assoc-ref inputs "mpfr")))
+             ;; do not pass "--enable-fast-install", which makes the
+             ;; homebrew configure process fail
+             (zero? (system*
+                     "./configure"
+                     (string-append "--prefix=" out)
+                     (string-append "--with-flint=" flint)
+                     (string-append "--with-gmp=" gmp)
+                     (string-append "--with-mpfr=" mpfr)))))
+         %standard-phases)))
+   (synopsis "Arbitrary precision floating-point ball arithmetic")
+   (description
+    "Arb is a C library for arbitrary-precision floating-point ball
+arithmetic.  It supports efficient high-precision computation with
+polynomials, power series, matrices and special functions over the
+real and complex numbers, with automatic, rigorous error control.")
+   (license gpl2+)
+   (home-page "http://fredrikj.net/arb/")))
+
 (define-public bc
   (package
     (name "bc")
