@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
@@ -19,8 +19,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages compression)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -58,12 +57,12 @@
                                (string-append "--prefix=" out)))))
                  %standard-phases)))
     (home-page "http://zlib.net/")
-    (synopsis "The zlib compression library")
+    (synopsis "Compression library")
     (description
      "zlib is designed to be a free, general-purpose, legally unencumbered --
 that is, not covered by any patents -- lossless data-compression library for
 use on virtually any computer hardware and operating system.  The zlib data
-format is itself portable across platforms. Unlike the LZW compression method
+format is itself portable across platforms.  Unlike the LZW compression method
 used in Unix compress(1) and in the GIF image format, the compression method
 currently used in zlib essentially never expands the data. (LZW can double or
 triple the file size in extreme cases.)  zlib's memory footprint is also
@@ -174,7 +173,7 @@ file; as a result, it is often used in conjunction with \"tar\", resulting in
          ,@(if (%current-target-system)
                '(#:tests? #f)
                '())))
-      (synopsis "high-quality data compression program")
+      (synopsis "High-quality data compression program")
       (description
        "bzip2 is a freely available, patent free (see below), high-quality data
 compressor.  It typically compresses files to within 10% to 15% of the best
@@ -197,8 +196,7 @@ decompression.")
              (base32
               "1dl35ca8fdss9z2d6y234gxh24ixq904xksizrjmjr5dimwhax6n"))))
    (build-system gnu-build-system)
-   (synopsis
-    "XZ, general-purpose data compression software, successor of LZMA")
+   (synopsis "General-purpose data compression")
    (description
     "XZ Utils is free general-purpose data compression software with high
 compression ratio.  XZ Utils were written for POSIX-like systems, but also
@@ -228,7 +226,7 @@ than gzip and 15 % smaller output than bzip2.")
     (arguments '(#:configure-flags '("--enable-shared")))
     (home-page "http://www.oberhumer.com/opensource/lzo")
     (synopsis
-     "A data compresion library suitable for real-time data de-/compression")
+     "Data compresion library suitable for real-time data de-/compression")
     (description
      "LZO is a data compression library which is suitable for data
 de-/compression in real-time.  This means it favours speed over
@@ -264,14 +262,14 @@ some compression ratio).")
 (define-public lzip
   (package
     (name "lzip")
-    (version "1.15")
+    (version "1.16")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://savannah/lzip/lzip-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "1dh5vmj5apizfawnsm50y7z064yx7cz3313przph16gwd3dgrlvw"))))
+               "0l9724rw1l3hg2ldr3n7ihqich4m9nc6y7l302bvdj4jmxdw530j"))))
     (build-system gnu-build-system)
     (home-page "http://www.nongnu.org/lzip/lzip.html")
     (synopsis "Lossless data compressor based on the LZMA algorithm")
