@@ -80,8 +80,8 @@ addr2line, and more.")
                                          (string-append "--prefix=" out)))))
                            %standard-phases)))
     (home-page "http://www.mr511.de/software/english.html")
-    (synopsis "An ELF object file access library")
-    (description "libelf is a C library to access ELF object files.")
+    (synopsis "ELF object file access library")
+    (description "Libelf is a C library to access ELF object files.")
     (license lgpl2.0+)))
 
 (define-public patchelf
