@@ -27,22 +27,36 @@
 (define-public file
   (package
    (name "file")
-   (version "5.18")
+   (version "5.19")
    (source (origin
             (method url-fetch)
             (uri (string-append "ftp://ftp.astron.com/pub/file/file-"
                    version ".tar.gz"))
             (sha256 (base32
-                     "01xz106biz6x4h5ilymg5v3367djvgnfp4lm87132cjqdmqgn6b5"))))
+                     "0z1sgrcfy6d285kj5izy1yypf371bjl3247plh9ppk0svaxv714l"))
+            (patches (list (search-patch "file-CVE-2014-3587.patch")))))
    (build-system gnu-build-system)
-   (native-inputs
-    ;; This package depends upon a native install of itself.
-     (if (%current-target-system) `(("file" ,file)) '() ))
-   (synopsis "file, a file type guesser")
+
+   ;; When cross-compiling, this package depends upon a native install of
+   ;; itself.
+   (self-native-input? #t)
+
+   (synopsis "File type guesser")
    (description
     "The file command is a file type guesser, a command-line tool that tells
-you in words what kind of data a file contains. It does not rely on filename
-extentions to tell you the type of a file, but looks at the actual contents
+you in words what kind of data a file contains.  It does not rely on filename
+extensions to tell you the type of a file, but looks at the actual contents
 of the file.")
    (license bsd-2)
    (home-page "http://www.darwinsys.com/file/")))
+
+(define-public file-5.20                          ;fix for CVE-2014-3710
+  (package (inherit file)
+    (version "5.20")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "ftp://ftp.astron.com/pub/file/file-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "0iyjs9z8kp43gz7gva4j67h4p0n53f7q8x3ibai9s01sp3xnphsv"))))))
