@@ -268,23 +268,27 @@ Go.  It also includes runtime support libraries for these languages.")
                                  version "/gcc-" version ".tar.bz2"))
              (sha256
               (base32
-               "07hg10zs7gnqz58my10ch0zygizqh0z0bz6pv4pgxx45n48lz3ka"))))))
+               "07hg10zs7gnqz58my10ch0zygizqh0z0bz6pv4pgxx45n48lz3ka"))
+             (patches (list (search-patch "gcc-fix-pr61801.patch")))))))
 
 (define-public gcc-4.9
   (package (inherit gcc-4.7)
-    (version "4.9.1")
+    (version "4.9.2")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/gcc/gcc-"
                                  version "/gcc-" version ".tar.bz2"))
              (sha256
               (base32
-               "0zki3ngi0gsidnmsp88mjl2868cc7cm5wm1vwqw6znja28d7hd6k"))))))
+               "1pbjp4blk2ycaa6r3jmw4ky5f1s9ji3klbqgv8zs2sl5jn1cj810"))))))
 
-(define (custom-gcc gcc name languages)
+(define* (custom-gcc gcc name languages #:key (separate-lib-output? #t))
   "Return a custom version of GCC that supports LANGUAGES."
   (package (inherit gcc)
     (name name)
+    (outputs (if separate-lib-output?
+                 (package-outputs gcc)
+                 (delete "lib" (package-outputs gcc))))
     (arguments
      (substitute-keyword-arguments `(#:modules ((guix build gnu-build-system)
                                                 (guix build utils)
@@ -302,7 +306,11 @@ Go.  It also includes runtime support libraries for these languages.")
   (custom-gcc gcc-4.8 "gfortran" '("fortran")))
 
 (define-public gccgo-4.8
-  (custom-gcc gcc-4.8 "gccgo" '("go")))
+  (custom-gcc gcc-4.8 "gccgo" '("go")
+              ;; Suppress the separate "lib" output, because otherwise the
+              ;; "lib" and "out" outputs would refer to each other, creating
+              ;; a cyclic dependency.  <http://debbugs.gnu.org/18101>
+              #:separate-lib-output? #f))
 
 (define-public gcc-objc-4.8
   (custom-gcc gcc-4.8 "gcc-objc" '("objc")))
@@ -329,15 +337,15 @@ Go.  It also includes runtime support libraries for these languages.")
     (inputs `(("gmp" ,gmp)))
     (home-page "http://isl.gforge.inria.fr/")
     (synopsis
-     "A library for manipulating sets and relations of integer points bounded
-by linear constraints")
+     "Manipulating sets and relations of integer points \
+bounded by linear constraints")
     (description
      "isl is a library for manipulating sets and relations of integer points
-bounded by linear constraints. Supported operations on sets include
+bounded by linear constraints.  Supported operations on sets include
 intersection, union, set difference, emptiness check, convex hull, (integer)
 affine hull, integer projection, computing the lexicographic minimum using
 parametric integer programming, coalescing and parametric vertex
-enumeration. It also includes an ILP solver based on generalized basis
+enumeration.  It also includes an ILP solver based on generalized basis
 reduction, transitive closures on maps (which may encode infinite graphs),
 dependence analysis and bounds on piecewise step-polynomials.")
     (license lgpl2.1+)))
@@ -364,7 +372,7 @@ dependence analysis and bounds on piecewise step-polynomials.")
               ("isl" ,isl)))
     (arguments '(#:configure-flags '("--with-isl=system")))
     (home-page "http://www.cloog.org/")
-    (synopsis "A library to generate code for scanning Z-polyhedra")
+    (synopsis "Library to generate code for scanning Z-polyhedra")
     (description
      "CLooG is a free software library to generate code for scanning
 Z-polyhedra.  That is, it finds a code (e.g., in C, FORTRAN...) that
