@@ -19,8 +19,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages glib)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -55,7 +54,7 @@
 (define dbus
   (package
     (name "dbus")
-    (version "1.6.4")
+    (version "1.8.8")
     (source (origin
              (method url-fetch)
              (uri
@@ -63,7 +62,7 @@
                              version ".tar.gz"))
              (sha256
               (base32
-               "1wacqyfkcpayg7f8rvx9awqg275n5pksxq5q7y21lxjx85x6pfjz"))
+               "1zfi5grrlryppgrl23im82cqw6l9fk1wlc2ayvzx0yd994v2dayz"))
              (patches (list (search-patch "dbus-localstatedir.patch")))))
     (build-system gnu-build-system)
     (arguments
@@ -74,10 +73,21 @@
                                ;; config.
                                ;; "--sysconfdir=/etc"
 
-                               "--with-session-socket-dir=/tmp")))
+                               "--with-session-socket-dir=/tmp")
+       #:phases (alist-cons-after
+                 'install 'post-install
+                 (lambda* (#:key outputs #:allow-other-keys)
+                   ;; 'dbus-launch' bails out if the 'session.d' directory
+                   ;; below is missing, so create it along with its companion.
+                   (let ((out (assoc-ref outputs "out")))
+                     (mkdir (string-append out "/etc/dbus-1/session.d"))
+                     (mkdir (string-append out "/etc/dbus-1/system.d"))
+                     #t))
+                 %standard-phases)))
+    (native-inputs
+     `(("pkg-config" ,pkg-config)))
     (inputs
      `(("expat" ,expat)
-       ("pkg-config" ,pkg-config)
 
        ;; Add a dependency on libx11 so that 'dbus-launch' has support for
        ;; '--autolaunch'.
@@ -87,7 +97,7 @@
     (synopsis "Message bus for inter-process communication (IPC)")
     (description
      "D-Bus is a message bus system, a simple way for applications to
-talk to one another. In addition to interprocess communication, D-Bus
+talk to one another.  In addition to interprocess communication, D-Bus
 helps coordinate process lifecycle; it makes it simple and reliable to
 code a \"single instance\" application or daemon, and to launch
 applications and daemons on demand when their services are needed.
@@ -95,10 +105,10 @@ applications and daemons on demand when their services are needed.
 D-Bus supplies both a system daemon (for events such as \"new hardware
 device added\" or \"printer queue changed\") and a
 per-user-login-session daemon (for general IPC needs among user
-applications). Also, the message bus is built on top of a general
+applications).  Also, the message bus is built on top of a general
 one-to-one message passing framework, which can be used by any two apps
 to communicate directly (without going through the message bus
-daemon). Currently the communicating applications are on one computer,
+daemon).  Currently the communicating applications are on one computer,
 or through unencrypted TCP/IP suitable for use behind a firewall with
 shared NFS home directories.")
     (license license:gpl2+)))                     ; or Academic Free License 2.1
@@ -253,7 +263,7 @@ bindings to call into the C library.")
     (home-page "https://launchpad.net/intltool/+download")
     (synopsis "Tools to centralise translations of different file formats")
     (description
-     "intltool is a set of tools to centralise translations of many different
+     "Intltool is a set of tools to centralise translations of many different
 file formats using GNU gettext-compatible PO files.
 
 The intltool collection can be used to do these things:
@@ -265,7 +275,7 @@ The intltool collection can be used to do these things:
     source files (.c, .h) in po/$(PACKAGE).pot.
 
     Merge back the translations from .po files into .xml, .desktop and
-    oaf files. This merge step will happen at build resp. installation time.")
+    oaf files.  This merge step will happen at build resp. installation time.")
     (license license:gpl2+)))
 
 (define itstool
@@ -344,12 +354,12 @@ by GDBus included in Glib.")
               (base32
                "14q3sq6d43f6wfcmwhw4v1aal4ba0h5x9v6wkxy2dnqznd95il37"))))
     (build-system gnu-build-system)
-    (inputs `(("pkg-config" ,pkg-config)))
-    (native-inputs `(("m4" ,m4)))
+    (native-inputs `(("pkg-config" ,pkg-config)
+                     ("m4" ,m4)))
     (home-page "http://libsigc.sourceforge.net/")
     (synopsis "Type-safe callback system for standard C++")
     (description
-     "libsigc++ implements a type-safe callback system for standard C++.  It
+     "Libsigc++ implements a type-safe callback system for standard C++.  It
 allows you to define signals and to connect those signals to any callback
 function, either global or a member function, regardless of whether it is
 static or virtual.
@@ -387,14 +397,14 @@ has an ease of use unmatched by other C++ callback libraries.")
                      (("Gio::init.*$")
                       "return 77;\n")))
                  %standard-phases)))
-    (inputs `(("pkg-config" ,pkg-config)
-              ("glib" ,glib "bin")))
+    (native-inputs `(("pkg-config" ,pkg-config)
+                     ("glib" ,glib "bin")))
     (propagated-inputs
      `(("libsigc++" ,libsigc++)
        ("glib" ,glib)))
     (home-page "http://gtkmm.org/")
     (synopsis "C++ interface to the GLib library")
     (description
-     "glibmm provides a C++ programming interface to the part of GLib that are
+     "Glibmm provides a C++ programming interface to the part of GLib that are
 useful for C++.")
     (license license:lgpl2.1+)))
