@@ -1,6 +1,8 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014 Ian Denhardt <ian@zenhack.net>
+;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -18,14 +20,15 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages gnome)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
+  #:use-module (guix utils)
   #:use-module (guix build-system gnu)
+  #:use-module (guix build-system glib-or-gtk)
   #:use-module (gnu packages)
   #:use-module (gnu packages bison)
-  #:use-module (gnu packages flex)  
+  #:use-module (gnu packages flex)
   #:use-module (gnu packages docbook)
   #:use-module (gnu packages glib)
   #:use-module (gnu packages gnupg)
@@ -43,8 +46,7 @@
   #:use-module (gnu packages xml)
   #:use-module (gnu packages gl)
   #:use-module (gnu packages compression)
-  #:use-module (gnu packages xorg)
-  #:use-module (srfi srfi-1))
+  #:use-module (gnu packages xorg))
 
 (define-public brasero
   (package
@@ -90,7 +92,8 @@ features to enable users to create their discs easily and quickly.")
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "mirror://gnome/sources/" name "/3.10/"
+      (uri (string-append "mirror://gnome/sources/" name "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -113,12 +116,12 @@ features to enable users to create their discs easily and quickly.")
        ("xkeyboard-config" ,xkeyboard-config)))
     (home-page "https://www.gnome.org/")
     (synopsis
-     "libgnome-desktop, gnome-about, and desktop-wide documents")
+     "Libgnome-desktop, gnome-about, and desktop-wide documents")
     (description
      "The libgnome-desktop library provides API shared by several applications
-on the desktop, but that cannot live in the platform for various reasons. There
-is no API or ABI guarantee, although we are doing our best to provide
-stability. Documentation for the API is available with gtk-doc.
+on the desktop, but that cannot live in the platform for various reasons.
+There is no API or ABI guarantee, although we are doing our best to provide
+stability.  Documentation for the API is available with gtk-doc.
 
 The gnome-about program helps find which version of GNOME is installed.")
     ; Some bits under the LGPL.
@@ -131,7 +134,8 @@ The gnome-about program helps find which version of GNOME is installed.")
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "mirror://gnome/sources/" name "/0.20/"
+      (uri (string-append "mirror://gnome/sources/" name "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -170,10 +174,9 @@ and keep up to date translations of documentation.")
     (version "3.6.0")
     (source (origin
              (method url-fetch)
-             (uri (string-append
-                   "mirror://gnome/sources/libgnome-keyring/3.6/libgnome-keyring-"
-                   version
-                   ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "0c4qrjpmv1hqga3xv6wsq2z10x2n78qgw7q3k3s01y1pggxkgjkd"))))
@@ -202,12 +205,13 @@ and keep up to date translations of documentation.")
     (version "3.6.1")
     (source (origin
              (method url-fetch)
-             (uri (string-append "mirror://gnome/sources/evince/3.6/evince-"
-                                 version ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version) "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "1da1pij030dh8mb0pr0jnyszgsbjnh8lc17rj5ii52j3kmbv51qv"))))
-    (build-system gnu-build-system)
+    (build-system glib-or-gtk-build-system)
     (arguments
      `(#:configure-flags '("--disable-nautilus")
 
@@ -270,7 +274,7 @@ on the GNOME Desktop with a single simple application.")
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnome/sources/" name "/"
-                          (string-copy version 0 (string-rindex version #\.)) "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -323,7 +327,7 @@ GNOME and KDE desktops to the icon names proposed in the specification.")
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnome/sources/" name "/"
-                          (string-copy version 0 (string-rindex version #\.)) "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -348,8 +352,8 @@ GNOME and KDE desktops to the icon names proposed in the specification.")
     (version "1.2")
     (source (origin
              (method url-fetch)
-             (uri (string-append "http://freedesktop.org/~hadess/shared-mime-info-"
-                                 version ".tar.xz"))
+             (uri (string-append "http://freedesktop.org/~hadess/"
+                                 "shared-mime-info-" version ".tar.xz"))
              (sha256
               (base32
                "0y5vi0vr6rbhvfzcfg57cfskn362bpvcpca9cy598nmr87i6lld5"))))
@@ -380,8 +384,8 @@ database is translated at Transifex.")
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "http://icon-theme.freedesktop.org/releases/hicolor-icon-theme-"
-                          version ".tar.gz"))
+      (uri (string-append "http://icon-theme.freedesktop.org/releases/"
+                          "hicolor-icon-theme-" version ".tar.gz"))
       (sha256
        (base32
         "0wzc7g4ldb2l8zc0x2785ck808c03i857jji942ikakyc68adp4y"))))
@@ -403,7 +407,7 @@ database is translated at Transifex.")
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnome/sources/" name "/"
-                          (string-copy version 0 (string-rindex version #\.)) "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -422,7 +426,7 @@ database is translated at Transifex.")
      "GNOME desktop notification library")
     (description
      "Libnotify is a library that sends desktop notifications to a
-notification daemon, as defined in the Desktop Notifications spec. These
+notification daemon, as defined in the Desktop Notifications spec.  These
 notifications can be used to inform the user about an event or display
 some form of information without getting in the user's way.")
     (license license:lgpl2.1+)))
@@ -435,7 +439,7 @@ some form of information without getting in the user's way.")
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnome/sources/" name "/"
-                          (substring version 0 (string-rindex version #\.)) "/"
+                          (version-major+minor version)  "/"
                           name "-" version ".tar.xz"))
       (sha256
        (base32
@@ -449,12 +453,13 @@ some form of information without getting in the user's way.")
        ("pango" ,pango)))
     (native-inputs
      `(("pkg-config" ,pkg-config)
+       ("glib:bin" ,glib "bin")
        ("gobject-introspection" ,gobject-introspection)
        ("intltool" ,intltool)))
     (home-page "https://wiki.gnome.org/Libpeas")
     (synopsis "GObject plugin system")
     (description
-     "libpeas is a gobject-based plugins engine, and is targetted at giving
+     "Libpeas is a gobject-based plugins engine, and is targetted at giving
 every application the chance to assume its own extensibility.  It also has a
 set of features including, but not limited to: multiple extension points; on
 demand (lazy) programming language support for C, Python and JS; simplicity of
@@ -483,8 +488,8 @@ the API")
                      ("glib" ,glib "bin")))
     (propagated-inputs `(("pangox-compat" ,pangox-compat)))
     (home-page "https://projects.gnome.org/gtkglext")
-    (synopsis "OpenGL extension to GTK+.")
-    (description "GtkGLExt is an OpenGL extension to GTK+. It provides
+    (synopsis "OpenGL extension to GTK+")
+    (description "GtkGLExt is an OpenGL extension to GTK+.  It provides
 additional GDK objects which support OpenGL rendering in GTK+ and GtkWidget
 API add-ons to make GTK+ widgets OpenGL-capable.")
     (license license:lgpl2.1+)))
@@ -493,12 +498,11 @@ API add-ons to make GTK+ widgets OpenGL-capable.")
   (package
     (name "glade")
     (version "3.8.4")
-    (source
-     (origin
-      (method url-fetch)
-      (uri (string-append "mirror://gnome/sources/" name "/"
-                          (substring version 0 (string-rindex version #\.)) "/"
-                          name "3-" version ".tar.xz"))
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "3-" version ".tar.xz"))
               (sha256
                (base32 "021xgq2l18w3rvwms9aq2idm0fk66vwb4f777gs0qh3ap5shgbn7"))))
     (build-system gnu-build-system)
@@ -522,10 +526,9 @@ the GNOME desktop environment.")
     (version "0.6.8")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/libcroco/0.6/libcroco-"
-                    version
-                    ".tar.xz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.xz"))
               (sha256
                (base32
                 "0w453f3nnkbkrly7spx5lx5pf6mwynzmd5qhszprq8amij2invpa"))))
@@ -553,8 +556,9 @@ XML/CSS rendering engine.")
     (version "1.14.30")
     (source (origin
               (method url-fetch)
-              (uri (string-append "mirror://gnome/sources/libgsf/1.14/libgsf-"
-                                  version ".tar.xz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.xz"))
               (sha256
                (base32
                 "0w2v1a9sxsymd1mcy4mwsz4r6za9iwq69rj86nb939p41d4c6j6b"))))
@@ -585,9 +589,9 @@ dealing with different structured file formats.")
     (version "2.40.2")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/librsvg/2.40/librsvg-"
-                    version ".tar.xz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.xz"))
               (sha256
                (base32
                 "071959yjb2i1bja7ciy4bmpnd6fn2is9jjqsvvvnsqwl69j9n128"))))
@@ -607,7 +611,21 @@ dealing with different structured file formats.")
             ;; Likewise, create a separate 'loaders.cache' file.
             (("gdk_pixbuf_cache_file = .*$")
              "gdk_pixbuf_cache_file = $(gdk_pixbuf_moduledir).cache\n")))
-        %standard-phases)))
+        (alist-cons-after
+         'install 'generate-full-cache
+         (lambda* (#:key inputs outputs #:allow-other-keys)
+           (let ((loaders-directory 
+                  (string-append (assoc-ref outputs "out")
+                                 "/lib/gdk-pixbuf-2.0/2.0.10/loaders")))
+             (zero?
+              (system 
+               (string-append 
+                "gdk-pixbuf-query-loaders " 
+                loaders-directory "/libpixbufloader-svg.so "
+                (string-join (find-files (assoc-ref inputs "gdk-pixbuf") 
+                                         "libpixbufloader-.*\\.so") " ")
+                "> " loaders-directory ".cache")))))
+         %standard-phases))))
     (native-inputs
      `(("pkg-config" ,pkg-config)
        ("glib" ,glib "bin")                               ; glib-mkenums, etc.
@@ -626,7 +644,7 @@ dealing with different structured file formats.")
     (home-page "https://wiki.gnome.org/LibRsvg")
     (synopsis "Render SVG files using Cairo")
     (description
-     "librsvg is a C library to render SVG files using the Cairo 2D graphics
+     "Librsvg is a C library to render SVG files using the Cairo 2D graphics
 library.")
     (license license:lgpl2.0+)))
 
@@ -637,10 +655,9 @@ library.")
     (source (origin
               (method url-fetch)
               (uri (let ((upstream-name "libIDL"))
-		     (string-append
-		      "mirror://gnome/sources/" upstream-name "/" (string-take version 3) "/" upstream-name "-"
-		      version
-		      ".tar.bz2")))
+		     (string-append "mirror://gnome/sources/" upstream-name "/"
+                                    (version-major+minor version) "/"
+                                    upstream-name "-" version ".tar.bz2")))
               (sha256
                (base32
                 "08129my8s9fbrk0vqvnmx6ph4nid744g5vbwphzkaik51664vln5"))))
@@ -652,10 +669,10 @@ library.")
        ("bison" ,bison)))
     (home-page "http://freecode.com/projects/libidl")
     (synopsis "Create trees of CORBA Interface Definition Language files")
-    (description  "libidl is a library for creating trees of CORBA Interface
+    (description  "Libidl is a library for creating trees of CORBA Interface
 Definition Language (idl) files, which is a specification for defining
 portable interfaces. libidl was initially written for orbit (the orb from the
-GNOME project, and the primary means of libidl distribution). However, the
+GNOME project, and the primary means of libidl distribution).  However, the
 functionality was designed to be as reusable and portable as possible.") 
     (license license:lgpl2.0+)))
 
@@ -667,10 +684,9 @@ functionality was designed to be as reusable and portable as possible.")
     (source (origin
               (method url-fetch)
               (uri (let ((upstream-name "ORBit2")) 
-		     (string-append
-		      "mirror://gnome/sources/" upstream-name "/" (string-take version 4) "/" upstream-name "-"
-		      version
-		      ".tar.bz2")))
+		     (string-append "mirror://gnome/sources/" upstream-name "/"
+                                    (version-major+minor version) "/"
+                                    upstream-name "-" version ".tar.bz2")))
               (sha256
                (base32 "0l3mhpyym9m5iz09fz0rgiqxl2ym6kpkwpsp1xrr4aa80nlh1jam"))))
     (build-system gnu-build-system)
@@ -691,7 +707,7 @@ functionality was designed to be as reusable and portable as possible.")
      `(("pkg-config" ,pkg-config)))
     (home-page "https://projects.gnome.org/orbit2/")
     (synopsis "CORBA 2.4-compliant Object Request Broker")
-    (description  "orbit2 is a CORBA 2.4-compliant Object Request Broker (orb)
+    (description  "ORBit2 is a CORBA 2.4-compliant Object Request Broker (orb)
 featuring mature C, C++ and Python bindings.") 
     ;; Licence notice is unclear.  The Web page simply say "GPL" without giving a version.
     ;; SOME of the code files have licence notices for GPLv2+
@@ -706,8 +722,7 @@ featuring mature C, C++ and Python bindings.")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnome/sources/" name "/"
-                                  (string-join (take (string-split version #\.) 2)
-                                               ".")
+                                  (version-major+minor version)
                                   "/" name "-" version ".tar.bz2"))
               (sha256
                (base32 "0swp4kk6x7hy1rvd1f9jba31lvfc6qvafkvbpg9h0r34fzrd8q4i"))
@@ -755,10 +770,9 @@ use in GNOME applications, built on top of CORBA.")
               (method url-fetch)
 	      (uri 
 	       (let ((upstream-name "GConf"))
-		 (string-append
-		  "mirror://gnome/sources/" upstream-name "/" (string-take version 3)  "/" upstream-name "-"
-		  version
-		  ".tar.xz")))
+		 (string-append "mirror://gnome/sources/" upstream-name "/"
+                                (version-major+minor version) "/"
+                                upstream-name "-" version ".tar.xz")))
               (sha256
                (base32 "0k3q9nh53yhc9qxf1zaicz4sk8p3kzq4ndjdsgpaa2db0ccbj4hr"))))
     (build-system gnu-build-system)
@@ -772,9 +786,9 @@ use in GNOME applications, built on top of CORBA.")
        ("glib" ,glib "bin")             ; for glib-genmarshal, etc.
        ("pkg-config" ,pkg-config)))
     (home-page "https://projects.gnome.org/gconf/")
-    (synopsis "store application preferences")
-    (description  "gconf is a system for storing application preferences. It
-is intended for user preferences; not arbitrary data storage.") 
+    (synopsis "Store application preferences")
+    (description "Gconf is a system for storing application preferences.  It
+is intended for user preferences; not arbitrary data storage.")
     (license license:lgpl2.0+))) 
 
 
@@ -784,10 +798,9 @@ is intended for user preferences; not arbitrary data storage.")
     (version "2.18.0")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 4)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "1mvg8glb2a40yilmyabmb7fkbzlqd3i3d31kbkabqnq86xdnn69p"))))
@@ -796,7 +809,7 @@ is intended for user preferences; not arbitrary data storage.")
      `(("perl" ,perl)
        ("intltool" ,intltool)))
     (home-page "http://www.gnome.org")
-    (synopsis "base MIME and Application database for GNOME")
+    (synopsis "Base MIME and Application database for GNOME")
     (description  "GNOME Mime Data is a module which contains the base MIME
 and Application database for GNOME.  The data stored by this module is
 designed to be accessed through the MIME functions in GnomeVFS.")
@@ -809,10 +822,9 @@ designed to be accessed through the MIME functions in GnomeVFS.")
     (version "2.24.4")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 4)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32 "1ajg8jb8k3snxc7rrgczlh8daxkjidmcv3zr9w809sq4p2sn9pk2"))))
     (build-system gnu-build-system)
@@ -842,9 +854,9 @@ designed to be accessed through the MIME functions in GnomeVFS.")
        ("intltool" ,intltool)
        ("pkg-config" ,pkg-config)))
     (home-page "https://developer.gnome.org/gnome-vfs/")
-    (synopsis "access files and folders in GNOME applications")
+    (synopsis "Access files and folders in GNOME applications")
     (description  "GnomeVFS is the core library used to access files and
-folders in GNOME applications. It provides a file system abstraction which
+folders in GNOME applications.  It provides a file system abstraction which
 allows applications to access local and remote files with a single consistent API.")
     (license license:lgpl2.0+)))
 
@@ -856,11 +868,9 @@ allows applications to access local and remote files with a single consistent AP
     (version "2.32.1")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/"
-                    (string-take version 4)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "197pnq8y0knqjhm2fg4j6hbqqm3qfzfnd0irhwxpk1b4hqb3kimj"))))
@@ -900,17 +910,16 @@ files and URIs, and displaying help.")
 (define-public libart-lgpl
   (package
     (name "libart-lgpl")
-    (version "2.3.9")
+    (version "2.3.21")
     (source (origin
               (method url-fetch)
               (uri (let ((upstream-name "libart_lgpl"))
-                     (string-append
-                      "mirror://gnome/sources/" upstream-name "/" 
-                      (string-take version 3) "/" upstream-name "-" version
-                      ".tar.bz2")))
+                     (string-append "mirror://gnome/sources/" upstream-name "/"
+                                    (version-major+minor version) "/"
+                                    upstream-name "-" version ".tar.bz2")))
               (sha256
                (base32
-                "072r4svs4hjf2f4gxzx02n3f970kdv9fpx54r2m8bd42fjyyawrw"))))
+                "1yknfkyzgz9s616is0l9gp5aray0f2ry4dw533jgzj8gq5s1xhgx"))))
     (build-system gnu-build-system)
     (native-inputs
      `(("pkg-config" ,pkg-config)))
@@ -928,10 +937,9 @@ high-quality vector-based 2D library with antialiasing and alpha composition.")
     (version "2.30.3")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 4)  "/" name "-"
-                    version
-                    ".tar.gz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.gz"))
               (sha256
                (base32
                 "1nhnq4lfkk8ljkdafscwaggx0h95mq0rxnd7zgqyq0xb6kkqbjm8"))))
@@ -955,10 +963,9 @@ creating interactive structured graphics.")
     (version "2.24.5")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 4)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "03rwbli76crkjl6gp422wrc9lqpl174k56cp9i96b7l8jlj2yddf"))))
@@ -979,8 +986,8 @@ creating interactive structured graphics.")
        ("pkg-config" ,pkg-config)))
     (home-page "https://developer.gnome.org/libgnomeui/")
     (synopsis "Additional widgets for applications")
-    (description  "The libgnomeui library provides additional widgets for
-applications. Many of the widgets from libgnomeui have already been ported to GTK+.")
+    (description "The libgnomeui library provides additional widgets for
+applications.  Many of the widgets from libgnomeui have already been ported to GTK+.")
     (license license:lgpl2.0+)))
 
 (define-public libglade
@@ -989,10 +996,9 @@ applications. Many of the widgets from libgnomeui have already been ported to GT
     (version "2.6.4")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 3)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "1v2x2s04jry4gpabws92i0wq2ghd47yr5n9nhgnkd7c38xv1wdk4"))))
@@ -1004,8 +1010,8 @@ applications. Many of the widgets from libgnomeui have already been ported to GT
     (native-inputs
      `(("pkg-config" ,pkg-config)))
     (home-page "https://developer.gnome.org/libglade")
-    (synopsis "load glade interfaces and access the glade built widgets")
-    (description  "libglade is a library that provides interfaces for loading
+    (synopsis "Load glade interfaces and access the glade built widgets")
+    (description "Libglade is a library that provides interfaces for loading
 graphical interfaces described in glade files and for accessing the
 widgets built in the loading process.")
     (license license:gpl2+))) ; This is correct.  GPL not LGPL
@@ -1016,10 +1022,9 @@ widgets built in the loading process.")
     (version "2.8.2")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 3)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "129ka3nn8gx9dlfry17ib79azxk45wzfv5rgqzw6dwx2b5ns8phm"))))
@@ -1034,8 +1039,8 @@ widgets built in the loading process.")
        ("glib" ,glib "bin")             ; for glib-genmarshal, etc.
        ("pkg-config" ,pkg-config)))
     (home-page "https://projects.gnome.org/gnome-print/home/faq.html")
-    (synopsis "printing framework for GNOME")
-    (description  "Gnome-print is a high-quality printing framework for GNOME.")
+    (synopsis "Printing framework for GNOME")
+    (description "Gnome-print is a high-quality printing framework for GNOME.")
     (license license:lgpl2.0+)))
 
 
@@ -1045,10 +1050,9 @@ widgets built in the loading process.")
     (version "2.8.2")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" (string-take version 3)  "/" name "-"
-                    version
-                    ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "1ivipk7r61rg90p9kp889j28xlyyj6466ypvwa4jvnrcllnaajsw"))))
@@ -1075,10 +1079,9 @@ widgets built in the loading process.")
     (version "2.24.5")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/"
-                    (string-join (take (string-split version #\.) 2) ".")
-                    "/" name "-" version ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "1kbgqh7bw0fdx4f1a1aqwpff7gp5mwhbaz60c6c98bc4djng5dgs"))))
@@ -1123,10 +1126,9 @@ controls using the Bonobo component framework.")
     (version "0.10.14")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" 
-                    (string-take version 4) "/" name "-"
-                    version    ".tar.xz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.xz"))
               (sha256
                (base32 "0kj0iwng6w4axm7yv2zy7myn5dhw5ilrlq2pzrjlm9i852ikqy60"))))
     (build-system gnu-build-system)
@@ -1138,6 +1140,7 @@ controls using the Bonobo component framework.")
        ("libxml2" ,libxml2)))
     (native-inputs
      `(("intltool" ,intltool)
+       ("glib" ,glib "bin")
        ("pkg-config" ,pkg-config)))
     (home-page "https://developer.gnome.org/goffice/")
     (synopsis "Document-centric objects and utilities")
@@ -1153,10 +1156,9 @@ controls using the Bonobo component framework.")
     (version "1.12.17")
     (source (origin
               (method url-fetch)
-              (uri (string-append
-                    "mirror://gnome/sources/" name "/" 
-                    (string-take version 4) "/" name "-" version
-                    ".tar.xz"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.xz"))
               (sha256
                (base32
                 "18bvc3phghr4p5440fp8hm6gvp53d3mqs9cyc637zpmk0b6bcp7c"))))
@@ -1187,6 +1189,7 @@ controls using the Bonobo component framework.")
        ("zlib" ,zlib)))
     (native-inputs
      `(("intltool" ,intltool)
+       ("glib:bin" ,glib "bin")
        ("pkg-config" ,pkg-config)))
     (home-page "http://www.gnumeric.org")
     (synopsis "Spreadsheet application")
@@ -1199,3 +1202,47 @@ engineering.")
     (license
     ;; Dual licensed under GPLv2 or GPLv3 (both without "or later")
      (list license:gpl2 license:gpl3))))
+
+(define-public gnome-themes-standard
+  (package
+    (name "gnome-themes-standard")
+    ;; The version of this package should be the same as the version of
+    ;; gnome-desktop.
+    (version (package-version gnome-desktop))
+    (source
+     (origin
+       (method url-fetch)
+       (uri (string-append "mirror://gnome/sources/" name "/" 
+                           (version-major+minor version) "/" name "-"
+                           version ".tar.xz"))
+       (sha256
+        (base32
+         "0f2b3ypkfvrdsxcvp14ja9wqj382f1p46yrjvhhxkkjgagy6qb41"))))
+    (build-system gnu-build-system)
+    (inputs
+     `(("gtk+" ,gtk+)
+       ("gtk+-2" ,gtk+-2)
+       ("librsvg" ,librsvg)
+       ("libxml2" ,libxml2)
+       ("glib" ,glib)))
+    (native-inputs
+     `(("intltool" ,intltool)
+       ("glib:bin" ,glib "bin")
+       ("pkg-config" ,pkg-config)))
+    (arguments
+     `(#:phases
+       (alist-cons-before
+        'build 'use-full-cache
+        ;; Use librsvg's loaders.cache instead of the one provided by
+        ;; gdk-pixbuf because the latter does not include support for SVG
+        ;; files.
+        (lambda* (#:key inputs #:allow-other-keys)
+          (setenv "GDK_PIXBUF_MODULE_FILE" 
+                  (car (find-files (assoc-ref inputs "librsvg") 
+                                   "loaders\\.cache"))))
+        %standard-phases)))
+    (home-page "https://launchpad.net/gnome-themes-standard")
+    (synopsis "Default GNOME 3 themes")
+    (description
+     "The default GNOME 3 themes (Adwaita and some accessibility themes).")
+    (license license:lgpl2.1+)))
