@@ -27,8 +27,7 @@
   #:use-module (gnu packages pth)
   #:use-module (gnu packages python)
   #:use-module (gnu packages readline)
-  #:use-module ((gnu packages compression)
-                #:renamer (symbol-prefix-proc 'guix:))
+  #:use-module ((gnu packages compression) #:prefix guix:)
   #:use-module (gnu packages gtk)
   #:use-module (gnu packages glib)
   #:use-module (gnu packages pkg-config)
@@ -51,8 +50,7 @@
         "02lv5h865f8if391xjp3njg04k0l4x2pwjkcdbzcwilail1skazq"))))
     (build-system gnu-build-system)
     (home-page "http://gnupg.org")
-    (synopsis
-     "Libgpg-error, a small library that defines common error values for all GnuPG components")
+    (synopsis "Library of error values for GnuPG components")
     (description
      "Libgpg-error is a small library that defines common error values
 for all GnuPG components.  Among these are GPG, GPGSM, GPGME,
@@ -63,14 +61,14 @@ Daemon and possibly more in the future.")
 (define-public libgcrypt
   (package
     (name "libgcrypt")
-    (version "1.6.1")
+    (version "1.6.2")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnupg/libgcrypt/libgcrypt-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "0w10vhpj1r5nq7qm6jp21p1v1vhf37701cw8yilygzzqd7mfzhx1"))))
+               "0k2wi34qhp5hq71w1ab3kw1gfsx7xff79bvynqkxp35kls94826y"))))
     (build-system gnu-build-system)
     (propagated-inputs
      `(("libgpg-error" ,libgpg-error)))
@@ -96,7 +94,7 @@ generation.")
 
 (define-public libgcrypt-1.5
   (package (inherit libgcrypt)
-    (version "1.5.3")
+    (version "1.5.4")
     (source
      (origin
       (method url-fetch)
@@ -104,12 +102,12 @@ generation.")
                           version ".tar.bz2"))
       (sha256
        (base32
-        "1lar8y3lh61zl5flljpz540d78g99h4d5idfwrfw8lm3gm737xdw"))))))
+        "0czvqxkzd5y872ipy6s010ifwdwv29sqbnqc4pf56sd486gqvy6m"))))))
 
 (define-public libassuan
   (package
     (name "libassuan")
-    (version "2.1.1")
+    (version "2.1.3")
     (source
      (origin
       (method url-fetch)
@@ -117,13 +115,13 @@ generation.")
                           version ".tar.bz2"))
       (sha256
        (base32
-        "1783nb0b6nr9yjhb5wfh8ykc5w89f4anppz1kz9913mqg5vxdqi3"))))
+        "06hxyns8i73c6vrbrxyx6h38kwa7971h01qfc5cyna69afrp08gs"))))
     (build-system gnu-build-system)
     (propagated-inputs
      `(("libgpg-error" ,libgpg-error) ("pth" ,pth)))
     (home-page "http://gnupg.org")
     (synopsis
-     "Libassuan, the IPC library used by GnuPG and related software")
+     "IPC library used by GnuPG and related software")
     (description
      "Libassuan is a small library implementing the so-called Assuan
 protocol.  This protocol is used for IPC between most newer
@@ -157,8 +155,7 @@ provided.")
              (string-append "--with-gpg-error-prefix="
                             (assoc-ref %build-inputs "libgpg-error")))))
     (home-page "http://www.gnupg.org")
-    (synopsis
-     "Libksba is a CMS and X.509 access library under development")
+    (synopsis "CMS and X.509 access library")
     (description
      "KSBA (pronounced Kasbah) is a library to make X.509 certificates
 as well as the CMS easily accessible by other applications.  Both
@@ -168,14 +165,14 @@ specifications are building blocks of S/MIME and TLS.")
 (define-public gnupg
   (package
     (name "gnupg")
-    (version "2.0.25")
+    (version "2.0.26")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnupg/gnupg/gnupg-" version
                                   ".tar.bz2"))
               (sha256
                (base32
-                "08sqdkybgw4jkdkcyz1bi6y8irj87hpr5b12lkb57kwny1yykaxk"))))
+                "1q5qcl5panrvcvpwvz6nl9gayl5a6vwvfhgdcxqpmbl2qc6y6n3p"))))
     (build-system gnu-build-system)
     (inputs
      `(("bzip2" ,guix:bzip2)
@@ -234,7 +231,7 @@ libskba (working with X.509 certificates and CMS data).")
 (define-public gpgme
   (package
     (name "gpgme")
-    (version "1.4.3")
+    (version "1.5.1")
     (source
      (origin
       (method url-fetch)
@@ -242,7 +239,7 @@ libskba (working with X.509 certificates and CMS data).")
                           ".tar.bz2"))
       (sha256
        (base32
-        "15h429h6pd67iiv580bjmwbkadpxsdppw0xrqpcm4dvm24jc271d"))))
+        "1qqi9bxwxxsc4r15j7drclgp0w8jk9nj3h2fsivk4c7brvw3lbvc"))))
     (build-system gnu-build-system)
     (propagated-inputs
      ;; Needs to be propagated because gpgme.h includes gpg-error.h.
@@ -250,8 +247,9 @@ libskba (working with X.509 certificates and CMS data).")
     (inputs
      `(("gnupg" ,gnupg)
        ("libassuan" ,libassuan)))
+    (arguments '(#:make-flags '("GPG=gpg2")))
     (home-page "http://www.gnupg.org/related_software/gpgme/")
-    (synopsis "library providing simplified access to GnuPG functionality")
+    (synopsis "Library providing simplified access to GnuPG functionality")
     (description
      "GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
 easier for applications.  It provides a High-Level Crypto API for encryption,
@@ -303,8 +301,8 @@ and every application benefits from this.")
    (synopsis "Programs to simplify GnuPG key signing")
    (description
     "Pius (PGP Individual UID Signer) helps attendees of PGP keysigning
-parties. It is the main utility and makes it possible to quickly and easily
-sign each UID on a set of PGP keys. It is designed to take the pain out of
+parties.  It is the main utility and makes it possible to quickly and easily
+sign each UID on a set of PGP keys.  It is designed to take the pain out of
 the sign-all-the-keys part of PGP Keysigning Party while adding security
 to the process.
 
@@ -375,9 +373,9 @@ PGP keysigning parties.")
                 "gpgparticipants.1" "gpgsigs.1" "gpgwrap.1"
                 "process_keys.1" "pgpring.1" "keyanalyze.1"))))
       %standard-phases)))))
-   (synopsis "collection of scripts for simplifying gnupg key signing")
+   (synopsis "Collection of scripts for simplifying gnupg key signing")
    (description
-    "signing-party is a collection for all kinds of PGP/GnuPG related things,
+    "Signing-party is a collection for all kinds of PGP/GnuPG related things,
 including tools for signing keys, keyring analysis, and party preparation.
 
  * caff: CA - Fire and Forget signs and mails a key
