@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -19,8 +20,7 @@
 
 (define-module (gnu packages gnuzilla)
   #:use-module (gnu packages)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -31,9 +31,11 @@
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages compression)
+  #:use-module (gnu packages fontutils)
   #:use-module (gnu packages libevent)
   #:use-module (gnu packages image)
   #:use-module (gnu packages libffi)
+  #:use-module (gnu packages pulseaudio)
   #:use-module (gnu packages python)
   #:use-module (gnu packages xorg)
   #:use-module (gnu packages gl)
@@ -43,16 +45,15 @@
 (define-public icecat
   (package
     (name "icecat")
-    (version "24.0")
+    (version "31.2.0")
     (source
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnu/gnuzilla/"
-                          (substring version 0 (string-index version #\.))
-                          "/icecat-" version ".tar.gz"))
+                          version "/" name "-" version ".tar.xz"))
       (sha256
        (base32
-        "1vxzjwmhad6yxx4sk9zvapjgv5salcv10id061q0991ii3dycy9a"))))
+        "02r9klfc0z26w270inq652249hq0wfzvwhzvwmk0n8v8nzkk5idh"))))
     (build-system gnu-build-system)
     (inputs
      `(("alsa-lib" ,alsa-lib)
@@ -63,9 +64,13 @@
        ("gstreamer" ,gstreamer-0.10)
        ("gst-plugins-base" ,gst-plugins-base-0.10)
        ("gtk+" ,gtk+-2)
+       ("pango" ,pango)
+       ("freetype" ,freetype)
+       ("libxft" ,libxft)
        ("libevent" ,libevent)
        ("libxt" ,libxt)
        ("libffi" ,libffi)
+       ("pulseaudio" ,pulseaudio)
        ("mesa" ,mesa)
        ("unzip" ,unzip)
        ("yasm" ,yasm)
@@ -77,7 +82,8 @@
        ("python2-pysqlite" ,python2-pysqlite)
        ("pkg-config" ,pkg-config)))
     (arguments
-     `(#:tests? #f ; no check target
+     `(#:tests? #f          ; no check target
+       #:out-of-source? #t  ; must be built outside of the source directory
 
        #:configure-flags '(;; Building with debugging symbols takes ~5GiB, so
                            ;; disable it.
@@ -113,30 +119,33 @@
                            "--enable-system-ffi")
 
        #:phases
-         (alist-cons-before
-          'patch-source-shebangs 'sanitise
-          (lambda _
-            ;; delete dangling symlinks
-            (delete-file "browser/base/content/.#aboutDialog.xul")
-            (delete-file "browser/base/content/abouthome/.#aboutHome.xhtml")
-            (delete-file "browser/branding/unofficial/content/.#aboutHome.xhtml")
-            (delete-file "toolkit/crashreporter/google-breakpad/autotools/compile"))
-         (alist-replace
-          'configure
-          ;; configure does not work followed by both "SHELL=..." and
-          ;; "CONFIG_SHELL=..."; set environment variables instead
-          (lambda* (#:key outputs configure-flags #:allow-other-keys)
-            (let ((out (assoc-ref outputs "out")))
-              (setenv "SHELL" (which "bash"))
-              (setenv "CONFIG_SHELL" (which "bash"))
-              (zero? (apply system* "./configure"
-                            (string-append "--prefix=" out)
-                            configure-flags))))
-          %standard-phases))))
+       (alist-replace
+        'configure
+        ;; configure does not work followed by both "SHELL=..." and
+        ;; "CONFIG_SHELL=..."; set environment variables instead
+        (lambda* (#:key outputs configure-flags #:allow-other-keys)
+          (let* ((out (assoc-ref outputs "out"))
+                 (bash (which "bash"))
+                 (abs-srcdir (getcwd))
+                 (srcdir (string-append "../" (basename abs-srcdir)))
+                 (flags `(,(string-append "--prefix=" out)
+                          ,(string-append "--with-l10n-base="
+                                          abs-srcdir "/l10n")
+                          ,@configure-flags)))
+            (setenv "SHELL" bash)
+            (setenv "CONFIG_SHELL" bash)
+            (mkdir "../build")
+            (chdir "../build")
+            (format #t "build directory: ~s~%" (getcwd))
+            (format #t "configure flags: ~s~%" flags)
+            (zero? (apply system* bash
+                          (string-append srcdir "/configure")
+                          flags))))
+        %standard-phases)))
     (home-page "http://www.gnu.org/software/gnuzilla/")
     (synopsis "Entirely free browser derived from Mozilla Firefox")
     (description
      "IceCat is the GNU version of the Firefox browser.  It is entirely free
-software, which does not recommend non-free plugins and addons. It also
+software, which does not recommend non-free plugins and addons.  It also
 features built-in privacy-protecting features.")
     (license license:mpl2.0))) ; and others, see toolkit/content/license.html
