@@ -1,6 +1,8 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -18,8 +20,8 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages gtk)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
+  #:use-module (guix utils)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -45,8 +47,8 @@
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnome/sources/" name "/"
-                                (string-take version 4) "/" name "-"
-                                version ".tar.xz"))
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "1c2hbg66wfvibsz2ia0ri48yr62751fn950i97c53j3b0fjifsb3"))))
@@ -59,7 +61,7 @@
    (synopsis "GNOME accessibility toolkit")
    (description
     "ATK provides the set of accessibility interfaces that are implemented
-by other toolkits and applications. Using the ATK interfaces, accessibility
+by other toolkits and applications.  Using the ATK interfaces, accessibility
 tools have full access to view and control running applications.")
    (license license:lgpl2.0+)
    (home-page "https://developer.gnome.org/atk/")))
@@ -101,16 +103,16 @@ tools have full access to view and control running applications.")
     "Cairo is a 2D graphics library with support for multiple output devices.
 Currently supported output targets include the X Window System (via both
 Xlib and XCB), Quartz, Win32, image buffers, PostScript, PDF, and SVG file
-output. Experimental backends include OpenGL, BeOS, OS/2, and DirectFB.
+output.  Experimental backends include OpenGL, BeOS, OS/2, and DirectFB.
 
 Cairo is designed to produce consistent output on all output media while
 taking advantage of display hardware acceleration when available
 eg. through the X Render Extension).
 
 The cairo API provides operations similar to the drawing operators of
-PostScript and PDF. Operations in cairo including stroking and filling cubic
+PostScript and PDF.  Operations in cairo including stroking and filling cubic
 Bézier splines, transforming and compositing translucent images, and
-antialiased text rendering. All drawing operations can be transformed by any
+antialiased text rendering.  All drawing operations can be transformed by any
 affine transformation (scale, rotation, shear, etc.)")
    (license license:lgpl2.1) ; or Mozilla Public License 1.1
    (home-page "http://cairographics.org/")))
@@ -129,11 +131,14 @@ affine transformation (scale, rotation, shear, etc.)")
    (build-system gnu-build-system)
    (inputs
     `(("cairo" ,cairo)
+      ("graphite2" ,graphite2)
       ("icu4c" ,icu4c)))
    (native-inputs
-     `(("pkg-config" ,pkg-config)
+    `(("pkg-config" ,pkg-config)
       ("python" ,python-wrapper)))
-   (synopsis "opentype text shaping engine")
+   (arguments
+    `(#:configure-flags `("--with-graphite2=yes")))
+   (synopsis "OpenType text shaping engine")
    (description
     "HarfBuzz is an OpenType text shaping engine.")
    (license (license:x11-style "file://COPYING"
@@ -164,7 +169,7 @@ affine transformation (scale, rotation, shear, etc.)")
    (synopsis "GNOME text and font handling library")
    (description
     "Pango is the core text and font handling library used in GNOME
-applications. It has extensive support for the different writing systems
+applications.  It has extensive support for the different writing systems
 used throughout the world.")
    (license license:lgpl2.0+)
    (home-page "https://developer.gnome.org/pango/")))
@@ -175,10 +180,9 @@ used throughout the world.")
     (version "0.0.2")
     (source (origin
              (method url-fetch)
-             (uri (string-append
-                   "mirror://gnome/sources/" name "/" (string-take version 3)  "/" name "-"
-                   version
-                   ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "0ip0ziys6mrqqmz4n71ays0kf5cs1xflj1gfpvs4fgy2nsrr482m"))))
@@ -190,7 +194,7 @@ used throughout the world.")
      `(("intltool" ,intltool)
        ("pkg-config" ,pkg-config)))
     (home-page "https://developer.gnome.org/pango")
-    (synopsis "functions now obsolete in pango")
+    (synopsis "Obsolete pango functions")
     (description  "Pangox was a X backend to pango.  It is now obsolete and no
 longer provided by recent pango releases.  pangox-compat provides the
 functions which were removed.")
@@ -203,9 +207,9 @@ functions which were removed.")
     (version "2.10.5") ; This is the last version which builds against gtk+2
     (source (origin
               (method url-fetch)
-              (uri (string-append "mirror://gnome/sources/gtksourceview/"
-                                  (string-take version 4) "/gtksourceview-"
-                                  version ".tar.bz2"))
+              (uri (string-append "mirror://gnome/sources/" name "/"
+                                  (version-major+minor version)  "/"
+                                  name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "07hrabhpl6n8ajz10s0d960jdwndxs87szxyn428mpxi8cvpg1f5"))))
@@ -257,8 +261,9 @@ printing and other features typical of a source code editor.")
    (version "2.28.2")
    (source (origin
             (method url-fetch)
-            (uri (string-append "mirror://gnome/sources/gdk-pixbuf/2.28/gdk-pixbuf-"
-                                version ".tar.xz"))
+            (uri (string-append "mirror://gnome/sources/" name "/"
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "05s6ksvy1yan6h6zny9n3bmvygcnzma6ljl6i0z9cci2xg116c8q"))))
@@ -286,8 +291,8 @@ in the GNOME project.")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnome/sources/" name "/"
-                                (string-take version 4) "/" name "-"
-                                version ".tar.xz"))
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "1ns44yibdgcwzwri7sr075hfs5rh5lgxkh71247a0822az3mahcn"))))
@@ -316,8 +321,8 @@ is part of the GNOME accessibility project.")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnome/sources/" name "/"
-                                (string-take version 4) "/" name "-"
-                                version ".tar.xz"))
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "150sqc21difazqd53llwfdaqnwfy73bic9hia41xpfy9kcpzz9yy"))))
@@ -345,8 +350,8 @@ is part of the GNOME accessibility project.")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnome/sources/" name "/"
-                                (string-take version 4) "/" name "-"
-                                version ".tar.xz"))
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "1qyw73pr9ryqhir2h1kbx3vm70km4dg2fxrgkrdlpv0rvlb94bih"))))
@@ -372,7 +377,7 @@ is part of the GNOME accessibility project.")
    (synopsis "Cross-platform toolkit for creating graphical user interfaces")
    (description
     "GTK+, or the GIMP Toolkit, is a multi-platform toolkit for creating
-graphical user interfaces. Offering a complete set of widgets, GTK+ is
+graphical user interfaces.  Offering a complete set of widgets, GTK+ is
 suitable for projects ranging from small one-off tools to complete
 application suites.")
    (license license:lgpl2.0+)
@@ -380,12 +385,13 @@ application suites.")
 
 (define-public gtk+
   (package (inherit gtk+-2)
+   (name "gtk+")
    (version "3.10.1")
    (source (origin
             (method url-fetch)
-            (uri (string-append "mirror://gnome/sources/gtk+/"
-                                (string-take version 4) "/gtk+-"
-                                version ".tar.xz"))
+            (uri (string-append "mirror://gnome/sources/" name "/"
+                                (version-major+minor version)  "/"
+                                name "-" version ".tar.xz"))
             (sha256
              (base32
               "1f3a7r3z7i9xh5imlfpfcgyydzkj2fnd0v6ylvqxij0yzfbnhbn1"))))
@@ -404,9 +410,18 @@ application suites.")
       ("pkg-config" ,pkg-config)
       ("gobject-introspection" ,gobject-introspection)
       ("python-wrapper" ,python-wrapper)
-      ("xorg-server" ,xorg-server)))
+
+      ;; FIXME: The Xorg server is needed to run the tests, but it currently
+      ;; fails to build on mips64el, so remove it in the meantime.
+      ,@(if (string=? (or (%current-target-system) (%current-system))
+                      "mips64el-linux")
+            '()
+            `(("xorg-server" ,xorg-server)))))
    (arguments
-    `(#:phases
+    `(;; FIXME: See above.
+      #:tests? ,(not (string=? (or (%current-target-system) (%current-system))
+                               "mips64el-linux"))
+      #:phases
       (alist-replace
        'configure
        (lambda* (#:key inputs #:allow-other-keys #:rest args)
@@ -466,8 +481,10 @@ application suites.")
     (inputs
      `(("guile-lib" ,guile-lib)
        ("expat" ,expat)
-       ("cairo" ,cairo)
        ("guile" ,guile-2.0)))
+    (propagated-inputs
+     ;; The .pc file refers to 'cairo'.
+     `(("cairo" ,cairo)))
     (native-inputs
       `(("pkg-config" ,pkg-config)))
     (home-page "http://www.nongnu.org/guile-cairo/")
@@ -520,8 +537,9 @@ library.")
     (version "2.34.0")
     (source (origin
              (method url-fetch)
-             (uri (string-append "mirror://gnome/sources/pangomm/2.34/pangomm-"
-                                 version ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "0hcyvv7c5zmivprdam6cp111i6hn2y5jsxzk00m6j9pncbzvp0hf"))))
@@ -545,8 +563,9 @@ library.")
     (version "2.22.7")
     (source (origin
              (method url-fetch)
-             (uri (string-append "mirror://gnome/sources/atkmm/2.22/atkmm-"
-                                 version ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "06zrf2ymml2dzp53sss0d4ch4dk9v09jm8rglnrmwk4v81mq9gxz"))))
@@ -567,8 +586,9 @@ toolkit.")
     (version "3.9.16")
     (source (origin
              (method url-fetch)
-             (uri (string-append "mirror://gnome/sources/gtkmm/3.9/gtkmm-"
-                                 version ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "0yf8wwv4w02p70nrxsbs0nhm0w4gkn2wggdjygd8vif062anf1rs"))))
@@ -594,12 +614,13 @@ extensive documentation, including API reference and a tutorial.")
 
 (define-public gtkmm-2
   (package (inherit gtkmm)
+    (name "gtkmm")
     (version "2.24.2")
     (source (origin
              (method url-fetch)
-             (uri (string-append "mirror://gnome/sources/gtkmm/"
-                                 (string-take version 4) "/gtkmm-"
-                                 version ".tar.xz"))
+             (uri (string-append "mirror://gnome/sources/" name "/"
+                                 (version-major+minor version)  "/"
+                                 name "-" version ".tar.xz"))
              (sha256
               (base32
                "0gcm91sc1a05c56kzh74l370ggj0zz8nmmjvjaaxgmhdq8lpl369"))))
