@@ -68,15 +68,17 @@
         (lambda* (#:key outputs #:allow-other-keys)
           (let* ((out (assoc-ref outputs "out"))
                  (lib (string-append out "/lib")))
-            ;; Add LIB to the RUNPATH of all the libraries.
+            ;; Add LIB to the RUNPATH of all the libraries and binaries.
             (with-directory-excursion out
               (for-each (cut augment-rpath <> lib)
-                        (find-files "lib" ".*")))))
+                        (append (find-files "lib" ".*")
+                                (find-files "bin" ".*")
+                                (find-files "sbin" ".*"))))))
         %standard-phases)))))
-   (synopsis "ICU, International Components for Unicode")
+   (synopsis "International Components for Unicode")
    (description
     "ICU is a set of C/C++ and Java libraries providing Unicode and
-globalisation support for software applications. This package contains the
+globalisation support for software applications.  This package contains the
 C/C++ part.")
    (license x11)
    (home-page "http://site.icu-project.org/")))
