@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2014 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -24,7 +25,9 @@
   #:use-module (gnu packages autotools)
   #:use-module (gnu packages gstreamer)
   #:use-module (gnu packages gtk)
+  #:use-module (gnu packages glib)
   #:use-module (gnu packages linux)
+  #:use-module (gnu packages pulseaudio)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages xiph))
 
@@ -35,19 +38,24 @@
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "http://0pointer.de/lennart/projects/libcanberra/libcanberra-"
-                          version ".tar.xz"))
+
+      ;; This used to be at 0pointer.de but it vanished.
+      (uri (string-append
+            "http://pkgs.fedoraproject.org/repo/pkgs/libcanberra/libcanberra-"
+            version ".tar.xz/34cb7e4430afaf6f447c4ebdb9b42072/libcanberra-"
+            version ".tar.xz"))
       (sha256
        (base32
         "0wps39h8rx2b00vyvkia5j40fkak3dpipp1kzilqla0cgvk73dn2"))))
     (build-system gnu-build-system)
     (inputs
-     ;; FIXME: Add optional inputs udev and pulse.
      `(("alsa-lib" ,alsa-lib)
        ("gstreamer" ,gstreamer)
        ("gtk+" ,gtk+)
        ("libtool" ,libtool)
-       ("libvorbis" ,libvorbis)))
+       ("libvorbis" ,libvorbis)
+       ("pulseaudio" ,pulseaudio)
+       ("udev" ,eudev)))
     (native-inputs
      `(("pkg-config" ,pkg-config)))
     (home-page "http://0pointer.de/lennart/projects/libcanberra/")
@@ -59,3 +67,23 @@ Specifications, for generating event sounds on free desktops, such as
 GNOME.  It comes with several backends (ALSA, PulseAudio, OSS, GStreamer,
 null) and is designed to be portable.")
     (license lgpl2.1+)))
+
+(define-public sound-theme-freedesktop
+  (package
+    (name "sound-theme-freedesktop")
+    (version "0.8")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "http://people.freedesktop.org/~mccann/dist/"
+                                  name "-" version ".tar.bz2"))
+              (sha256
+               (base32
+                "054abv4gmfk9maw93fis0bf605rc56dah7ys5plc4pphxqh8nlfb"))))
+    (build-system gnu-build-system)
+    (native-inputs `(("intltool" ,intltool)))
+    (synopsis "Audio samples for use as a desktop sound theme")
+    (description
+     "This package provides audio samples that can be used by libcanberra as
+sounds for various system events.")
+    (license #f)
+    (home-page "http://www.freedesktop.org/wiki/Specifications/sound-theme-spec/")))
