@@ -26,18 +26,18 @@
 (define-public libidn
   (package
    (name "libidn")
-   (version "1.28")
+   (version "1.29")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/libidn/libidn-" version
                                 ".tar.gz"))
             (sha256 (base32
-                     "1yxbfdiwr3l91m79sksn6v5mgpl4lfj8i82zgryckas9hjb7ldfx"))))
+                     "0z3w5arlvyiyvzg76msg3n2px3c1glqr6wnj7rq6zczrpdyp90pv"))))
    (build-system gnu-build-system)
 ;; FIXME: No Java and C# libraries are currently built.
    (synopsis "Internationalized string processing library")
    (description
-    "libidn is a library implementing of the Stringprep, Punycode and IDNA
+     "libidn is a library implementing of the Stringprep, Punycode and IDNA
 specifications.  These are used to encode and decode internationalized domain
 names.  It includes native C, C# and Java libraries.")
    (license lgpl2.1+)
