@@ -129,6 +129,12 @@ the traditional flat-text whatis databases.")
     (build-system gnu-build-system)
     (arguments
      '(#:phases (alist-delete 'configure %standard-phases)
+
+       ;; The 'all' target depends on three targets that directly populate
+       ;; $(MANDIR) based on its current contents.  Doing that in parallel
+       ;; leads to undefined behavior (see <http://bugs.gnu.org/18701>.)
+       #:parallel-build? #f
+
        #:tests? #f
        #:make-flags (list (string-append "MANDIR="
                                          (assoc-ref %outputs "out")
@@ -145,7 +151,7 @@ Linux kernel and C library interfaces employed by user-space programs.")
 (define-public help2man
   (package
     (name "help2man")
-    (version "1.45.1")
+    (version "1.46.3")
     (source
      (origin
       (method url-fetch)
@@ -153,7 +159,7 @@ Linux kernel and C library interfaces employed by user-space programs.")
                           version ".tar.xz"))
       (sha256
        (base32
-        "1hk7ciqinq7djdb7s94y3jxh06rp8i93bpjmg4r40cniws8wf3y7"))))
+        "0hi94a6ai96yw0v8xgjzpp5c6jr33ifmbn2mkp7wz7rgmwxxqsd6"))))
     (build-system gnu-build-system)
     (arguments `(;; There's no `check' target.
                  #:tests? #f))
