@@ -22,29 +22,35 @@
   #:use-module (guix git-download)
   #:use-module (guix utils)
   #:use-module (guix build-system gnu)
-  #:use-module ((guix licenses) #:select (gpl3+))
+  #:use-module ((guix licenses) #:select (gpl3+ lgpl2.1+))
   #:use-module (gnu packages)
   #:use-module (gnu packages guile)
   #:use-module ((gnu packages compression) #:select (bzip2 gzip))
   #:use-module (gnu packages gnupg)
-  #:use-module (gnu packages sqlite)
+  #:use-module (gnu packages databases)
   #:use-module (gnu packages graphviz)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages autotools)
   #:use-module (gnu packages gettext)
-  #:use-module (gnu packages texinfo))
+  #:use-module (gnu packages texinfo)
+  #:use-module (gnu packages perl)
+  #:use-module (gnu packages curl)
+  #:use-module (gnu packages web)
+  #:use-module (gnu packages emacs)
+  #:use-module (gnu packages openssl)
+  #:use-module (gnu packages bdw-gc))
 
-(define-public guix-0.6
+(define-public guix-0.7
   (package
     (name "guix")
-    (version "0.6")
+    (version "0.7")
     (source (origin
              (method url-fetch)
              (uri (string-append "ftp://alpha.gnu.org/gnu/guix/guix-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "01xw51wizhsk827w4xp79k2b6dxjaviw04r6rbrb85qdxnwg6k9n"))))
+               "05r7bsjgc0a4m7yy433n3c1dlv2yqlf3qpwlhayn9djhpp2q1ssb"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags (list
@@ -70,6 +76,8 @@
                    (copy "mips64el")
                    #t)
                  %standard-phases)))
+    (native-inputs `(("pkg-config" ,pkg-config)
+                     ("emacs" ,emacs)))           ;for guix.el (0.8)
     (inputs
      (let ((boot-guile (lambda (arch hash)
                          (origin
@@ -85,7 +93,6 @@
          ("sqlite" ,sqlite)
          ("libgcrypt" ,libgcrypt)
          ("guile" ,guile-2.0)
-         ("pkg-config" ,pkg-config)
 
          ("boot-guile/i686"
           ,(boot-guile "i686"
@@ -103,17 +110,17 @@
     (synopsis "Functional package manager for installed software packages and versions")
     (description
      "GNU Guix is a functional package manager for the GNU system, and is
-also a distribution thereof.  It includes a virtual machine image. Besides
+also a distribution thereof.  It includes a virtual machine image.  Besides
 the usual package management features, it also supports transactional
-upgrades and roll-backs, per-user profiles, and much more. It is based on the
-Nix package manager.")
+upgrades and roll-backs, per-user profiles, and much more.  It is based on
+the Nix package manager.")
     (license gpl3+)))
 
-(define-public guix
+(define guix-devel
   ;; Development version of Guix.
-  (let ((commit "0ae8c15"))
-    (package (inherit guix-0.6)
-      (version (string-append "0.6." commit))
+  (let ((commit "48bd76e"))
+    (package (inherit guix-0.7)
+      (version (string-append "0.7." commit))
       (source (origin
                 (method git-fetch)
                 (uri (git-reference
@@ -122,9 +129,9 @@ Nix package manager.")
                       (recursive? #t)))
                 (sha256
                  (base32
-                  "1y6mwzwsjdxbfibqypb55dix371rifhfz0bygfr8k868lcdsawic"))))
+                  "1zd583msp531cs5crx6xjxmk181d2qwd6j3kjc29zrmvxh8rpk94"))))
       (arguments
-       (substitute-keyword-arguments (package-arguments guix-0.6)
+       (substitute-keyword-arguments (package-arguments guix-0.7)
          ((#:phases phases)
           `(alist-cons-before
             'configure 'bootstrap
@@ -160,4 +167,45 @@ Nix package manager.")
          ("gettext" ,gnu-gettext)
          ("texinfo" ,texinfo)
          ("graphviz" ,graphviz)
-         ,@(package-native-inputs guix-0.6))))))
+         ,@(package-native-inputs guix-0.7)))
+      (propagated-inputs
+       `(("guile-json" ,guile-json)
+         ,@(package-propagated-inputs guix-0.7))))))
+
+(define-public guix guix-devel)
+
+(define-public nix
+  (package
+    (name "nix")
+    (version "1.7")
+    (source (origin
+             (method url-fetch)
+             (uri (string-append "http://nixos.org/releases/nix/nix-"
+                                 version "/nix-" version ".tar.xz"))
+             (sha256
+              (base32
+               "14nc7mnma5sffqk9mglbf99w3jm4ck8pxnmkgyhy3qra9xjn749l"))))
+    (build-system gnu-build-system)
+    ;; XXX: Should we pass '--with-store-dir=/gnu/store'?  But then we'd also
+    ;; need '--localstatedir=/var'.  But then!  The thing would use /var/nix
+    ;; instead of /var/guix.  So in the end, we do nothing special.
+    (native-inputs `(("perl" ,perl)
+                     ("pkg-config" ,pkg-config)))
+    (inputs `(("curl" ,curl)
+              ("openssl" ,openssl)
+              ("libgc" ,libgc)
+              ("sqlite" ,sqlite)
+              ("bzip2" ,bzip2)
+              ("perl-www-curl" ,perl-www-curl)
+              ("perl-dbi" ,perl-dbi)
+              ("perl-dbd-sqlite" ,perl-dbd-sqlite)))
+    (home-page "http://nixos.org/nix/")
+    (synopsis "The Nix package manager")
+    (description
+     "Nix is a purely functional package manager.  This means that it treats
+packages like values in purely functional programming languages such as
+Haskell—they are built by functions that don't have side-effects, and they
+never change after they have been built.  Nix stores packages in the Nix
+store, usually the directory /nix/store, where each package has its own unique
+sub-directory.")
+    (license lgpl2.1+)))
