@@ -17,8 +17,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages pdf)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
@@ -35,6 +34,7 @@
   #:use-module (gnu packages glib)
   #:use-module (gnu packages gtk)
   #:use-module (gnu packages lua)
+  #:use-module (gnu packages curl)
   #:use-module (srfi srfi-1))
 
 (define-public poppler
@@ -76,7 +76,7 @@
       #:configure-flags
        '("--enable-xpdf-headers" ; to install header files
          "--enable-zlib")))
-   (synopsis "Poppler, a pdf rendering library")
+   (synopsis "PDF rendering library")
    (description
     "Poppler is a PDF rendering library based on the xpdf-3.0 code base.")
    (license license:gpl2+)
@@ -85,14 +85,13 @@
 (define-public xpdf
   (package
    (name "xpdf")
-   (version "3.03")
+   (version "3.04")
    (source (origin
             (method url-fetch)
             (uri (string-append "ftp://ftp.foolabs.com/pub/xpdf/xpdf-"
                                 version ".tar.gz"))
             (sha256 (base32
-                     "1jnfzdqc54wa73lw28kjv0m7120mksb0zkcn81jdlvijyvc67kq2"))
-            (patches (list (search-patch "xpdf-constchar.patch")))))
+                     "1rbp54mr3z2x3a3a1qmz8byzygzi223vckfam9ib5g1sfds0qf8i"))))
    (build-system gnu-build-system)
    (inputs `(("freetype" ,freetype)
              ("gs-fonts" ,gs-fonts)
@@ -103,6 +102,7 @@
              ("libxp" ,libxp)
              ("libxpm" ,libxpm)
              ("libxt" ,libxt)
+             ("libpng" ,libpng)
              ("zlib" ,zlib)))
    (arguments
     `(#:tests? #f ; there is no check target
@@ -121,7 +121,7 @@
                  (string-append gs-fonts "/share/fonts/type1/ghostscript"))
                 (("#fontFile") "fontFile"))))
         %standard-phases)))
-   (synopsis "Viewer for pdf files based on the Motif toolkit.")
+   (synopsis "Viewer for PDF files based on the Motif toolkit")
    (description
     "Xpdf is a viewer for Portable Document Format (PDF) files")
    (license license:gpl3) ; or gpl2, but not gpl2+
@@ -159,3 +159,69 @@ it easy to modify them and write the changes to disk.  It is primarily useful
 for applications that wish to do lower level manipulation of PDF, such as
 extracting content or merging files.")
     (license license:lgpl2.0+)))
+
+(define-public mupdf
+  (package
+    (name "mupdf")
+    (version "1.6")
+    (source
+      (origin
+        (method url-fetch)
+        (uri (string-append "http://mupdf.com/downloads/archive/"
+                            name "-" version "-source.tar.gz"))
+        (sha256
+          (base32 "0qx51rj6alzcagcixm59rvdpm54w6syrwr4184v439jh14ryw4wq"))
+        (patches
+          (list (search-patch "mupdf-buildsystem-fix.patch")))
+        (modules '((guix build utils)))
+        (snippet
+          '(begin
+            ;; Don't build the bundled-in third party libraries.
+            (delete-file-recursively "thirdparty")
+
+            ;; Make the scripts for finding openjpeg build details executable.
+            (chmod "ojp2_cppflags.sh" #o0755)
+            (chmod "ojp2_ldflags.sh" #o0755)))))
+
+    (build-system gnu-build-system)
+    (inputs
+      `(("curl" ,curl)
+        ("freetype" ,freetype)
+        ("jbig2dec" ,jbig2dec)
+        ("libjpeg" ,libjpeg)
+        ("libx11" ,libx11)
+        ("libxext" ,libxext)
+        ("openjpeg" ,openjpeg)
+        ("openssl" ,openssl)
+        ("zlib" ,zlib)))
+    (native-inputs
+      `(("pkg-config" ,pkg-config)))
+    (arguments
+      ;; Trying to run `$ make check' results in a no rule fault.
+      '(#:tests? #f
+
+        #:modules ((guix build gnu-build-system)
+                     (guix build utils)
+                     (srfi srfi-1))
+        #:phases (alist-replace
+                   'build
+                   (lambda _ (zero? (system* "make" "XCFLAGS=-fpic")))
+                   (alist-replace
+                     'install
+                     (lambda* (#:key outputs #:allow-other-keys)
+                       (let ((out (assoc-ref outputs "out")))
+                         (zero? (system* "make" (string-append "prefix=" out)
+                                         "install"))))
+                     (alist-delete 'configure %standard-phases)))))
+    (home-page "http://mupdf.com")
+    (synopsis "Lightweight PDF viewer and toolkit")
+    (description
+      "MuPDF is a C library that implements a PDF and XPS parsing and
+rendering engine.  It is used primarily to render pages into bitmaps,
+but also provides support for other operations such as searching and
+listing the table of contents and hyperlinks.
+
+The library ships with a rudimentary X11 viewer, and a set of command
+line tools for batch rendering (pdfdraw), examining the file structure
+(pdfshow), and rewriting files (pdfclean).")
+    (license license:agpl3+)))
