@@ -48,14 +48,13 @@
                           "share/pkgconfig")))))
    (home-page "http://www.freedesktop.org/wiki/Software/pkg-config")
    (license gpl2+)
-   (synopsis "a helper tool used when compiling applications and
-libraries")
+   (synopsis "Helper tool used when compiling applications and libraries")
    (description
     "pkg-config is a helper tool used when compiling applications and
 libraries.  It helps you insert the correct compiler options on the
 command line so an application can use gcc -o test test.c `pkg-config
 --libs --cflags glib-2.0` for instance, rather than hard-coding values
-on where to find glib (or other libraries). It is language-agnostic, so
+on where to find glib (or other libraries).  It is language-agnostic, so
 it can be used for defining the location of documentation tools, for
 instance.")))
 
