@@ -37,10 +37,18 @@
   #:use-module (gnu packages image)
   #:use-module (ice-9 match))
 
+(define (mit-scheme-source-directory system version)
+  (string-append "mit-scheme-"
+                 (if (or (string-prefix? "x86_64" system)
+                         (string-prefix? "i686" system))
+                     ""
+                     "c-")
+                 version))
+
 (define-public mit-scheme
   (package
     (name "mit-scheme")
-    (version "9.1.1")
+    (version "9.2")
     (source #f)                                   ; see below
     (build-system gnu-build-system)
     (arguments
@@ -51,13 +59,16 @@
         (lambda* (#:key inputs #:allow-other-keys)
           (and (zero? (system* "tar" "xzvf"
                                (assoc-ref inputs "source")))
-               (chdir ,(string-append name "-" version))
+               (chdir ,(mit-scheme-source-directory (%current-system)
+                                                    version))
                (begin
                  ;; Delete these dangling symlinks since they break
                  ;; `patch-shebangs'.
                  (for-each delete-file
-                           (append (find-files "src/lib/lib" "\\.so$")
-                                   (find-files "src/lib" "^ffi-test")))
+                           (append '("src/lib/shim-config.scm")
+                                   (find-files "src/lib/lib" "\\.so$")
+                                   (find-files "src/lib" "^liarc-")
+                                   (find-files "src/compiler" "^make\\.")))
                  (chdir "src")
                  #t)))
         (alist-replace
@@ -88,25 +99,31 @@
           (method url-fetch)
           (uri (string-append "mirror://gnu/mit-scheme/stable.pkg/"
                               version "/mit-scheme-"
-                              version "-"
                               (match (%current-system)
-                                ("x86_64-linux" "x86-64")
-                                ("i686-linux" "i386")
-                                (_ "c"))
+                                ("x86_64-linux"
+                                 (string-append version "-x86-64"))
+                                ("i686-linux"
+                                 (string-append version "-i386"))
+                                (_
+                                 (string-append "c-" version)))
                               ".tar.gz"))
           (sha256
            (match (%current-system)
              ("x86_64-linux"
               (base32
-               "1wcxm9hyfc53myvlcn93fyqrnnn4scwkknl9hkbp1cphc6mp291x"))
+               "1skzxxhr0iq96bf0j5m7mvf3i4sppfyfa6gpqn34mwgkw1fx8274"))
              ("i686-linux"
               (base32
-               "0vi760fy550d9db538m0vzbq1mpdncvw9g8bk4lswk0kcdira55z"))
+               "1fmlpnhf5a75db93phajh4ysbdgrgl72v45lk3kznriprl0a7jc6"))
              (_
               (base32
-               "0pclakzwxbqgy6wqwvs6ml62wgby8ba8xzmwzdwhx1v8wv05yw1j"))))))))
+               "0w5ib5vsidihb4hb6fma3sp596ykr8izagm57axvgd6lqzwicsjg"))))))))
+
+    ;; Fails to build on MIPS, see <http://bugs.gnu.org/18221>.
+    (supported-systems (delete "mips64el-linux" %supported-systems))
+
     (home-page "http://www.gnu.org/software/mit-scheme/")
-    (synopsis "Scheme implementation with integrated editor and debugger")
+    (synopsis "A Scheme implementation with integrated editor and debugger")
     (description
      "GNU/MIT Scheme is an implementation of the Scheme programming
 language.  It provides an interpreter, a compiler and a debugger.  It also
@@ -188,7 +205,7 @@ features an integrated Emacs-like editor and a large runtime library.")
     (propagated-inputs
      `(("gmp" ,gmp)))                             ; bigloo.h refers to gmp.h
     (home-page "http://www-sop.inria.fr/indes/fp/Bigloo/")
-    (synopsis "Bigloo, an efficient Scheme compiler")
+    (synopsis "Efficient Scheme compiler")
     (description
      "Bigloo is a Scheme implementation devoted to one goal: enabling
 Scheme based programming style where C(++) is usually
@@ -261,7 +278,7 @@ Scheme and C programs and between Scheme and Java programs.")
               ("which" ,which)
               ("patchelf" ,patchelf)))
     (home-page "http://hop.inria.fr/")
-    (synopsis "A multi-tier programming language for the Web 2.0")
+    (synopsis "Multi-tier programming language for the Web 2.0")
     (description
      "HOP is a multi-tier programming language for the Web 2.0 and the
 so-called diffuse Web.  It is designed for programming interactive web
@@ -273,14 +290,14 @@ mashups, office (web agendas, mail clients, ...), etc.")
 (define-public chicken
   (package
     (name "chicken")
-    (version "4.8.0.3")
+    (version "4.9.0.1")
     (source (origin
              (method url-fetch)
-             (uri (string-append "http://code.call-cc.org/releases/4.8.0/chicken-"
+             (uri (string-append "http://code.call-cc.org/releases/4.9.0/chicken-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "1hwrnc2dhgbnz3mlpcb4qvg76kwsfzqylw24gxyy91jmygk1853a"))))
+               "0598mar1qswfd8hva9nqs88zjn02lzkqd8fzdd21dz1nki1prpq4"))))
     (build-system gnu-build-system)
     (arguments
      `(#:modules ((guix build gnu-build-system)
@@ -405,4 +422,8 @@ implementation techniques and as an expository tool.")
 R6RS) and related languages, such as Typed Racket.  It features a compiler and
 a virtual machine with just-in-time native compilation, as well as a large set
 of libraries.")
-    (license lgpl2.0+)))
+    (license lgpl2.0+)
+
+    ;; Fails to build on MIPS with "address or size is not OS PAGE ALIGNED".
+    ;; See <http://hydra.gnu.org/build/121775>.
+    (supported-systems (delete "mips64el-linux" %supported-systems))))
