@@ -18,8 +18,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages ssh)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'license:))
+  #:use-module ((guix licenses) #:prefix license:)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages gnupg)
   #:use-module (gnu packages groff)
@@ -37,6 +36,7 @@
   #:use-module (gnu packages)
   #:use-module (guix packages)
   #:use-module (guix download)
+  #:use-module (guix git-download)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system cmake))
 
@@ -50,7 +50,17 @@
                                   version ".tar.xz"))
               (sha256
                (base32
-                "1jyaj9h1iglvn02hrvcchbx8ycjpj8b91h8mi459k7q5jp2xgd9b"))))
+                "1jyaj9h1iglvn02hrvcchbx8ycjpj8b91h8mi459k7q5jp2xgd9b"))
+              (patches
+               ;; Apply the patch as discussed at
+               ;; <http://lists.gnu.org/archive/html/guix-devel/2014-10/msg00180.html>.
+               (list (origin
+                       (uri
+                        "http://git.libssh.org/projects/libssh.git/patch/?id=a033b93c616f4a81afc3fc6a017396d507d96c19")
+                       (method url-fetch)
+                       (sha256
+                        (base32
+                         "16fdkjcnhc6j7qxz9575fzr9044927ws5259yh0xb9yv1q14j0vh")))))))
     (build-system cmake-build-system)
     (arguments
      '(#:configure-flags '("-DWITH_GCRYPT=ON")
@@ -101,10 +111,10 @@ remote applications.")
    (propagated-inputs `(("libgcrypt" ,libgcrypt)
                         ("zlib" ,zlib)))
    (arguments '(#:configure-flags `("--with-libgcrypt")))
-   (synopsis "libssh2, a client-side C library implementing the SSH2 protocol")
+   (synopsis "Client-side C library implementing the SSH2 protocol")
    (description
     "libssh2 is a library intended to allow software developers access to
-the SSH-2 protocol in an easy-to-use self-contained package. It can be built
+the SSH-2 protocol in an easy-to-use self-contained package.  It can be built
 into an application to perform many different tasks when communicating with
 a server that supports the SSH-2 protocol.")
    (license license:bsd-3)
@@ -113,7 +123,7 @@ a server that supports the SSH-2 protocol.")
 (define-public openssh
   (package
    (name "openssh")
-   (version "6.6p1")
+   (version "6.7p1")
    (source (origin
             (method url-fetch)
             (uri (let ((tail (string-append name "-" version ".tar.gz")))
@@ -122,7 +132,7 @@ a server that supports the SSH-2 protocol.")
                          (string-append "ftp://ftp2.fr.openbsd.org/pub/OpenBSD/OpenSSH/portable/"
                                         tail))))
             (sha256 (base32
-                     "1fq3w86q05y5nn6z878wm312k0svaprw8k007188fd259dkg1ha8"))))
+                     "01smf9pvn2sk5qs80gkmc9acj07ckawi1b3xxyysp3c5mr73ky5j"))))
    (build-system gnu-build-system)
    (inputs `(("groff" ,groff)
              ("openssl" ,openssl)
@@ -149,7 +159,7 @@ a server that supports the SSH-2 protocol.")
           ;; install without host keys and system configuration files
           (zero? (apply system* "make" "install-nosysconf" make-flags)))
        %standard-phases)))))
-   (synopsis "OpenSSH, a client and server for the secure shell (ssh) protocol")
+   (synopsis "Client and server for the secure shell (ssh) protocol")
    (description
     "The SSH2 protocol implemented in OpenSSH is standardised by the
 IETF secsh working group and is specified in several RFCs and drafts.
@@ -161,13 +171,13 @@ cryptographically secured connection: it provides integrity, confidentiality
 and optional compression.
 
 The user authentication layer uses the established connection and relies on
-the services provided by the transport layer. It provides several mechanisms
-for user authentication. These include traditional password authentication
+the services provided by the transport layer.  It provides several mechanisms
+for user authentication.  These include traditional password authentication
 as well as public-key or host-based authentication mechanisms.
 
 The connection layer multiplexes many different concurrent channels over the
 authenticated connection and allows tunneling of login sessions and
-TCP-forwarding. It provides a flow control service for these channels.
+TCP-forwarding.  It provides a flow control service for these channels.
 Additionally, various channel-specific options can be negotiated.")
    (license (license:bsd-style "file://LICENSE"
                                "See LICENSE in the distribution."))
@@ -176,25 +186,21 @@ Additionally, various channel-specific options can be negotiated.")
 (define-public guile-ssh
   (package
     (name "guile-ssh")
-    (version "0.6.0")
+    (version "0.7.1")
     (source (origin
-              (method url-fetch)
-              (uri (string-append
-                    "https://github.com/artyom-poptsov/libguile-ssh/archive/v"
-                    version ".tar.gz"))
+              (method git-fetch)
+              (uri (git-reference
+                    (url "https://github.com/artyom-poptsov/libguile-ssh.git")
+                    (commit "e216e1d78bf93a9753ea813f930cac5e68e52180")))
               (sha256
                (base32
-                "1v4y5vrwg0g6804pzbr160zahlqvj7k7iwys2bdpfzp7m2i47siq"))))
+                "1sbxhmynmpwfjwb3dp6lrc3cxi5kffqmb6klhx7wnkgqxvs61lsw"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases (alist-cons-before
                  'configure 'autoreconf
                  (lambda* (#:key inputs #:allow-other-keys)
-                   (substitute* "ssh/Makefile.am"
-                     (("-lssh_threads" match)
-                      (string-append "-L" (assoc-ref inputs "libssh")
-                                     "/lib " match)))
-
+                   (chmod "doc/version.texi" #o777) ;make it writable
                    (zero? (system* "autoreconf" "-vfi")))
                  (alist-cons-after
                   'install 'fix-libguile-ssh-file-name
@@ -216,9 +222,6 @@ Additionally, various channel-specific options can be negotiated.")
                                               (assoc-ref %outputs "out")
                                               "/share/guile/site/2.0"))
 
-       ;; Building the .go requires building libguile-ssh.so first.
-       #:parallel-build? #f
-
        ;; Tests are not parallel-safe.
        #:parallel-tests? #f))
     (native-inputs `(("autoconf" ,autoconf)
@@ -228,7 +231,8 @@ Additionally, various channel-specific options can be negotiated.")
                      ("pkg-config" ,pkg-config)
                      ("which" ,which)))
     (inputs `(("guile" ,guile-2.0)
-              ("libssh" ,libssh-0.5)))
+              ("libssh" ,libssh)
+              ("libgcrypt" ,libgcrypt-1.5)))
     (synopsis "Guile bindings to libssh")
     (description
      "Guile-SSH is a library that provides access to the SSH protocol for
@@ -272,7 +276,7 @@ libssh library.")
                           flags))))
         %standard-phases)))
     (home-page "http://www.agroman.net/corkscrew")
-    (synopsis "A tool for tunneling SSH through HTTP proxies")
+    (synopsis "Tunneling SSH through HTTP proxies")
     (description
      "Corkscrew allows creating TCP tunnels through HTTP proxies.  WARNING:
 At the moment only plain text authentication is supported, should you require
@@ -337,7 +341,7 @@ especially over Wi-Fi, cellular, and long-distance links.")
     (inputs `(("zlib" ,zlib)))
     (synopsis "Small SSH server and client")
     (description "Dropbear is a relatively small SSH server and
-client. It runs on a variety of POSIX-based platforms. Dropbear is
-particularly useful for embedded systems, such as wireless routers.")   
+client.  It runs on a variety of POSIX-based platforms.  Dropbear is
+particularly useful for embedded systems, such as wireless routers.")
     (home-page "https://matt.ucc.asn.au/dropbear/dropbear.html")
     (license (license:x11-style "" "See file LICENSE."))))
