@@ -44,7 +44,7 @@
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages python)
-  #:use-module (gnu packages sqlite)
+  #:use-module (gnu packages databases)
   #:use-module (gnu packages admin)
   #:use-module (gnu packages xml)
   #:use-module (gnu packages emacs)
@@ -56,15 +56,15 @@
 (define-public bazaar
   (package
     (name "bazaar")
-    (version "2.5.1")
+    (version "2.6.0")
     (source
      (origin
       (method url-fetch)
-      (uri (string-append "https://launchpad.net/bzr/2.5/" version
+      (uri (string-append "https://launchpad.net/bzr/2.6/" version
                           "/+download/bzr-" version ".tar.gz"))
       (sha256
        (base32
-        "10krjbzia2avn09p0cdlbx2wya0r5v11w5ymvyl72af5dkx4cwwn"))))
+        "1c6sj77h5f97qimjc14kr532kgc0jk3wq778xrkqi0pbh9qpk509"))))
     (build-system python-build-system)
     (inputs
      ;; Note: 'tools/packaging/lp-upload-release' and 'tools/weavemerge.sh'
@@ -84,21 +84,21 @@
     (synopsis "Version control system supporting both distributed and centralized workflows")
     (description
      "GNU Bazaar is a version control system that allows you to record
-changes to project files over time. It supports both a distributed workflow
+changes to project files over time.  It supports both a distributed workflow
 as well as the classic centralized workflow.")
     (license gpl2+)))
 
 (define-public git
   (package
    (name "git")
-   (version "1.8.4")
+   (version "2.1.2")
    (source (origin
             (method url-fetch)
-            (uri (string-append "http://git-core.googlecode.com/files/git-"
-                                version ".tar.gz"))
+            (uri (string-append "mirror://kernel.org/software/scm/git/git-"
+                                version ".tar.xz"))
             (sha256
              (base32
-              "156bwqqgaw65rsvbb4wih5jfg94bxyf6p16mdwf0ky3f4ln55s2i"))))
+              "12x1qycc0rii6fqpiizp9v9ysdmj6lpi9imqqbrkdx6cifbwh9vv"))))
    (build-system gnu-build-system)
    (native-inputs
     `(("native-perl" ,perl)
@@ -294,14 +294,14 @@ property manipulation.")
 (define-public subversion
   (package
     (name "subversion")
-    (version "1.7.14")
+    (version "1.7.18")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://archive.apache.org/dist/subversion/subversion-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "038jbcpwm083abp0rvk0fhnx65kp9mz1qvzs3f83ig8fxcvqzb64"))))
+               "06nrqnn3qq1hhskkcdbm0ilk2xv6ay2gyf2c7qvxp6xncb782wzn"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases (alist-cons-after
@@ -337,7 +337,7 @@ property manipulation.")
         ("sqlite" ,sqlite)
         ("zlib" ,zlib)))
     (home-page "http://subversion.apache.org/")
-    (synopsis "Subversion, a revision control system")
+    (synopsis "Revision control system")
     (description
      "Subversion exists to be universally recognized and adopted as a
 centralized version control system characterized by its
@@ -349,14 +349,14 @@ projects, from individuals to large-scale enterprise operations.")
 (define-public rcs
   (package
     (name "rcs")
-    (version "5.9.2")
+    (version "5.9.3")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/rcs/rcs-"
                                  version ".tar.xz"))
              (sha256
               (base32
-               "0wdmmplga9k05d9k7wjqv4zb6xvvzsli8hmn206pvangki1g66k5"))))
+               "0isvzwfvqkg7zcsznra6wqh650z49ib113n7gp6ncxv5p30x3c38"))))
     (build-system gnu-build-system)
     (native-inputs `(("ed" ,ed)))
     (home-page "http://www.gnu.org/software/rcs/")
@@ -438,7 +438,7 @@ standards-compliant ChangeLog entries based on the changes that it detects.")
     (home-page "http://invisible-island.net/diffstat/")
     (synopsis "Make histograms from the output of 'diff'")
     (description
-     "diffstat reads the output of 'diff' and displays a histogram of the
+     "Diffstat reads the output of 'diff' and displays a histogram of the
 insertions, deletions, and modifications per-file.  It is useful for reviewing
 large, complex patch files.")
     (license (x11-style "file://COPYING"))))
@@ -507,7 +507,7 @@ accessed and migrated on modern systems.")
     (inputs
      `(("e2fsprogs" ,e2fsprogs)
        ("curl" ,curl)
-       ("file" ,file)
+       ("file" ,file-5.20)                        ;work around CVE-2014-3710
        ("libxml2" ,libxml2)
        ("zlib" ,zlib)
        ("gettext" ,gnu-gettext)))
@@ -563,10 +563,10 @@ accessed and migrated on modern systems.")
     (home-page "http://aegis.sourceforge.net")
     (synopsis "Project change supervisor")
     (description "Aegis is a project change supervisor, and performs some of
-the Software Configuration Management needed in a CASE environment. Aegis
+the Software Configuration Management needed in a CASE environment.  Aegis
 provides a framework within which a team of developers may work on many
 changes to a program independently, and Aegis coordinates integrating these
 changes back into the master source of the program, with as little disruption
-as possible. Resolution of contention for source files, a major headache for
+as possible.  Resolution of contention for source files, a major headache for
 any project with more than one developer, is one of Aegis's major functions.")
     (license gpl3+)))
