@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013, 2014 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014 David Thompson <davet@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -18,6 +19,7 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages video)
+  #:use-module (ice-9 match)
   #:use-module ((guix licenses)
                 #:select (gpl2 gpl2+ bsd-3 public-domain))
   #:use-module (guix packages)
@@ -56,14 +58,14 @@
 (define-public ffmpeg
   (package
     (name "ffmpeg")
-    (version "2.3")
+    (version "2.4.3")
     (source (origin
              (method url-fetch)
              (uri (string-append "http://www.ffmpeg.org/releases/ffmpeg-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "17l0bx95al6cjhz3pzfcbwg07sbfbwqbxg34zl5lhl89w9jbngbb"))))
+               "00p6qi7kwc2rv7h98bczrdssa7nbda3fpz7avjwl77jg1qy3wp6a"))))
     (build-system gnu-build-system)
     (inputs
      `(("fontconfig" ,fontconfig)
@@ -168,31 +170,11 @@
                       "--enable-libtheora"
                       "--enable-libvorbis"
                       "--enable-libvpx"
-                      ;; drop special machine instructions not supported
-                      ;; on all instances of the target
-                      ,@(if (string-prefix? "x86_64"
-                                            (or (%current-target-system)
-                                                (%current-system)))
-                            '()
-                            '("--disable-amd3dnow"
-                              "--disable-amd3dnowext"
-                              "--disable-mmx"
-                              "--disable-mmxext"
-                              "--disable-sse"
-                              "--disable-sse2"))
-                      "--disable-altivec"
-                      "--disable-sse3"
-                      "--disable-ssse3"
-                      "--disable-sse4"
-                      "--disable-sse42"
-                      "--disable-avx"
-                      "--disable-fma4"
-                      "--disable-avx2"
-                      "--disable-armv5te"
-                      "--disable-armv6"
-                      "--disable-armv6t2"
-                      "--disable-vfp"
-                      "--disable-neon"
+
+                      "--enable-runtime-cpudetect"
+
+                      ;; Runtime cpu detection is not implemented on
+                      ;; MIPS, so we disable some features.
                       "--disable-mips32r2"
                       "--disable-mipsdspr1"
                       "--disable-mipsdspr2"
@@ -214,10 +196,22 @@ convert and stream audio and video.  It includes the libavcodec
 audio/video codec library.")
     (license gpl2+)))
 
+;; We need this older ffmpeg because vlc-2.1.5 doesn't work with ffmpeg-2.4.
+(define-public ffmpeg-2.2
+  (package (inherit ffmpeg)
+    (version "2.2.10")
+    (source (origin
+             (method url-fetch)
+             (uri (string-append "http://www.ffmpeg.org/releases/ffmpeg-"
+                                 version ".tar.bz2"))
+             (sha256
+              (base32
+               "14d83ijp5lxdr6nl9rqhc4598jp020paxrg64r9ifxqhbigl0yqm"))))))
+
 (define-public vlc
   (package
     (name "vlc")
-    (version "2.1.4")
+    (version "2.1.5")
     (source (origin
              (method url-fetch)
              (uri (string-append
@@ -225,7 +219,7 @@ audio/video codec library.")
                    version "/vlc-" version ".tar.xz"))
              (sha256
               (base32
-               "1lymhbb2bns73qivdaqanhggjjhyc9fwfgf5ikhng0a74msnqmiy"))))
+               "0whzbn7ahn5maarcwl1yhk9lq10b0q0y9w5pjl9kh3frdjmncrbg"))))
     (build-system gnu-build-system)
     (native-inputs
      `(("git" ,git) ; needed for a test
@@ -236,7 +230,7 @@ audio/video codec library.")
        ("avahi" ,avahi)
        ("dbus" ,dbus)
        ("flac" ,flac)
-       ("ffmpeg" ,ffmpeg)
+       ("ffmpeg" ,ffmpeg-2.2)     ; FIXME: vlc-2.1.5 won't work with ffmpeg-2.4
        ("fontconfig" ,fontconfig)
        ("freetype" ,freetype)
        ("gnutls" ,gnutls)
@@ -268,10 +262,6 @@ audio/video codec library.")
     (arguments
      `(#:configure-flags
        `("--disable-a52" ; FIXME: reenable once available
-         "--disable-mmx" ; FIXME: may be enabled on x86_64
-         "--disable-sse" ; 1-4, no separate options available
-         "--disable-neon"
-         "--disable-altivec"
          ,(string-append "LDFLAGS=-Wl,-rpath -Wl,"
                          (assoc-ref %build-inputs "ffmpeg")
                          "/lib")))) ; needed for the tests
@@ -342,20 +332,18 @@ treaming protocols.")
                                      libx11 "/include") ; to detect libx11
                       "--disable-tremor-internal" ; forces external libvorbis
                       (string-append "--prefix=" out)
-                      ;; drop special machine instructions not supported
-                      ;; on all instances of the target
-                      ,@(if (string-prefix? "x86_64"
-                                            (or (%current-target-system)
-                                                (%current-system)))
-                            '()
-                            '("--disable-3dnow"
-                              "--disable-3dnowext"
-                              "--disable-mmx"
-                              "--disable-mmxext"
-                              "--disable-sse"
-                              "--disable-sse2"))
-                      "--disable-ssse3"
-                      "--disable-altivec"
+                      ;; Enable runtime cpu detection where supported,
+                      ;; and choose a suitable target.
+                      ,@(match (or (%current-target-system)
+                                   (%current-system))
+                          ("x86_64-linux"
+                           '("--enable-runtime-cpudetection"
+                             "--target=x86_64-linux"))
+                          ("i686-linux"
+                           '("--enable-runtime-cpudetection"
+                             "--target=i686-linux"))
+                          ("mips64el-linux"
+                           '("--target=mips3-linux")))
                       "--disable-armv5te"
                       "--disable-armv6"
                       "--disable-armv6t2"
@@ -407,7 +395,7 @@ SVCD, DVD, 3ivx, DivX 3/4/5, WMV and H.264 movies.")
 (define-public youtube-dl
   (package
     (name "youtube-dl")
-    (version "2014.06.26")
+    (version "2014.09.06")
     (source (origin
               (method url-fetch)
               (uri (string-append "http://youtube-dl.org/downloads/"
@@ -415,7 +403,7 @@ SVCD, DVD, 3ivx, DivX 3/4/5, WMV and H.264 movies.")
                                   version ".tar.gz"))
               (sha256
                (base32
-                "0jl90plg9mz4mwich219a58y4npwi33myx0cx44v8pymkqykv5cd"))))
+                "1a50vqgzp9wjh2763shald6dlmdd5qlqy83vg4yrihdrlh8sk6dd"))))
     (build-system python-build-system)
     (inputs `(("setuptools" ,python-setuptools)))
     (home-page "http://youtube-dl.org")
