@@ -19,21 +19,25 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages web)
-  #:use-module ((guix licenses)
-                #:renamer (symbol-prefix-proc 'l:))
+  #:use-module ((guix licenses) #:prefix l:)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix git-download)
-  #:use-module (guix build-system perl)
   #:use-module (guix build-system gnu)
+  #:use-module (guix build-system perl)
+  #:use-module (guix build-system cmake)
   #:use-module (gnu packages apr)
   #:use-module (gnu packages asciidoc)
   #:use-module (gnu packages docbook)
   #:use-module (gnu packages autotools)
   #:use-module ((gnu packages compression) #:select (zlib))
   #:use-module (gnu packages openssl)
+  #:use-module (gnu packages gettext)
+  #:use-module (gnu packages icu4c)
+  #:use-module (gnu packages which)
   #:use-module (gnu packages pcre)
   #:use-module (gnu packages xml)
+  #:use-module (gnu packages curl)
   #:use-module (gnu packages perl))
 
 (define-public httpd
@@ -66,10 +70,10 @@
     (description
      "The Apache HTTP Server Project is a collaborative software development
 effort aimed at creating a robust, commercial-grade, featureful, and
-freely-available source code implementation of an HTTP (Web) server. The project
-is jointly managed by a group of volunteers located around the world, using the
-Internet and the Web to communicate, plan, and develop the server and its
-related documentation.")
+freely-available source code implementation of an HTTP (Web) server.  The
+project is jointly managed by a group of volunteers located around the world,
+using the Internet and the Web to communicate, plan, and develop the server
+and its related documentation.")
     (license l:asl2.0)
     (home-page "https://httpd.apache.org/")))
 
@@ -110,7 +114,7 @@ parse JSON formatted strings back into the C representation of JSON objects.")
 (define-public libwebsockets
   (package
     (name "libwebsockets")
-    (version "1.2")
+    (version "1.3")
     (source (origin
               ;; The project does not publish tarballs, so we have to take
               ;; things from Git.
@@ -118,34 +122,24 @@ parse JSON formatted strings back into the C representation of JSON objects.")
               (uri (git-reference
                     (url "git://git.libwebsockets.org/libwebsockets")
                     (commit (string-append "v" version
-                                           "-chrome26-firefox18"))))
+                                           "-chrome37-firefox30"))))
               (sha256
                (base32
-                "1293hbz8qj4p27m1qjf8dn97r10xjyiwdpq491m87zi025s558cl"))
+                "12fqh2d2098mgf0ls19p9lzibpsqhv7mc5rn1yvrbfnazmcr40g4"))
               (file-name (string-append name "-" version))))
 
-    ;; The package has both CMake and GNU build systems, but the latter is
-    ;; apparently better supported (CMake-generated makefiles lack an
-    ;; 'install' target, for instance.)
-    (build-system gnu-build-system)
-
+    (build-system cmake-build-system)
     (arguments
-     '(#:phases (alist-cons-before
-                 'configure 'bootstrap
-                 (lambda _
-                   (chmod "libwebsockets-api-doc.html" #o666)
-                   (zero? (system* "./autogen.sh")))
-                 %standard-phases)))
+     ;; XXX: The thing lacks a 'make test' target, because CMakeLists.txt
+     ;; doesn't use 'add_test', and it's unclear how to run the test suite.
+     '(#:tests? #f))
 
-    (native-inputs `(("autoconf" ,autoconf)
-                     ("automake" ,automake)
-                     ("libtool" ,libtool "bin")
-                     ("perl" ,perl)))             ; to build the HTML doc
+    (native-inputs `(("perl" ,perl)))             ; to build the HTML doc
     (inputs `(("zlib" ,zlib)
               ("openssl" ,openssl)))
     (synopsis "WebSockets library written in C")
     (description
-     "libwebsockets is a library that allows C programs to establish client
+     "Libwebsockets is a library that allows C programs to establish client
 and server WebSockets connections---a protocol layered above HTTP that allows
 for efficient socket-like bidirectional reliable communication channels.")
     (home-page "http://libwebsockets.org/")
@@ -153,6 +147,59 @@ for efficient socket-like bidirectional reliable communication channels.")
     ;; This is LGPLv2.1-only with extra exceptions specified in 'LICENSE'.
     (license l:lgpl2.1)))
 
+(define-public libpsl
+  (package
+    (name "libpsl")
+    (version "0.6.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://github.com/rockdaboot/libpsl/"
+                                  "archive/" version ".tar.gz"))
+              (sha256
+               (base32
+                "10s7xxxx6pp4ydp3san69sa6q379ih3pv92fyi565ggmlw8igv7a"))
+              (file-name (string-append name "-" version ".tar.gz"))))
+    (build-system gnu-build-system)
+    (inputs `(("icu4c" ,icu4c)))
+    ;; The release tarball lacks the generated files.
+    (native-inputs `(("autoconf" ,autoconf)
+                     ("automake" ,automake)
+                     ("gettext"  ,gnu-gettext)
+                     ("which"    ,which)
+                     ("libtool"  ,libtool)
+                     ("libtool"  ,libtool "bin")))
+    (arguments
+     `(#:phases (alist-cons-before
+                 'bootstrap 'fix-autogen-shebang
+                 (lambda _
+                   (substitute* "autogen.sh"
+                     ;; Removing -e as it causes the whole script to fail when
+                     ;; `which gtkdocize` fails.
+                     (("# !/bin/sh -e") (string-append "#!" (which "sh")))))
+                 (alist-cons-before
+                  'patch-usr-bin-file 'bootstrap
+                  (lambda _
+                    (zero? (system* "./autogen.sh")))
+                  %standard-phases))))
+    (home-page "https://github.com/rockdaboot/libpsl")
+    (synopsis "C library for the Publix Suffix List")
+    (description
+     "A \"public suffix\" is a domain name under which Internet users can
+directly register own names.
+
+Browsers and other web clients can use it to avoid privacy-leaking
+\"supercookies\", avoid privacy-leaking \"super domain\" certificates, domain
+highlighting parts of the domain in a user interface, and sorting domain lists
+by site.
+
+Libpsl has built-in PSL data for fast access, allows to load PSL data from
+files, checks if a given domain is a public suffix, provides immediate cookie
+domain verification, finds the longest public part of a given domain, finds
+the shortest private part of a given domain, works with international
+domains (UTF-8 and IDNA2008 Punycode), is thread-safe, and handles IDNA2008
+UTS#46")
+    (license l:x11)))
+
 (define-public perl-html-tagset
   (package
     (name "perl-html-tagset")
@@ -502,8 +549,8 @@ Encode::decode(locale => $string).")
      "The libwww-perl collection is a set of Perl modules which provides a
 simple and consistent application programming interface to the
 World-Wide Web.  The main focus of the library is to provide classes
-and functions that allow you to write WWW clients. The library also
-contain modules that are of more general use and even classes that
+and functions that allow you to write WWW clients.  The library also
+contains modules that are of more general use and even classes that
 help you implement simple HTTP servers.")
     (home-page "http://search.cpan.org/~gaas/libwww-perl/")))
 
@@ -514,7 +561,8 @@ help you implement simple HTTP servers.")
     (source (origin
               (method url-fetch)
               (uri (string-append
-                    "http://www.samba.org/~obnox/" name "/download/" name "-" version ".tar.bz2"))
+                    "http://www.samba.org/~obnox/" name "/download/"
+                    name "-" version ".tar.bz2"))
               (sha256
                (base32
                 "0vl9igw7vm924rs6d6bkib7zfclxnlf9s8rmml1sfwj7xda9nmdy"))))
@@ -552,8 +600,54 @@ help you implement simple HTTP servers.")
     (home-page "https://banu.com/tinyproxy/")
     (synopsis "Light-weight HTTP/HTTPS proxy daemon")
     (description "Tinyproxy is a light-weight HTTP/HTTPS proxy
-daemon. Designed from the ground up to be fast and yet small, it is an ideal
+daemon.  Designed from the ground up to be fast and yet small, it is an ideal
 solution for use cases such as embedded deployments where a full featured HTTP
 proxy is required, but the system resources for a larger proxy are
-unavailable.") 
+unavailable.")
     (license l:gpl2+)))
+
+(define-public perl-www-curl
+  (package
+    (name "perl-www-curl")
+    (version "4.17")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "mirror://cpan/authors/id/S/SZ/SZBALINT/WWW-Curl-"
+                    version".tar.gz"))
+              (sha256
+               (base32
+                "1fmp9aib1kaps9vhs4dwxn7b15kgnlz9f714bxvqsd1j1q8spzsj"))))
+    (build-system perl-build-system)
+    (arguments
+     '(#:tests? #f))                        ;XXX: tests require network access
+    (inputs `(("curl" ,curl)))
+    (synopsis "Perl extension interface for libcurl")
+    (description
+     "This is a Perl extension interface for the libcurl file downloading
+library.")
+    (license (package-license perl))
+    (home-page "http://search.cpan.org/~szbalint/WWW-Curl-4.17/lib/WWW/Curl.pm")))
+
+(define-public perl-io-socket-ssl
+  (package
+    (name "perl-io-socket-ssl")
+    (version "2.002")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://cpan/authors/id/S/SU/SULLR/"
+                                  "IO-Socket-SSL-" version ".tar.gz"))
+              (sha256
+               (base32
+                "1mph52lw6x5v44wf8mw00llzi8pp6k5c4jnrnrvlacrlfv260jb8"))))
+    (build-system perl-build-system)
+    (propagated-inputs `(("perl-net-ssleay" ,perl-net-ssleay)))
+    (synopsis "Nearly transparent SSL encapsulation for IO::Socket::INET")
+    (description
+     "IO::Socket::SSL makes using SSL/TLS much easier by wrapping the
+necessary functionality into the familiar IO::Socket interface and providing
+secure defaults whenever possible.  This way existing applications can be made
+SSL-aware without much effort, at least if you do blocking I/O and don't use
+select or poll.")
+    (license (package-license perl))
+    (home-page "https://github.com/noxxi/p5-io-socket-ssl")))
