@@ -38,10 +38,7 @@
     (home-page "https://gnu.org/software/which/")
     (synopsis "Find full path of shell commands")
     (description
-     "GNU Which takes one or more arguments. For each of its arguments
-it prints to stdout the full path of the executables that would have
-been executed when this argument had been entered at the shell
-prompt. It does this by searching for an executable or script in the
-directories listed in the environment variable PATH using the same
-algorithm as bash(1).")
+     "The which program finds the location of executables in PATH, with a
+variety of options.  It is an alternative to the shell \"type\" built-in
+command.")
     (license gpl3+))) ; some files are under GPLv2+
