@@ -25,11 +25,11 @@
   #:use-module (gnu system linux)                 ; 'pam-service', etc.
   #:use-module (gnu packages admin)
   #:use-module ((gnu packages linux)
-                #:select (udev kbd e2fsprogs))
+                #:select (eudev kbd e2fsprogs lvm2 fuse alsa-utils))
   #:use-module ((gnu packages base)
-                #:select (glibc-final))
+                #:select (canonical-package glibc))
   #:use-module (gnu packages package-management)
-  #:use-module ((guix build linux-initrd)
+  #:use-module ((gnu build file-systems)
                 #:select (mount-flags->bit-mask))
   #:use-module (guix gexp)
   #:use-module (guix monads)
@@ -38,6 +38,9 @@
   #:use-module (ice-9 format)
   #:export (root-file-system-service
             file-system-service
+            user-unmount-service
+            device-mapping-service
+            swap-service
             user-processes-service
             host-name-service
             console-font-service
@@ -99,18 +102,20 @@ This service must be the root of the service dependency graph so that its
 
 (define* (file-system-service device target type
                               #:key (flags '()) (check? #t)
-                              create-mount-point? options (title 'any))
+                              create-mount-point? options (title 'any)
+                              (requirements '()))
   "Return a service that mounts DEVICE on TARGET as a file system TYPE with
 OPTIONS.  TITLE is a symbol specifying what kind of name DEVICE is: 'label for
 a partition label, 'device for a device file name, or 'any.  When CHECK? is
 true, check the file system before mounting it.  When CREATE-MOUNT-POINT? is
 true, create TARGET if it does not exist yet.  FLAGS is a list of symbols,
-such as 'read-only' etc."
+such as 'read-only' etc.  Optionally, REQUIREMENTS may be a list of service
+names such as device-mapping services."
   (with-monad %store-monad
     (return
      (service
       (provision (list (symbol-append 'file-system- (string->symbol target))))
-      (requirement '(root-file-system))
+      (requirement `(root-file-system ,@requirements))
       (documentation "Check, mount, and unmount the given file system.")
       (start #~(lambda args
                  (let ((device (canonicalize-device-spec #$device '#$title)))
@@ -134,15 +139,49 @@ such as 'read-only' etc."
       (stop #~(lambda args
                 ;; Normally there are no processes left at this point, so
                 ;; TARGET can be safely unmounted.
+
+                ;; Make sure PID 1 doesn't keep TARGET busy.
+                (chdir "/")
+
                 (umount #$target)
                 #f))))))
 
+(define (user-unmount-service known-mount-points)
+  "Return a service whose sole purpose is to unmount file systems not listed
+in KNOWN-MOUNT-POINTS when it is stopped."
+  (with-monad %store-monad
+    (return
+     (service
+      (documentation "Unmount manually-mounted file systems.")
+      (provision '(user-unmount))
+      (start #~(const #t))
+      (stop #~(lambda args
+                (define (known? mount-point)
+                  (member mount-point
+                          (cons* "/proc" "/sys"
+                                 '#$known-mount-points)))
+
+                ;; Make sure we don't keep the user's mount points busy.
+                (chdir "/")
+
+                (for-each (lambda (mount-point)
+                            (format #t "unmounting '~a'...~%" mount-point)
+                            (catch 'system-error
+                              (lambda ()
+                                (umount mount-point))
+                              (lambda args
+                                (let ((errno (system-error-errno args)))
+                                  (format #t "failed to unmount '~a': ~a~%"
+                                          mount-point (strerror errno))))))
+                          (filter (negate known?) (mount-points)))
+                #f))))))
+
 (define %do-not-kill-file
   ;; Name of the file listing PIDs of processes that must survive when halting
   ;; the system.  Typical example is user-space file systems.
   "/etc/dmd/do-not-kill")
 
-(define* (user-processes-service requirements #:key (grace-delay 2))
+(define* (user-processes-service requirements #:key (grace-delay 5))
   "Return the service that is responsible for terminating all the processes so
 that the root file system can be re-mounted read-only, just before
 rebooting/halting.  Processes still running GRACE-DELAY seconds after SIGTERM
@@ -179,6 +218,8 @@ stopped before 'kill' is called."
                                              (@ (ice-9 rdelim) read-string))))
                              '()))
 
+                       (define lset= (@ (srfi srfi-1) lset=))
+
                        ;; When this happens, all the processes have been
                        ;; killed, including 'deco', so DMD-OUTPUT-PORT and
                        ;; thus CURRENT-OUTPUT-PORT are dangling.
@@ -203,6 +244,15 @@ stopped before 'kill' is called."
                              (kill-except omitted-pids SIGKILL)
                              (delete-file #$%do-not-kill-file)))
 
+                       (let wait ()
+                         (let ((pids (processes)))
+                           (unless (lset= = pids (cons 1 omitted-pids))
+                             (format #t "waiting for process termination\
+ (processes left: ~s)~%"
+                                     pids)
+                             (sleep 2)
+                             (wait))))
+
                        (display "all processes have been terminated\n")
                        #f))
              (respawn? #f)))))
@@ -324,7 +374,7 @@ the ``message of the day''."
                                #:allow-empty-passwords? allow-empty-passwords?
                                #:motd motd)))))))
 
-(define* (nscd-service #:key (glibc glibc-final))
+(define* (nscd-service #:key (glibc (canonical-package glibc)))
   "Return a service that runs libc's name service cache daemon (nscd)."
   (with-monad %store-monad
     (return (service
@@ -399,7 +449,7 @@ starting at FIRST-UID, and under GID."
                        ;; guix-daemon expects GROUP to be listed as a
                        ;; supplementary group too:
                        ;; <http://lists.gnu.org/archive/html/bug-guix/2013-01/msg00239.html>.
-                       (supplementary-groups (list group))
+                       (supplementary-groups (list group "kvm"))
 
                        (comment (format #f "Guix Build User ~2d" n))
                        (home-directory "/var/empty")
@@ -479,9 +529,65 @@ passed to @command{guix-daemon}."
                                  (id 30000))))
              (activate activate)))))
 
-(define* (udev-service #:key (udev udev))
-  "Run @var{udev}, which populates the @file{/dev} directory dynamically."
-  (with-monad %store-monad
+(define (udev-rules-union packages)
+  "Return the union of the @code{lib/udev/rules.d} directories found in each
+item of @var{packages}."
+  (define build
+    #~(begin
+        (use-modules (guix build union)
+                     (guix build utils)
+                     (srfi srfi-1)
+                     (srfi srfi-26))
+
+        (define %standard-locations
+          '("/lib/udev/rules.d" "/libexec/udev/rules.d"))
+
+        (define (rules-sub-directory directory)
+          ;; Return the sub-directory of DIRECTORY containing udev rules, or
+          ;; #f if none was found.
+          (find directory-exists?
+                (map (cut string-append directory <>) %standard-locations)))
+
+        (mkdir-p (string-append #$output "/lib/udev"))
+        (union-build (string-append #$output "/lib/udev/rules.d")
+                     (filter-map rules-sub-directory '#$packages))))
+
+  (gexp->derivation "udev-rules" build
+                    #:modules '((guix build union)
+                                (guix build utils))
+                    #:local-build? #t))
+
+(define* (kvm-udev-rule)
+  "Return a directory with a udev rule that changes the group of
+@file{/dev/kvm} to \"kvm\" and makes it #o660."
+  ;; Apparently QEMU-KVM used to ship this rule, but now we have to add it by
+  ;; ourselves.
+  (gexp->derivation "kvm-udev-rules"
+                    #~(begin
+                        (use-modules (guix build utils))
+
+                        (define rules.d
+                          (string-append #$output "/lib/udev/rules.d"))
+
+                        (mkdir-p rules.d)
+                        (call-with-output-file
+                            (string-append rules.d "/90-kvm.rules")
+                          (lambda (port)
+                            ;; FIXME: As a workaround for
+                            ;; <http://bugs.gnu.org/18994>, make /dev/kvm 666
+                            ;; instead of 660.
+                            (display "\
+KERNEL==\"kvm\", GROUP=\"kvm\", MODE=\"0666\"\n" port))))
+                    #:modules '((guix build utils))))
+
+(define* (udev-service #:key (udev eudev) (rules '()))
+  "Run @var{udev}, which populates the @file{/dev} directory dynamically.  Get
+extra rules from the packages listed in @var{rules}."
+  (mlet* %store-monad ((kvm       (kvm-udev-rule))
+                       (rules     (udev-rules-union (cons* udev kvm rules)))
+                       (udev.conf (text-file* "udev.conf"
+                                              "udev_rules=\"" rules
+                                              "/lib/udev/rules.d\"\n")))
     (return (service
              (provision '(udev))
 
@@ -492,8 +598,16 @@ passed to @command{guix-daemon}."
 
              (documentation "Populate the /dev directory, dynamically.")
              (start #~(lambda ()
+                        (define find
+                          (@ (srfi srfi-1) find))
+
                         (define udevd
-                          (string-append #$udev "/libexec/udev/udevd"))
+                          ;; Choose the right 'udevd'.
+                          (find file-exists?
+                                (map (lambda (suffix)
+                                       (string-append #$udev suffix))
+                                     '("/libexec/udev/udevd" ;udev
+                                       "/sbin/udevd"))))     ;eudev
 
                         (define (wait-for-udevd)
                           ;; Wait until someone's listening on udevd's control
@@ -513,6 +627,11 @@ passed to @command{guix-daemon}."
                         (setenv "LINUX_MODULE_DIRECTORY"
                                 "/run/booted-system/kernel/lib/modules")
 
+                        ;; The first one is for udev, the second one for eudev.
+                        (setenv "UDEV_CONFIG_FILE" #$udev.conf)
+                        (setenv "EUDEV_RULES_DIRECTORY"
+                                (string-append #$rules "/lib/udev/rules.d"))
+
                         (let ((pid (primitive-fork)))
                           (case pid
                             ((0)
@@ -531,7 +650,47 @@ passed to @command{guix-daemon}."
                              (system* (string-append #$udev "/bin/udevadm")
                                       "settle")
                              pid)))))
-             (stop #~(make-kill-destructor))))))
+             (stop #~(make-kill-destructor))
+
+             ;; When halting the system, 'udev' is actually killed by
+             ;; 'user-processes', i.e., before its own 'stop' method was
+             ;; called.  Thus, make sure it is not respawned.
+             (respawn? #f)))))
+
+(define (device-mapping-service target open close)
+  "Return a service that maps device @var{target}, a string such as
+@code{\"home\"} (meaning @code{/dev/mapper/home}).  Evaluate @var{open}, a
+gexp, to open it, and evaluate @var{close} to close it."
+  (with-monad %store-monad
+    (return (service
+             (provision (list (symbol-append 'device-mapping-
+                                             (string->symbol target))))
+             (requirement '(udev))
+             (documentation "Map a device node using Linux's device mapper.")
+             (start #~(lambda () #$open))
+             (stop #~(lambda _ (not #$close)))
+             (respawn? #f)))))
+
+(define (swap-service device)
+  "Return a service that uses @var{device} as a swap device."
+  (define requirement
+    (if (string-prefix? "/dev/mapper/" device)
+        (list (symbol-append 'device-mapping-
+                             (string->symbol (basename device))))
+        '()))
+
+  (with-monad %store-monad
+    (return (service
+             (provision (list (symbol-append 'swap- (string->symbol device))))
+             (requirement `(udev ,@requirement))
+             (documentation "Enable the given swap device.")
+             (start #~(lambda ()
+                        (swapon #$device)
+                        #t))
+             (stop #~(lambda _
+                       (swapoff #$device)
+                       #f))
+             (respawn? #f)))))
 
 (define %base-services
   ;; Convenience variable holding the basic services.
@@ -555,6 +714,10 @@ This is the GNU operating system, welcome!\n\n")))
           (syslog-service)
           (guix-service)
           (nscd-service)
-          (udev-service))))
+
+          ;; The LVM2 rules are needed as soon as LVM2 or the device-mapper is
+          ;; used, so enable them by default.  The FUSE and ALSA rules are
+          ;; less critical, but handy.
+          (udev-service #:rules (list lvm2 fuse alsa-utils)))))
 
 ;;; base.scm ends here
