@@ -95,6 +95,7 @@
           (system-group (name "tty") (id %tty-gid))
           (system-group (name "dialout"))
           (system-group (name "kmem"))
+          (system-group (name "input"))              ; input devices, from udev
           (system-group (name "video"))
           (system-group (name "audio"))
           (system-group (name "netdev"))             ; used in avahi-dbus.conf
@@ -102,7 +103,8 @@
           (system-group (name "disk"))
           (system-group (name "floppy"))
           (system-group (name "cdrom"))
-          (system-group (name "tape")))))
+          (system-group (name "tape"))
+          (system-group (name "kvm")))))             ; for /dev/kvm
 
 (define (default-skeletons)
   "Return the default skeleton files for /etc/skel.  These files are copied by
