@@ -23,11 +23,11 @@
   #:use-module (guix derivations)
   #:use-module (guix packages)
   #:use-module (guix monads)
-  #:use-module ((guix build vm)
+  #:use-module ((gnu build vm)
                 #:select (qemu-command))
-  #:use-module ((gnu packages base)
-                #:select (%final-inputs))
+  #:use-module (gnu packages base)
   #:use-module (gnu packages guile)
+  #:use-module (gnu packages gawk)
   #:use-module (gnu packages bash)
   #:use-module (gnu packages less)
   #:use-module (gnu packages qemu)
@@ -66,26 +66,6 @@
 ;;;
 ;;; Code:
 
-(define* (input->name+output tuple #:key (system (%current-system)))
-  "Return as a monadic value a name/file-name pair corresponding to TUPLE, an
-input tuple.  The output file name is when building for SYSTEM."
-  (with-monad %store-monad
-    (match tuple
-      ((input (? package? package))
-       (mlet %store-monad ((out (package-file package #:system system)))
-         (return `(,input . ,out))))
-      ((input (? package? package) sub-drv)
-       (mlet %store-monad ((out (package-file package
-                                              #:output sub-drv
-                                              #:system system)))
-         (return `(,input . ,out))))
-      ((input (? derivation? drv))
-       (return `(,input . ,(derivation->output-path drv))))
-      ((input (? derivation? drv) sub-drv)
-       (return `(,input . ,(derivation->output-path drv sub-drv))))
-      ((input (and (? string?) (? store-path?) file))
-       (return `(,input . ,file))))))
-
 (define %linux-vm-file-systems
   ;; File systems mounted for 'derivation-in-linux-vm'.  The store and /xchg
   ;; directory are shared with the host over 9p.
@@ -112,10 +92,12 @@ input tuple.  The output file name is when building for SYSTEM."
                                              (qemu qemu-headless)
                                              (env-vars '())
                                              (modules
-                                              '((guix build vm)
-                                                (guix build install)
-                                                (guix build linux-initrd)
-                                                (guix build utils)))
+                                              '((gnu build vm)
+                                                (gnu build install)
+                                                (gnu build linux-boot)
+                                                (gnu build file-systems)
+                                                (guix build utils)
+                                                (guix build store-copy)))
                                              (guile-for-build
                                               (%guile-for-build))
 
@@ -152,19 +134,18 @@ made available under the /xchg CIFS share."
                                            (cons #$compiled
                                                  %load-compiled-path))
                                      (primitive-load #$user-builder))))
-       (coreutils -> (car (assoc-ref %final-inputs "coreutils")))
+       (coreutils -> (canonical-package coreutils))
        (initrd       (if initrd                   ; use the default initrd?
                          (return initrd)
                          (base-initrd %linux-vm-file-systems
                                       #:virtio? #t
-                                      #:qemu-networking? #t
-                                      #:guile-modules-in-chroot? #t))))
+                                      #:qemu-networking? #t))))
 
     (define builder
       ;; Code that launches the VM that evaluates EXP.
       #~(begin
           (use-modules (guix build utils)
-                       (guix build vm))
+                       (gnu build vm))
 
           (let ((inputs  '#$(list qemu coreutils))
                 (linux   (string-append #$linux "/bzImage"))
@@ -217,48 +198,46 @@ INPUTS is a list of inputs (as for packages).  When COPY-INPUTS? is true, copy
 all of INPUTS into the image being built.  When REGISTER-CLOSURES? is true,
 register INPUTS in the store database of the image so that Guix can be used in
 the image."
-  (mlet %store-monad
-      ((graph (sequence %store-monad (map input->name+output inputs))))
-   (expression->derivation-in-linux-vm
-    name
-    #~(begin
-        (use-modules (guix build vm)
-                     (guix build utils))
+  (expression->derivation-in-linux-vm
+   name
+   #~(begin
+       (use-modules (gnu build vm)
+                    (guix build utils))
 
-        (let ((inputs
-               '#$(append (list qemu parted grub e2fsprogs util-linux)
-                          (map (compose car (cut assoc-ref %final-inputs <>))
-                               '("sed" "grep" "coreutils" "findutils" "gawk"))
-                          (if register-closures? (list guix) '())))
+       (let ((inputs
+              '#$(append (list qemu parted grub e2fsprogs util-linux)
+                         (map canonical-package
+                              (list sed grep coreutils findutils gawk))
+                         (if register-closures? (list guix) '())))
 
-              ;; This variable is unused but allows us to add INPUTS-TO-COPY
-              ;; as inputs.
-              (to-register
-                '#$(map (match-lambda
-                         ((name thing) thing)
-                         ((name thing output) `(,thing ,output)))
-                        inputs)))
+             ;; This variable is unused but allows us to add INPUTS-TO-COPY
+             ;; as inputs.
+             (to-register
+              '#$(map (match-lambda
+                       ((name thing) thing)
+                       ((name thing output) `(,thing ,output)))
+                      inputs)))
 
-          (set-path-environment-variable "PATH" '("bin" "sbin") inputs)
+         (set-path-environment-variable "PATH" '("bin" "sbin") inputs)
 
-          (let ((graphs '#$(match inputs
-                             (((names . _) ...)
-                              names))))
-            (initialize-hard-disk "/dev/vda"
-                                  #:system-directory #$os-derivation
-                                  #:grub.cfg #$grub-configuration
-                                  #:closures graphs
-                                  #:copy-closures? #$copy-inputs?
-                                  #:register-closures? #$register-closures?
-                                  #:disk-image-size #$disk-image-size
-                                  #:file-system-type #$file-system-type
-                                  #:file-system-label #$file-system-label)
-            (reboot))))
-    #:system system
-    #:make-disk-image? #t
-    #:disk-image-size disk-image-size
-    #:disk-image-format disk-image-format
-    #:references-graphs graph)))
+         (let ((graphs '#$(match inputs
+                            (((names . _) ...)
+                             names))))
+           (initialize-hard-disk "/dev/vda"
+                                 #:system-directory #$os-derivation
+                                 #:grub.cfg #$grub-configuration
+                                 #:closures graphs
+                                 #:copy-closures? #$copy-inputs?
+                                 #:register-closures? #$register-closures?
+                                 #:disk-image-size #$disk-image-size
+                                 #:file-system-type #$file-system-type
+                                 #:file-system-label #$file-system-label)
+           (reboot))))
+   #:system system
+   #:make-disk-image? #t
+   #:disk-image-size disk-image-size
+   #:disk-image-format disk-image-format
+   #:references-graphs inputs))
 
 
 ;;;
@@ -290,9 +269,11 @@ to USB sticks meant to be read-only."
               ;; Since this is meant to be used on real hardware, don't
               ;; install QEMU networking or anything like that, but make sure
               ;; USB mass storage devices are available.
-              (initrd (cut base-initrd <>
-                           #:volatile-root? #t
-                           #:extra-modules '("usb-storage.ko")))
+              (initrd (lambda (file-systems . rest)
+                        (apply base-initrd file-systems
+                               #:volatile-root? #t
+                               #:extra-modules '("usb-storage.ko")
+                               rest)))
 
               ;; Force our own root file system.
               (file-systems (cons (file-system
@@ -334,9 +315,11 @@ of the GNU system as described by OS."
 
   (let ((os (operating-system (inherit os)
               ;; Use an initrd with the whole QEMU shebang.
-              (initrd (cut base-initrd <>
-                           #:virtio? #t
-                           #:qemu-networking? #t))
+              (initrd (lambda (file-systems . rest)
+                        (apply base-initrd file-systems
+                               #:virtio? #t
+                               #:qemu-networking? #t
+                               rest)))
 
               ;; Force our own root file system.
               (file-systems (cons (file-system
@@ -359,10 +342,16 @@ of the GNU system as described by OS."
   "Return an operating system based on OS suitable for use in a virtualized
 environment with the store shared with the host."
   (operating-system (inherit os)
-    (initrd (cut base-initrd <>
-                 #:volatile-root? #t
-                 #:virtio? #t
-                 #:qemu-networking? #t))
+    (initrd (lambda (file-systems . rest)
+              (apply base-initrd file-systems
+                     #:volatile-root? #t
+                     #:virtio? #t
+                     #:qemu-networking? #t
+                     rest)))
+
+    ;; Disable swap.
+    (swap-devices '())
+
     (file-systems (cons* (file-system
                            (mount-point "/")
                            (device "/dev/vda1")
@@ -387,48 +376,79 @@ environment with the store shared with the host."
 
 (define* (system-qemu-image/shared-store
           os
-          #:key (disk-image-size (* 15 (expt 2 20))))
+          #:key
+          full-boot?
+          (disk-image-size (* (if full-boot? 500 15) (expt 2 20))))
   "Return a derivation that builds a QEMU image of OS that shares its store
-with the host."
-  (mlet* %store-monad
-      ((os-drv      (operating-system-derivation os))
-       (grub.cfg    (operating-system-grub.cfg os)))
+with the host.
+
+When FULL-BOOT? is true, return an image that does a complete boot sequence,
+bootloaded included; thus, make a disk image that contains everything the
+bootloader refers to: OS kernel, initrd, bootloader data, etc."
+  (mlet* %store-monad ((os-drv   (operating-system-derivation os))
+                       (grub.cfg (operating-system-grub.cfg os)))
+    ;; XXX: When FULL-BOOT? is true, we end up creating an image that contains
+    ;; GRUB.CFG and all its dependencies, including the output of OS-DRV.
+    ;; This is more than needed (we only need the kernel, initrd, GRUB for its
+    ;; font, and the background image), but it's hard to filter that.
     (qemu-image #:os-derivation os-drv
                 #:grub-configuration grub.cfg
                 #:disk-image-size disk-image-size
-                #:inputs `(("system" ,os-drv))
+                #:inputs (if full-boot?
+                             `(("grub.cfg" ,grub.cfg))
+                             '())
 
                 ;; XXX: Passing #t here is too slow, so let it off by default.
                 #:register-closures? #f
-                #:copy-inputs? #f)))
+                #:copy-inputs? full-boot?)))
 
-(define* (system-qemu-image/shared-store-script
-          os
-          #:key
-          (qemu qemu)
-          (graphic? #t))
+(define* (common-qemu-options image)
+  "Return the a string-value gexp with the common QEMU options to boot IMAGE."
+#~(string-append
+     " -enable-kvm -no-reboot -net nic,model=virtio \
+  -virtfs local,path=" #$(%store-prefix) ",security_model=none,mount_tag=store \
+  -net user \
+  -serial stdio \
+  -drive file=" #$image
+  ",if=virtio,cache=writeback,werror=report,readonly \
+  -m 256"))
+
+(define* (system-qemu-image/shared-store-script os
+                                                #:key
+                                                (qemu qemu)
+                                                (graphic? #t)
+                                                full-boot?
+                                                (disk-image-size
+                                                 (* (if full-boot? 500 15)
+                                                    (expt 2 20))))
   "Return a derivation that builds a script to run a virtual machine image of
-OS that shares its store with the host."
-  (mlet* %store-monad
-      ((os ->  (virtualized-operating-system os))
-       (os-drv (operating-system-derivation os))
-       (image  (system-qemu-image/shared-store os)))
+OS that shares its store with the host.
+
+When FULL-BOOT? is true, the returned script runs everything starting from the
+bootloader; otherwise it directly starts the operating system kernel.  The
+DISK-IMAGE-SIZE parameter specifies the size in bytes of the root disk image;
+it is mostly useful when FULL-BOOT?  is true."
+  (mlet* %store-monad ((os ->  (virtualized-operating-system os))
+                       (os-drv (operating-system-derivation os))
+                       (image  (system-qemu-image/shared-store
+                                os
+                                #:full-boot? full-boot?
+                                #:disk-image-size disk-image-size)))
     (define builder
       #~(call-with-output-file #$output
           (lambda (port)
             (display
              (string-append "#!" #$bash "/bin/sh
 exec " #$qemu "/bin/" #$(qemu-command (%current-system))
-" -enable-kvm -no-reboot -net nic,model=virtio \
-  -virtfs local,path=" #$(%store-prefix) ",security_model=none,mount_tag=store \
-  -net user \
-  -kernel " #$(operating-system-kernel os) "/bzImage \
-  -initrd " #$os-drv "/initrd \
--append \"" #$(if graphic? "" "console=ttyS0 ")
-  "--system=" #$os-drv " --load=" #$os-drv "/boot --root=/dev/vda1\" \
-  -serial stdio \
-  -drive file=" #$image
-  ",if=virtio,cache=writeback,werror=report,readonly\n")
+
+#$@(if full-boot?
+       #~()
+       #~(" -kernel " #$(operating-system-kernel os) "/bzImage \
+            -initrd " #$os-drv "/initrd \
+            -append \"" #$(if graphic? "" "console=ttyS0 ")
+            "--system=" #$os-drv " --load=" #$os-drv "/boot --root=/dev/vda1\" "))
+#$(common-qemu-options image)
+" \"$@\"\n")
              port)
             (chmod port #o555))))
 
