@@ -30,6 +30,7 @@
   #:use-module (guix utils)
   #:use-module (guix hash)
   #:use-module (guix base32)
+  #:use-module (guix records)
   #:export (<derivation>
             derivation?
             derivation-outputs
@@ -55,7 +56,10 @@
             derivation-input-sub-derivations
             derivation-input-output-paths
 
+            derivation-name
             fixed-output-derivation?
+            offloadable-derivation?
+            substitutable-derivation?
             derivation-hash
 
             read-derivation
@@ -65,6 +69,15 @@
             derivation-path->output-path
             derivation-path->output-paths
             derivation
+
+            graft
+            graft?
+            graft-origin
+            graft-replacement
+            graft-origin-output
+            graft-replacement-output
+            graft-derivation
+
             map-derivation
 
             %guile-for-build
@@ -116,6 +129,11 @@
                                           (derivation-outputs drv)))
                                     (number->string (object-address drv) 16))))
 
+(define (derivation-name drv)
+  "Return the base name of DRV."
+  (let ((base (store-path-package-name (derivation-file-name drv))))
+    (string-drop-right base 4)))
+
 (define (fixed-output-derivation? drv)
   "Return #t if DRV is a fixed-output derivation, such as the result of a
 download with a fixed hash (aka. `fetchurl')."
@@ -146,6 +164,18 @@ download with a fixed hash (aka. `fetchurl')."
                      read-derivation))
                  inputs)))))
 
+(define (offloadable-derivation? drv)
+  "Return true if DRV can be offloaded, false otherwise."
+  (match (assoc "preferLocalBuild"
+                (derivation-builder-environment-vars drv))
+    (("preferLocalBuild" . "1") #f)
+    (_ #t)))
+
+(define substitutable-derivation?
+  ;; Return #t if the derivation can be substituted.  Currently the two are
+  ;; synonymous, see <http://bugs.gnu.org/18747>.
+  offloadable-derivation?)
+
 (define* (derivation-prerequisites-to-build store drv
                                             #:key
                                             (outputs
@@ -193,7 +223,8 @@ that second value is the empty list."
     (every built? (derivation-output-paths drv sub-drvs)))
 
   (define (derivation-substitutable? drv sub-drvs)
-    (every substitutable? (derivation-output-paths drv sub-drvs)))
+    (and (substitutable-derivation? drv)
+         (every substitutable? (derivation-output-paths drv sub-drvs))))
 
   (let loop ((drv        drv)
              (sub-drvs   outputs)
@@ -206,7 +237,12 @@ that second value is the empty list."
                    (append (derivation-output-paths drv sub-drvs)
                            substitute)))
           (else
-           (let ((inputs (remove (lambda (i)
+           (let ((build  (if (substitutable-derivation? drv)
+                             build
+                             (cons (make-derivation-input
+                                    (derivation-file-name drv) sub-drvs)
+                                   build)))
+                 (inputs (remove (lambda (i)
                                    (or (member i build) ; XXX: quadratic
                                        (input-built? i)
                                        (input-substitutable? i)))
@@ -488,6 +524,16 @@ in SIZE bytes."
                               (logxor o (bytevector-u8-ref bv i)))
           (loop (+ 1 i))))))
 
+(define derivation-path->base16-hash
+  (memoize
+   (lambda (file)
+     "Return a string containing the base16 representation of the hash of the
+derivation at FILE."
+     (call-with-input-file file
+       (compose bytevector->base16-string
+                derivation-hash
+                read-derivation)))))
+
 (define derivation-hash            ; `hashDerivationModulo' in derivations.cc
   (memoize
    (lambda (drv)
@@ -511,10 +557,7 @@ in SIZE bytes."
        ;; derivation.
        (let* ((inputs (map (match-lambda
                             (($ <derivation-input> path sub-drvs)
-                             (let ((hash (call-with-input-file path
-                                           (compose bytevector->base16-string
-                                                    derivation-hash
-                                                    read-derivation))))
+                             (let ((hash (derivation-path->base16-hash path)))
                                (make-derivation-input hash sub-drvs))))
                            inputs))
               (drv    (make-derivation outputs inputs sources
@@ -885,6 +928,11 @@ system, imported, and appears under FINAL-PATH in the resulting store path."
                                   #:guile-for-build guile
                                   #:local-build? #t)))
 
+(define search-path*
+  ;; A memoizing version of 'search-path' so 'imported-modules' does not end
+  ;; up looking for the same files over and over again.
+  (memoize search-path))
+
 (define* (imported-modules store modules
                            #:key (name "module-import")
                            (system (%current-system))
@@ -899,7 +947,7 @@ search path."
                       (let ((f (string-append
                                 (string-join (map symbol->string m) "/")
                                 ".scm")))
-                        (cons f (search-path module-path f))))
+                        (cons f (search-path* module-path f))))
                     modules)))
     (imported-files store files #:name name #:system system
                     #:guile guile)))
@@ -952,6 +1000,80 @@ they can refer to each other."
                                   #:guile-for-build guile
                                   #:local-build? #t)))
 
+(define-record-type* <graft> graft make-graft
+  graft?
+  (origin             graft-origin)               ;derivation | store item
+  (origin-output      graft-origin-output         ;string | #f
+                      (default "out"))
+  (replacement        graft-replacement)          ;derivation | store item
+  (replacement-output graft-replacement-output    ;string | #f
+                      (default "out")))
+
+(define* (graft-derivation store name drv grafts
+                           #:key (guile (%guile-for-build))
+                           (system (%current-system)))
+  "Return a derivation called NAME, based on DRV but with all the GRAFTS
+applied."
+  ;; XXX: Someday rewrite using gexps.
+  (define mapping
+    ;; List of store item pairs.
+    (map (match-lambda
+          (($ <graft> source source-output target target-output)
+           (cons (if (derivation? source)
+                     (derivation->output-path source source-output)
+                     source)
+                 (if (derivation? target)
+                     (derivation->output-path target target-output)
+                     target))))
+         grafts))
+
+  (define outputs
+    (match (derivation-outputs drv)
+      (((names . outputs) ...)
+       (map derivation-output-path outputs))))
+
+  (define output-names
+    (match (derivation-outputs drv)
+      (((names . outputs) ...)
+       names)))
+
+  (define build
+    `(begin
+       (use-modules (guix build graft)
+                    (guix build utils)
+                    (ice-9 match))
+
+       (let ((mapping ',mapping))
+         (for-each (lambda (input output)
+                     (format #t "grafting '~a' -> '~a'...~%" input output)
+                     (rewrite-directory input output
+                                        `((,input . ,output)
+                                          ,@mapping)))
+                   ',outputs
+                   (match %outputs
+                     (((names . files) ...)
+                      files))))))
+
+  (define add-label
+    (cut cons "x" <>))
+
+  (match grafts
+    ((($ <graft> sources source-outputs targets target-outputs) ...)
+     (let ((sources (zip sources source-outputs))
+           (targets (zip targets target-outputs)))
+       (build-expression->derivation store name build
+                                     #:system system
+                                     #:guile-for-build guile
+                                     #:modules '((guix build graft)
+                                                 (guix build utils))
+                                     #:inputs `(,@(map (lambda (out)
+                                                         `("x" ,drv ,out))
+                                                       output-names)
+                                                ,@(append (map add-label sources)
+                                                          (map add-label targets)))
+                                     #:outputs output-names
+                                     #:local-build? #t)))))
+
 (define* (build-expression->derivation store name exp
                                        #:key
                                        (system (%current-system))
