@@ -22,7 +22,7 @@
   #:use-module (guix derivations)
   #:use-module (guix packages)
   #:use-module ((guix store) #:select (derivation-path? add-to-store))
-  #:use-module ((guix build download) #:renamer (symbol-prefix-proc 'build:))
+  #:use-module ((guix build download) #:prefix build:)
   #:use-module (guix monads)
   #:use-module (guix gexp)
   #:use-module (guix utils)
@@ -130,7 +130,6 @@
        "ftp://ftp.piotrkosoft.net/pub/mirrors/ftp.x.org/"
        "ftp://ftp.portal-to-web.de/pub/mirrors/x.org/"
        "ftp://ftp.solnet.ch/mirror/x.org/"
-       "ftp://ftp.sunet.se/pub/X11/"
        "ftp://gd.tuwien.ac.at/X11/"
        "ftp://mi.mirror.garr.it/mirrors/x.org/"
        "ftp://mirror.cict.fr/x.org/"
@@ -161,7 +160,6 @@
        ;; from http://www.imagemagick.org/script/download.php
        ;; (without mirrors that are unavailable or not up to date)
        ;; mirrors keeping old versions at the top level
-       "ftp://ftp.sunet.se/pub/multimedia/graphics/ImageMagick/"
        "ftp://sunsite.icm.edu.pl/packages/ImageMagick/"
        ;; mirrors moving old versions to "legacy"
        "http://mirrors-au.go-parts.com/mirrors/ImageMagick/"
@@ -187,7 +185,7 @@
        "http://ftp.debian.org/debian/"))))
 
 (define (gnutls-package)
-  "Return the GnuTLS package for SYSTEM."
+  "Return the default GnuTLS package."
   (let ((module (resolve-interface '(gnu packages gnutls))))
     (module-ref module 'gnutls)))
 
@@ -207,8 +205,8 @@ must be a list of symbol/URL-list pairs."
   (define guile-for-build
     (package-derivation store
                         (or guile
-                            (let ((distro
-                                   (resolve-interface '(gnu packages base))))
+                            (let ((distro (resolve-interface
+                                           '(gnu packages commencement))))
                               (module-ref distro 'guile-final)))
                         system))
 
@@ -236,7 +234,8 @@ must be a list of symbol/URL-list pairs."
               #~(eval-when (load expand eval)
                   (set! %load-path
                         (cons (string-append #$(gnutls-package)
-                                             "/share/guile/site")
+                                             "/share/guile/site/"
+                                             (effective-version))
                               %load-path)))
               #~#t)
 
@@ -244,20 +243,29 @@ must be a list of symbol/URL-list pairs."
         (url-fetch '#$url #$output
                    #:mirrors '#$mirrors)))
 
-  (run-with-store store
-    (gexp->derivation (or name file-name) builder
-                      #:system system
-                      #:hash-algo hash-algo
-                      #:hash hash
-                      #:modules '((guix build download)
-                                  (guix build utils)
-                                  (guix ftp-client))
-                      #:guile-for-build guile-for-build
+  (let ((uri (and (string? url) (string->uri url))))
+    (if (or (and (string? url) (not uri))
+            (and uri (memq (uri-scheme uri) '(#f file))))
+        (add-to-store store (or name file-name)
+                      #f "sha256" (if uri (uri-path uri) url))
+        (run-with-store store
+          (gexp->derivation (or name file-name) builder
+                            #:system system
+                            #:hash-algo hash-algo
+                            #:hash hash
+                            #:modules '((guix build download)
+                                        (guix build utils)
+                                        (guix ftp-client))
+                            #:guile-for-build guile-for-build
 
-                      ;; In general, offloading downloads is not a good idea.
-                      #:local-build? #t)
-    #:guile-for-build guile-for-build
-    #:system system))
+                            ;; In general, offloading downloads is not a good idea.
+                            ;;#:local-build? #t
+                            ;; FIXME: The above would also disable use of
+                            ;; substitutes, so comment it out; see
+                            ;; <https://bugs.gnu.org/18747>.
+                            )
+          #:guile-for-build guile-for-build
+          #:system system))))
 
 (define* (download-to-store store url #:optional (name (basename url))
                             #:key (log (current-error-port)))
