@@ -24,8 +24,10 @@
   #:use-module (guix derivations)
   #:use-module (guix build-system)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 vlist)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-9 gnu)
+  #:use-module (srfi srfi-11)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-34)
   #:use-module (srfi srfi-35)
@@ -65,11 +67,12 @@
             package-outputs
             package-native-search-paths
             package-search-paths
+            package-replacement
             package-synopsis
             package-description
             package-license
             package-home-page
-            package-platforms
+            package-supported-systems
             package-maintainers
             package-properties
             package-location
@@ -80,10 +83,14 @@
             package-transitive-target-inputs
             package-transitive-native-inputs
             package-transitive-propagated-inputs
+            package-transitive-supported-systems
             package-source-derivation
             package-derivation
             package-cross-derivation
             package-output
+            package-grafts
+
+            %supported-systems
 
             &package-error
             package-error?
@@ -92,7 +99,15 @@
             package-input-error?
             package-error-invalid-input
             &package-cross-build-system-error
-            package-cross-build-system-error?))
+            package-cross-build-system-error?
+
+            %graft?
+            package->bag
+            bag->derivation
+            bag-transitive-inputs
+            bag-transitive-host-inputs
+            bag-transitive-build-inputs
+            bag-transitive-target-inputs))
 
 ;;; Commentary:
 ;;;
@@ -166,6 +181,11 @@ corresponds to the arguments expected by `set-path-environment-variable'."
     (($ <search-path-specification> variable directories separator)
      `(,variable ,directories ,separator))))
 
+(define %supported-systems
+  ;; This is the list of system types that are supported.  By default, we
+  ;; expect all packages to build successfully here.
+  '("x86_64-linux" "i686-linux" "mips64el-linux"))
+
 ;; A package.
 (define-record-type* <package>
   package make-package
@@ -196,12 +216,15 @@ corresponds to the arguments expected by `set-path-environment-variable'."
                                                   ; inputs
   (native-search-paths package-native-search-paths (default '()))
   (search-paths package-search-paths (default '()))
+  (replacement package-replacement                ; package | #f
+               (default #f) (thunked))
 
   (synopsis package-synopsis)                    ; one-line description
   (description package-description)              ; one or two paragraphs
   (license package-license)
   (home-page package-home-page)
-  (platforms package-platforms (default '()))
+  (supported-systems package-supported-systems    ; list of strings
+                     (default %supported-systems))
   (maintainers package-maintainers (default '()))
 
   (properties package-properties (default '()))   ; alist for anything else
@@ -214,11 +237,14 @@ corresponds to the arguments expected by `set-path-environment-variable'."
                           (lambda (package port)
                             (let ((loc    (package-location package))
                                   (format simple-format))
-                              (format port "#<package ~a-~a ~a:~a ~a>"
+                              (format port "#<package ~a-~a ~a~a>"
                                       (package-name package)
                                       (package-version package)
-                                      (location-file loc)
-                                      (location-line loc)
+                                      (if loc
+                                          (format #f "~a:~a "
+                                                  (location-file loc)
+                                                  (location-line loc))
+                                          "")
                                       (number->string (object-address
                                                        package)
                                                       16)))))
@@ -291,7 +317,7 @@ corresponds to the arguments expected by `set-path-environment-variable'."
 
 (define (default-guile)
   "Return the default Guile package for SYSTEM."
-  (let ((distro (resolve-interface '(gnu packages base))))
+  (let ((distro (resolve-interface '(gnu packages commencement))))
     (module-ref distro 'guile-final)))
 
 (define* (patch-and-repack store source patches
@@ -345,8 +371,12 @@ IMPORTED-MODULES specify modules to use/import for use by SNIPPET."
   (define patch-inputs
     (map (lambda (number patch)
            (list (string-append "patch" (number->string number))
-                 (add-to-store store (basename patch) #t
-                               "sha256" patch)))
+                 (match patch
+                   ((? string?)
+                    (add-to-store store (basename patch) #t
+                                  "sha256" patch))
+                   ((? origin?)
+                    (package-source-derivation store patch)))))
          (iota (length patches))
 
          patches))
@@ -422,8 +452,8 @@ IMPORTED-MODULES specify modules to use/import for use by SNIPPET."
                                (and (member name (cons decompression-type
                                                        '("tar" "xz" "patch")))
                                     (list name
-                                          (package-derivation store p
-                                                              system)))))
+                                          (package-derivation store p system
+                                                              #:graft? #f)))))
                              (or inputs (%standard-patch-inputs))))
         (modules (delete-duplicates (cons '(guix build utils) modules))))
 
@@ -449,12 +479,10 @@ IMPORTED-MODULES specify modules to use/import for use by SNIPPET."
      ;; Patches and/or a snippet.
      (let ((source (method store uri 'sha256 sha256 name
                            #:system system))
-           (guile  (match (or guile-for-build (%guile-for-build)
-                              (default-guile))
+           (guile  (match (or guile-for-build (default-guile))
                      ((? package? p)
-                      (package-derivation store p system))
-                     ((? derivation? drv)
-                      drv))))
+                      (package-derivation store p system
+                                          #:graft? #f)))))
        (patch-and-repack store source patches
                          #:inputs inputs
                          #:snippet snippet
@@ -515,6 +543,59 @@ for the host system (\"native inputs\"), and not target inputs."
 recursively."
   (transitive-inputs (package-propagated-inputs package)))
 
+(define-syntax-rule (first-value exp)
+  "Truncate all but the first value returned by EXP."
+  (call-with-values (lambda () exp)
+    (lambda (result . _)
+      result)))
+
+(define (package-transitive-supported-systems package)
+  "Return the intersection of the systems supported by PACKAGE and those
+supported by its dependencies."
+  (first-value
+   (let loop ((package package)
+              (systems (package-supported-systems package))
+              (visited vlist-null))
+     (match (vhash-assq package visited)
+       ((_ . result)
+        (values (lset-intersection string=? systems result)
+                visited))
+       (#f
+        (call-with-values
+            (lambda ()
+              (fold2 (lambda (input systems visited)
+                       (match input
+                         ((label (? package? package) . _)
+                          (loop package systems visited))
+                         (_
+                          (values systems visited))))
+                     (lset-intersection string=?
+                                        systems
+                                        (package-supported-systems package))
+                     visited
+                     (package-direct-inputs package)))
+          (lambda (systems visited)
+            (values systems
+                    (vhash-consq package systems visited)))))))))
+
+(define (bag-transitive-inputs bag)
+  "Same as 'package-transitive-inputs', but applied to a bag."
+  (transitive-inputs (append (bag-build-inputs bag)
+                             (bag-host-inputs bag)
+                             (bag-target-inputs bag))))
+
+(define (bag-transitive-build-inputs bag)
+  "Same as 'package-transitive-native-inputs', but applied to a bag."
+  (transitive-inputs (bag-build-inputs bag)))
+
+(define (bag-transitive-host-inputs bag)
+  "Same as 'package-transitive-target-inputs', but applied to a bag."
+  (transitive-inputs (bag-host-inputs bag)))
+
+(define (bag-transitive-target-inputs bag)
+  "Return the \"target inputs\" of BAG, recursively."
+  (transitive-inputs (bag-target-inputs bag)))
+
 
 ;;;
 ;;; Package derivations.
@@ -533,22 +614,26 @@ SYSTEM."
     ;; Use `hashq-set!' instead of `hash-set!' because `hash' returns the
     ;; same value for all structs (as of Guile 2.0.6), and because pointer
     ;; equality is sufficient in practice.
-    (hashq-set! %derivation-cache package `((,system ,@vals)))
+    (hashq-set! %derivation-cache package
+                `((,system ,@vals)
+                  ,@(or (hashq-ref %derivation-cache package)
+                        '())))
     (apply values vals)))
 
 (define-syntax-rule (cached package system body ...)
   "Memoize the result of BODY for the arguments PACKAGE and SYSTEM.
 Return the cached result when available."
-  (let ((thunk (lambda () body ...)))
+  (let ((thunk (lambda () body ...))
+        (key   system))
     (match (hashq-ref %derivation-cache package)
       ((alist (... ...))
-       (match (assoc-ref alist system)
+       (match (assoc-ref alist key)
          ((vals (... ...))
           (apply values vals))
          (#f
-          (cache package system thunk))))
+          (cache package key thunk))))
       (#f
-       (cache package system thunk)))))
+       (cache package key thunk)))))
 
 (define* (expand-input store package input system #:optional cross-system)
   "Expand INPUT, an input tuple, such that it contains only references to
@@ -561,8 +646,9 @@ information in exceptions."
 
   (define derivation
     (if cross-system
-        (cut package-cross-derivation store <> cross-system system)
-        (cut package-derivation store <> system)))
+        (cut package-cross-derivation store <> cross-system system
+             #:graft? #f)
+        (cut package-derivation store <> system #:graft? #f)))
 
   (match input
     (((? string? name) (? package? package))
@@ -587,100 +673,225 @@ information in exceptions."
                         (package package)
                         (input   x)))))))
 
+(define %graft?
+  ;; Whether to honor package grafts by default.
+  (make-parameter #t))
+
+(define* (package->bag package #:optional
+                       (system (%current-system))
+                       (target (%current-target-system))
+                       #:key (graft? (%graft?)))
+  "Compile PACKAGE into a bag for SYSTEM, possibly cross-compiled to TARGET,
+and return it."
+  ;; Bind %CURRENT-SYSTEM and %CURRENT-TARGET-SYSTEM so that thunked field
+  ;; values can refer to it.
+  (parameterize ((%current-system system)
+                 (%current-target-system target))
+    (match (if graft?
+               (or (package-replacement package) package)
+               package)
+      (($ <package> name version source build-system
+                    args inputs propagated-inputs native-inputs self-native-input?
+                    outputs)
+       (or (make-bag build-system (string-append name "-" version)
+                     #:system system
+                     #:target target
+                     #:source source
+                     #:inputs (append (inputs)
+                                      (propagated-inputs))
+                     #:outputs outputs
+                     #:native-inputs `(,@(if (and target self-native-input?)
+                                             `(("self" ,package))
+                                             '())
+                                       ,@(native-inputs))
+                     #:arguments (args))
+           (raise (if target
+                      (condition
+                       (&package-cross-build-system-error
+                        (package package)))
+                      (condition
+                       (&package-error
+                        (package package))))))))))
+
+(define (input-graft store system)
+  "Return a procedure that, given an input referring to a package with a
+graft, returns a pair with the original derivation and the graft's derivation,
+and returns #f for other inputs."
+  (match-lambda
+   ((label (? package? package) sub-drv ...)
+    (let ((replacement (package-replacement package)))
+      (and replacement
+           (let ((orig (package-derivation store package system
+                                           #:graft? #f))
+                 (new  (package-derivation store replacement system)))
+             (graft
+               (origin orig)
+               (replacement new)
+               (origin-output (match sub-drv
+                                (() "out")
+                                ((output) output)))
+               (replacement-output origin-output))))))
+   (x
+    #f)))
+
+(define (input-cross-graft store target system)
+  "Same as 'input-graft', but for cross-compilation inputs."
+  (match-lambda
+   ((label (? package? package) sub-drv ...)
+    (let ((replacement (package-replacement package)))
+      (and replacement
+           (let ((orig (package-cross-derivation store package target system
+                                                 #:graft? #f))
+                 (new  (package-cross-derivation store replacement
+                                                 target system)))
+             (graft
+               (origin orig)
+               (replacement new)
+               (origin-output (match sub-drv
+                                (() "out")
+                                ((output) output)))
+               (replacement-output origin-output))))))
+   (_
+    #f)))
+
+(define* (bag-grafts store bag)
+  "Return the list of grafts applicable to BAG.  Each graft is a <graft>
+record."
+  (let ((target (bag-target bag))
+        (system (bag-system bag)))
+    (define native-grafts
+      (filter-map (input-graft store system)
+                  (append (bag-transitive-build-inputs bag)
+                          (bag-transitive-target-inputs bag)
+                          (if target
+                              '()
+                              (bag-transitive-host-inputs bag)))))
+
+    (define target-grafts
+      (if target
+          (filter-map (input-cross-graft store target system)
+                      (bag-transitive-host-inputs bag))
+          '()))
+
+    (append native-grafts target-grafts)))
+
+(define* (package-grafts store package
+                         #:optional (system (%current-system))
+                         #:key target)
+  "Return the list of grafts applicable to PACKAGE as built for SYSTEM and
+TARGET."
+  (let* ((package (or (package-replacement package) package))
+         (bag     (package->bag package system target)))
+    (bag-grafts store bag)))
+
+(define* (bag->derivation store bag
+                          #:optional context)
+  "Return the derivation to build BAG for SYSTEM.  Optionally, CONTEXT can be
+a package object describing the context in which the call occurs, for improved
+error reporting."
+  (if (bag-target bag)
+      (bag->cross-derivation store bag)
+      (let* ((system     (bag-system bag))
+             (inputs     (bag-transitive-inputs bag))
+             (input-drvs (map (cut expand-input store context <> system)
+                              inputs))
+             (paths      (delete-duplicates
+                          (append-map (match-lambda
+                                       ((_ (? package? p) _ ...)
+                                        (package-native-search-paths
+                                         p))
+                                       (_ '()))
+                                      inputs))))
+
+        (apply (bag-build bag)
+               store (bag-name bag) input-drvs
+               #:search-paths paths
+               #:outputs (bag-outputs bag) #:system system
+               (bag-arguments bag)))))
+
+(define* (bag->cross-derivation store bag
+                                #:optional context)
+  "Return the derivation to build BAG, which is actually a cross build.
+Optionally, CONTEXT can be a package object denoting the context of the call.
+This is an internal procedure."
+  (let* ((system      (bag-system bag))
+         (target      (bag-target bag))
+         (host        (bag-transitive-host-inputs bag))
+         (host-drvs   (map (cut expand-input store context <> system target)
+                           host))
+         (target*     (bag-transitive-target-inputs bag))
+         (target-drvs (map (cut expand-input store context <> system)
+                           target*))
+         (build       (bag-transitive-build-inputs bag))
+         (build-drvs  (map (cut expand-input store context <> system)
+                           build))
+         (all         (append build target* host))
+         (paths       (delete-duplicates
+                       (append-map (match-lambda
+                                    ((_ (? package? p) _ ...)
+                                     (package-search-paths p))
+                                    (_ '()))
+                                   all)))
+         (npaths      (delete-duplicates
+                       (append-map (match-lambda
+                                    ((_ (? package? p) _ ...)
+                                     (package-native-search-paths
+                                      p))
+                                    (_ '()))
+                                   all))))
+
+    (apply (bag-build bag)
+           store (bag-name bag)
+           #:native-drvs build-drvs
+           #:target-drvs (append host-drvs target-drvs)
+           #:search-paths paths
+           #:native-search-paths npaths
+           #:outputs (bag-outputs bag)
+           #:system system #:target target
+           (bag-arguments bag))))
+
 (define* (package-derivation store package
-                             #:optional (system (%current-system)))
+                             #:optional (system (%current-system))
+                             #:key (graft? (%graft?)))
   "Return the <derivation> object of PACKAGE for SYSTEM."
 
   ;; Compute the derivation and cache the result.  Caching is important
   ;; because some derivations, such as the implicit inputs of the GNU build
   ;; system, will be queried many, many times in a row.
-  (cached package system
-
-          ;; Bind %CURRENT-SYSTEM so that thunked field values can refer
-          ;; to it.
-          (parameterize ((%current-system system)
-                         (%current-target-system #f))
-            (match package
-              (($ <package> name version source (= build-system-builder builder)
-                  args inputs propagated-inputs native-inputs self-native-input?
-                  outputs)
-               (let* ((inputs     (package-transitive-inputs package))
-                      (input-drvs (map (cut expand-input
-                                            store package <> system)
-                                       inputs))
-                      (paths      (delete-duplicates
-                                   (append-map (match-lambda
-                                                ((_ (? package? p) _ ...)
-                                                 (package-native-search-paths
-                                                  p))
-                                                (_ '()))
-                                               inputs))))
-
-                 (apply builder
-                        store (package-full-name package)
-                        (and source
-                             (package-source-derivation store source system))
-                        input-drvs
-                        #:search-paths paths
-                        #:outputs outputs #:system system
-                        (args))))))))
+  (cached package (cons system graft?)
+          (let* ((bag (package->bag package system #f #:graft? graft?))
+                 (drv (bag->derivation store bag package)))
+            (if graft?
+                (match (bag-grafts store bag)
+                  (()
+                   drv)
+                  (grafts
+                   (let ((guile (package-derivation store (default-guile)
+                                                    system #:graft? #f)))
+                     (graft-derivation store (bag-name bag) drv grafts
+                                       #:system system
+                                       #:guile guile))))
+                drv))))
 
 (define* (package-cross-derivation store package target
-                                   #:optional (system (%current-system)))
+                                   #:optional (system (%current-system))
+                                   #:key (graft? (%graft?)))
   "Cross-build PACKAGE for TARGET (a GNU triplet) from host SYSTEM (a Guix
 system identifying string)."
-  (cached package (cons system target)
-
-          ;; Bind %CURRENT-SYSTEM so that thunked field values can refer
-          ;; to it.
-          (parameterize ((%current-system system)
-                         (%current-target-system target))
-            (match package
-              (($ <package> name version source
-                  (= build-system-cross-builder builder)
-                  args inputs propagated-inputs native-inputs self-native-input?
-                  outputs)
-               (unless builder
-                 (raise (condition
-                         (&package-cross-build-system-error
-                          (package package)))))
-
-               (let* ((inputs     (package-transitive-target-inputs package))
-                      (input-drvs (map (cut expand-input
-                                            store package <>
-                                            system target)
-                                       inputs))
-                      (host       (append (if self-native-input?
-                                              `(("self" ,package))
-                                              '())
-                                          (package-transitive-native-inputs package)))
-                      (host-drvs  (map (cut expand-input
-                                            store package <> system)
-                                       host))
-                      (all        (append host inputs))
-                      (paths      (delete-duplicates
-                                   (append-map (match-lambda
-                                                ((_ (? package? p) _ ...)
-                                                 (package-search-paths p))
-                                                (_ '()))
-                                               all)))
-                      (npaths     (delete-duplicates
-                                   (append-map (match-lambda
-                                                ((_ (? package? p) _ ...)
-                                                 (package-native-search-paths
-                                                  p))
-                                                (_ '()))
-                                               all))))
-
-                 (apply builder
-                        store (package-full-name package) target
-                        (and source
-                             (package-source-derivation store source system))
-                        input-drvs host-drvs
-                        #:search-paths paths
-                        #:native-search-paths npaths
-                        #:outputs outputs #:system system
-                        (args))))))))
+  (cached package (list system target graft?)
+          (let* ((bag (package->bag package system target #:graft? graft?))
+                 (drv (bag->derivation store bag package)))
+            (if graft?
+                (match (bag-grafts store bag)
+                  (()
+                   drv)
+                  (grafts
+                   (graft-derivation store (bag-name bag) drv grafts
+                                     #:system system
+                                     #:guile
+                                     (package-derivation store (default-guile)
+                                                         system #:graft? #f))))
+                drv))))
 
 (define* (package-output store package
                          #:optional (output "out") (system (%current-system)))
