@@ -23,7 +23,7 @@
   #:use-module (guix utils)
   #:use-module (guix config)
   #:use-module (guix records)
-  #:use-module (guix nar)
+  #:use-module (guix serialization)
   #:use-module (guix hash)
   #:use-module (guix base64)
   #:use-module (guix pk-crypto)
@@ -528,10 +528,6 @@ PORT.  REPORT-PROGRESS is a two-argument procedure such as that returned by
                 (_ "(Please consider upgrading Guile to get proper progress report.)~%"))
         port)))
 
-(define %cache-url
-  (or (getenv "GUIX_BINARY_SUBSTITUTE_URL")
-      "http://hydra.gnu.org"))
-
 (define-syntax with-networking
   (syntax-rules ()
     "Catch DNS lookup errors and gracefully exit."
@@ -604,6 +600,45 @@ Internal tool to substitute a pre-built binary to a local build.\n"))
       (warning (_ "ACL for archive imports seems to be uninitialized, \
 substitutes may be unavailable\n")))))
 
+(define (daemon-options)
+  "Return a list of name/value pairs denoting build daemon options."
+  (define %not-newline
+    (char-set-complement (char-set #\newline)))
+
+  (match (getenv "_NIX_OPTIONS")
+    (#f                           ;should not happen when called by the daemon
+     '())
+    (newline-separated
+     ;; Here we get something of the form "OPTION1=VALUE1\nOPTION2=VALUE2\n".
+     (filter-map (lambda (option=value)
+                   (match (string-index option=value #\=)
+                     (#f                          ;invalid option setting
+                      #f)
+                     (equal-sign
+                      (cons (string-take option=value equal-sign)
+                            (string-drop option=value (+ 1 equal-sign))))))
+                 (string-tokenize newline-separated %not-newline)))))
+
+(define (find-daemon-option option)
+  "Return the value of build daemon option OPTION, or #f if it could not be
+found."
+  (assoc-ref (daemon-options) option))
+
+(define %cache-url
+  (match (and=> (find-daemon-option "substitute-urls")
+                string-tokenize)
+    ((url)
+     url)
+    ((head tail ..1)
+     ;; Currently we don't handle multiple substitute URLs.
+     (warning (_ "these substitute URLs will not be used:~{ ~a~}~%")
+              tail)
+     head)
+    (#f
+     ;; This can only happen when this script is not invoked by the
+     ;; daemon.
+     "http://hydra.gnu.org")))
+
 (define (guix-substitute-binary . args)
   "Implement the build daemon's substituter protocol."
   (mkdir-p %narinfo-cache-directory)
@@ -696,8 +731,8 @@ substituter disabled~%")
           ;; Tell the daemon what the expected hash of the Nar itself is.
           (format #t "~a~%" (narinfo-hash narinfo))
 
-          (format (current-error-port) "downloading `~a' from `~a'~:[~*~; (~,1f MiB installed)~]...~%"
-                  store-path (uri->string uri)
+          (format (current-error-port) "downloading `~a'~:[~*~; (~,1f MiB installed)~]...~%"
+                  store-path
 
                   ;; Use the Nar size as an estimate of the installed size.
                   (narinfo-size narinfo)
