@@ -28,12 +28,13 @@
   #:use-module (guix profiles)
   #:use-module (guix scripts build)
   #:use-module (guix build utils)
-  #:use-module (guix build install)
+  #:use-module (gnu build install)
   #:use-module (gnu system)
   #:use-module (gnu system vm)
   #:use-module (gnu system grub)
   #:use-module (gnu packages grub)
   #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-19)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-37)
   #:use-module (ice-9 match)
@@ -199,6 +200,9 @@ it atomically, and then run OS's activation script."
       ;; The activation script may change $PATH, among others, so protect
       ;; against that.
       (return (save-environment-excursion
+               ;; Tell 'activate-current-system' what the new system is.
+               (setenv "GUIX_NEW_SYSTEM" system)
+
                (primitive-load (derivation->output-path script))))
 
       ;; TODO: Run 'deco reload ...'.
@@ -213,9 +217,15 @@ it atomically, and then run OS's activation script."
           #f
           (apply throw args)))))
 
+(define (seconds->string seconds)
+  "Return a string representing the date for SECONDS."
+  (let ((time (make-time time-utc 0 seconds)))
+    (date->string (time-utc->date time)
+                  "~Y-~m-~d ~H:~M")))
+
 (define* (previous-grub-entries #:optional (profile %system-profile))
   "Return a list of 'menu-entry' for the generations of PROFILE."
-  (define (system->grub-entry system)
+  (define (system->grub-entry system number time)
     (unless-file-not-found
      (call-with-input-file (string-append system "/parameters")
        (lambda (port)
@@ -225,7 +235,9 @@ it atomically, and then run OS's activation script."
                               ('kernel linux)
                               _ ...)
             (menu-entry
-             (label label)
+             (label (string-append label " (#"
+                                   (number->string number) ", "
+                                   (seconds->string time) ")"))
              (linux linux)
              (linux-arguments
               (list (string-append "--root=" root)
@@ -237,9 +249,14 @@ it atomically, and then run OS's activation script."
                      system)
             #f))))))
 
-  (let ((systems (map (cut generation-file-name profile <>)
-                      (generation-numbers profile))))
-    (filter-map system->grub-entry systems)))
+  (let* ((numbers (generation-numbers profile))
+         (systems (map (cut generation-file-name profile <>)
+                       numbers))
+         (times   (map (lambda (system)
+                         (unless-file-not-found
+                          (stat:mtime (lstat system))))
+                       systems)))
+    (filter-map system->grub-entry systems numbers times)))
 
 
 ;;;
@@ -247,7 +264,7 @@ it atomically, and then run OS's activation script."
 ;;;
 
 (define* (system-derivation-for-action os action
-                                       #:key image-size)
+                                       #:key image-size full-boot?)
   "Return as a monadic value the derivation for OS according to ACTION."
   (case action
     ((build init reconfigure)
@@ -255,7 +272,9 @@ it atomically, and then run OS's activation script."
     ((vm-image)
      (system-qemu-image os #:disk-image-size image-size))
     ((vm)
-     (system-qemu-image/shared-store-script os))
+     (system-qemu-image/shared-store-script os
+                                            #:full-boot? full-boot?
+                                            #:disk-image-size image-size))
     ((disk-image)
      (system-disk-image os #:disk-image-size image-size))))
 
@@ -279,14 +298,16 @@ true."
 (define* (perform-action action os
                          #:key grub? dry-run?
                          use-substitutes? device target
-                         image-size)
+                         image-size full-boot?)
   "Perform ACTION for OS.  GRUB? specifies whether to install GRUB; DEVICE is
 the target devices for GRUB; TARGET is the target root directory; IMAGE-SIZE
 is the size of the image to be built, for the 'vm-image' and 'disk-image'
-actions."
+actions.  FULL-BOOT? is used for the 'vm' action; it determines whether to
+boot directly to the kernel or to the bootloader."
   (mlet* %store-monad
       ((sys       (system-derivation-for-action os action
-                                                #:image-size image-size))
+                                                #:image-size image-size
+                                                #:full-boot? full-boot?))
        (grub      (package->derivation grub))
        (grub.cfg  (grub.cfg os))
        (drvs   -> (if (and grub? (memq action '(init reconfigure)))
@@ -358,6 +379,8 @@ Build the operating system declared in FILE according to ACTION.\n"))
       --image-size=SIZE  for 'vm-image', produce an image of SIZE"))
   (display (_ "
       --no-grub          for 'init', do not install GRUB"))
+  (display (_ "
+      --full-boot        for 'vm', make a full boot sequence"))
   (newline)
   (display (_ "
   -h, --help             display this help and exit"))
@@ -382,6 +405,9 @@ Build the operating system declared in FILE according to ACTION.\n"))
          (option '("no-grub") #f #f
                  (lambda (opt name arg result)
                    (alist-delete 'install-grub? result)))
+         (option '("full-boot") #f #f
+                 (lambda (opt name arg result)
+                   (alist-cons 'full-boot? #t result)))
          (option '(#\n "dry-run") #f #f
                  (lambda (opt name arg result)
                    (alist-cons 'dry-run? #t result)))
@@ -475,6 +501,7 @@ Build the operating system declared in FILE according to ACTION.\n"))
                         #:dry-run? dry?
                         #:use-substitutes? (assoc-ref opts 'substitutes?)
                         #:image-size (assoc-ref opts 'image-size)
+                        #:full-boot? (assoc-ref opts 'full-boot?)
                         #:grub? grub?
                         #:target target #:device device)
         #:system system))))
