@@ -2,6 +2,7 @@
 ;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2013 Nikita Karetnikov <nikita@karetnikov.org>
+;;; Copyright © 2014 Alex Kost <alezost@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -23,8 +24,10 @@
   #:use-module (guix store)
   #:use-module (guix config)
   #:use-module (guix packages)
+  #:use-module (guix profiles)
   #:use-module (guix build-system)
   #:use-module (guix derivations)
+  #:use-module ((guix build utils) #:select (mkdir-p))
   #:use-module ((guix licenses) #:select (license? license-name))
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-11)
@@ -46,6 +49,7 @@
             string->number*
             size->number
             show-what-to-build
+            show-manifest-transaction
             call-with-error-handling
             with-error-handling
             read/eval
@@ -188,14 +192,22 @@ interpreted."
     ((compose inexact->exact round)
      (* num
         (match unit
-          ("KiB" (expt 2 10))
-          ("MiB" (expt 2 20))
-          ("GiB" (expt 2 30))
-          ("TiB" (expt 2 40))
-          ("KB"  (expt 10 3))
+          ((or "KiB" "K" "k") (expt 2 10))
+          ((or "MiB" "M")     (expt 2 20))
+          ((or "GiB" "G")     (expt 2 30))
+          ((or "TiB" "T")     (expt 2 40))
+          ((or "PiB" "P")     (expt 2 50))
+          ((or "EiB" "E")     (expt 2 60))
+          ((or "ZiB" "Z")     (expt 2 70))
+          ((or "YiB" "Y")     (expt 2 80))
+          ("kB"  (expt 10 3))
           ("MB"  (expt 10 6))
           ("GB"  (expt 10 9))
           ("TB"  (expt 10 12))
+          ("PB"  (expt 10 15))
+          ("EB"  (expt 10 18))
+          ("ZB"  (expt 10 21))
+          ("YB"  (expt 10 24))
           (""    1)
           (_
            (leave (_ "unknown unit: ~a~%") unit)))))))
@@ -220,6 +232,13 @@ interpreted."
                       (location->string loc)
                       (package-full-name package)
                       (build-system-name system))))
+            ((profile-not-found-error? c)
+             (leave (_ "profile '~a' does not exist~%")
+                    (profile-error-profile c)))
+            ((missing-generation-error? c)
+             (leave (_ "generation ~a of profile '~a' does not exist~%")
+                    (missing-generation-error-generation c)
+                    (profile-error-profile c)))
             ((nix-connection-error? c)
              (leave (_ "failed to connect to `~a': ~a~%")
                     (nix-connection-error-file c)
@@ -230,7 +249,8 @@ interpreted."
                     (nix-protocol-error-message c)))
             ((message-condition? c)
              ;; Normally '&message' error conditions have an i18n'd message.
-             (leave (_ "~a~%") (gettext (condition-message c)))))
+             (leave (_ "~a~%")
+                    (gettext (condition-message c) %gettext-domain))))
     ;; Catch EPIPE and the likes.
     (catch 'system-error
       thunk
@@ -338,6 +358,97 @@ available for download."
                   (null? download) download)))
     (pair? build)))
 
+(define (right-arrow port)
+  "Return either a string containing the 'RIGHT ARROW' character, or an ASCII
+replacement if PORT is not Unicode-capable."
+  (with-fluids ((%default-port-encoding (port-encoding port)))
+    (let ((arrow "→"))
+      (catch 'encoding-error
+        (lambda ()
+          (call-with-output-string
+            (lambda (port)
+              (set-port-conversion-strategy! port 'error)
+              (display arrow port))))
+        (lambda (key . args)
+          "->")))))
+
+(define* (show-manifest-transaction store manifest transaction
+                                    #:key dry-run?)
+  "Display what will/would be installed/removed from MANIFEST by TRANSACTION."
+  (define (package-strings name version output item)
+    (map (lambda (name version output item)
+           (format #f "   ~a~:[:~a~;~*~]\t~a\t~a"
+                   name
+                   (equal? output "out") output version
+                   (if (package? item)
+                       (package-output store item output)
+                       item)))
+         name version output item))
+
+  (define →                        ;an arrow that can be represented on stderr
+    (right-arrow (current-error-port)))
+
+  (define (upgrade-string name old-version new-version output item)
+    (format #f "   ~a~:[:~a~;~*~]\t~a ~a ~a\t~a"
+            name (equal? output "out") output
+            old-version → new-version
+            (if (package? item)
+                (package-output store item output)
+                item)))
+
+  (let-values (((remove install upgrade)
+                (manifest-transaction-effects manifest transaction)))
+    (match remove
+      ((($ <manifest-entry> name version output item) ..1)
+       (let ((len    (length name))
+             (remove (package-strings name version output item)))
+         (if dry-run?
+             (format (current-error-port)
+                     (N_ "The following package would be removed:~%~{~a~%~}~%"
+                         "The following packages would be removed:~%~{~a~%~}~%"
+                         len)
+                     remove)
+             (format (current-error-port)
+                     (N_ "The following package will be removed:~%~{~a~%~}~%"
+                         "The following packages will be removed:~%~{~a~%~}~%"
+                         len)
+                     remove))))
+      (_ #f))
+    (match upgrade
+      (((($ <manifest-entry> name old-version)
+         . ($ <manifest-entry> _ new-version output item)) ..1)
+       (let ((len     (length name))
+             (upgrade (map upgrade-string
+                           name old-version new-version output item)))
+         (if dry-run?
+             (format (current-error-port)
+                     (N_ "The following package would be upgraded:~%~{~a~%~}~%"
+                         "The following packages would be upgraded:~%~{~a~%~}~%"
+                         len)
+                     upgrade)
+             (format (current-error-port)
+                     (N_ "The following package will be upgraded:~%~{~a~%~}~%"
+                         "The following packages will be upgraded:~%~{~a~%~}~%"
+                         len)
+                     upgrade))))
+      (_ #f))
+    (match install
+      ((($ <manifest-entry> name version output item _) ..1)
+       (let ((len     (length name))
+             (install (package-strings name version output item)))
+         (if dry-run?
+             (format (current-error-port)
+                     (N_ "The following package would be installed:~%~{~a~%~}~%"
+                         "The following packages would be installed:~%~{~a~%~}~%"
+                         len)
+                     install)
+             (format (current-error-port)
+                     (N_ "The following package will be installed:~%~{~a~%~}~%"
+                         "The following packages will be installed:~%~{~a~%~}~%"
+                         len)
+                     install))))
+      (_ #f))))
+
 (define-syntax with-error-handling
   (syntax-rules ()
     "Run BODY within a user-friendly error condition handler."
@@ -370,15 +481,13 @@ exists.  Honor the XDG specs,
                     (cut string-append <> "/guix"))))
     (catch 'system-error
       (lambda ()
-        (mkdir dir)
+        (mkdir-p dir)
         dir)
       (lambda args
-        (match (system-error-errno args)
-          ((or EEXIST 0)
-           dir)
-          (err
-           (leave (_ "failed to create configuration directory `~a': ~a~%")
-                  dir (strerror err))))))))
+        (let ((err (system-error-errno args)))
+          ;; ERR is necessarily different from EEXIST.
+          (leave (_ "failed to create configuration directory `~a': ~a~%")
+                 dir (strerror err)))))))
 
 (define* (fill-paragraph str width #:optional (column 0))
   "Fill STR such that each line contains at most WIDTH characters, assuming
@@ -393,15 +502,17 @@ converted to a space; sequences of more than one line break are preserved."
          ((#\newline)
           `(,column ,(+ 1 newlines) ,chars))
          (else
-          (let ((chars  (case newlines
-                          ((0) chars)
-                          ((1) (cons #\space chars))
-                          (else
-                           (append (make-list newlines #\newline) chars))))
-                (column (case newlines
-                          ((0) column)
-                          ((1) (+ 1 column))
-                          (else 0))))
+          (let* ((spaces (if (and (pair? chars) (eqv? (car chars) #\.)) 2 1))
+                 (chars  (case newlines
+                           ((0) chars)
+                           ((1)
+                            (append (make-list spaces #\space) chars))
+                           (else
+                            (append (make-list newlines #\newline) chars))))
+                 (column (case newlines
+                           ((0) column)
+                           ((1) (+ spaces column))
+                           (else 0))))
             (let ((chars  (cons chr chars))
                   (column (+ 1 column)))
               (if (> column width)
@@ -414,7 +525,10 @@ converted to a space; sequences of more than one line break are preserved."
                           0
                           ,(if (null? after)
                                before
-                               (append before (cons #\newline (cdr after)))))
+                               (append before
+                                       (cons #\newline
+                                             (drop-while (cut eqv? #\space <>)
+                                                         after)))))
                         `(,column 0 ,chars)))     ; unbreakable
                   `(,column 0 ,chars)))))))))
 
@@ -468,8 +582,8 @@ WIDTH columns."
   (format port "version: ~a~%" (package-version p))
   (format port "dependencies: ~a~%"
           (match (package-direct-inputs p)
-            (((labels packages . _) ...)
-             (dependencies->recutils packages))))
+            (((labels inputs . _) ...)
+             (dependencies->recutils (filter package? inputs)))))
   (format port "location: ~a~%"
           (or (and=> (package-location p) location->string)
               (_ "unknown")))
