@@ -2,6 +2,7 @@
 ;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2014 Ian Denhardt <ian@zenhack.net>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -48,6 +49,7 @@
             compile-time-value
             fcntl-flock
             memoize
+            strip-keyword-arguments
             default-keyword-arguments
             substitute-keyword-arguments
 
@@ -64,6 +66,8 @@
             %current-target-system
             version-compare
             version>?
+            version-prefix
+            version-major+minor
             guile-version>?
             package-name->name+version
             string-tokenize*
@@ -120,12 +124,13 @@ evaluate to a simple datum."
                                                     0))))
                                     v))))))
     (define chars base16-chars)
-    (let loop ((i 0)
+    (let loop ((i len)
                (r '()))
-      (if (= i len)
-          (string-concatenate-reverse r)
-          (loop (+ 1 i)
-                (cons (vector-ref chars (bytevector-u8-ref bv i)) r))))))
+      (if (zero? i)
+          (string-concatenate r)
+          (let ((i (- i 1)))
+            (loop i
+                  (cons (vector-ref chars (bytevector-u8-ref bv i)) r)))))))
 
 (define base16-string->bytevector
   (let ((chars->value (fold (lambda (i r)
@@ -424,6 +429,21 @@ exception if it's already taken."
               (hash-set! cache args results)
               (apply values results)))))))
 
+(define (strip-keyword-arguments keywords args)
+  "Remove all of the keyword arguments listed in KEYWORDS from ARGS."
+  (let loop ((args   args)
+             (result '()))
+    (match args
+      (()
+       (reverse result))
+      (((? keyword? kw) arg . rest)
+       (loop rest
+             (if (memq kw keywords)
+                 result
+                 (cons* arg kw result))))
+      ((head . tail)
+       (loop tail (cons head result))))))
+
 (define (default-keyword-arguments args defaults)
   "Return ARGS augmented with any keyword/value from DEFAULTS for
 keywords not already present in ARGS."
@@ -501,6 +521,17 @@ or '= when they denote equal versions."
               ((negative? result) '<)
               (else '=))))))
 
+(define (version-prefix version-string num-parts)
+  "Truncate version-string to the first num-parts components of the version.
+For example, (version-prefix \"2.1.47.4.23\" 3) returns \"2.1.47\""
+  (string-join (take (string-split version-string #\.) num-parts) "."))
+
+
+(define (version-major+minor version-string)
+  "Return \"<major>.<minor>\", where major and minor are the major and
+minor version numbers from version-string."
+  (version-prefix version-string 2))
+
 (define (version>? a b)
   "Return #t when A denotes a newer version than B."
   (eq? '> (version-compare a b)))
@@ -600,8 +631,9 @@ REPLACEMENT."
   "Call PROC with a name of a temporary file and open output port to that
 file; close the file and delete it when leaving the dynamic extent of this
 call."
-  (let* ((template (string-copy "guix-file.XXXXXX"))
-         (out      (mkstemp! template)))
+  (let* ((directory (or (getenv "TMPDIR") "/tmp"))
+         (template  (string-append directory "/guix-file.XXXXXX"))
+         (out       (mkstemp! template)))
     (dynamic-wind
       (lambda ()
         #t)
