@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -25,6 +25,8 @@
   #:use-module (guix utils)
   #:use-module (guix base32)
   #:use-module (guix derivations)
+  #:use-module (guix hash)
+  #:use-module (guix tests)
   #:use-module ((guix packages)
                 #:select (package-derivation package-native-search-paths))
   #:use-module (gnu packages bootstrap)
@@ -35,11 +37,7 @@
 ;; Test the higher-level builders.
 
 (define %store
-  (false-if-exception (open-connection)))
-
-(when %store
-  ;; Make sure we build everything by ourselves.
-  (set-build-options %store #:use-substitutes? #f))
+  (open-connection-for-tests))
 
 (define %bootstrap-inputs
   ;; Use the bootstrap inputs so it doesn't take ages to run these tests.
@@ -49,14 +47,14 @@
        (map (match-lambda
              ((name package)
               (list name (package-derivation %store package))))
-            (@@ (gnu packages base) %boot0-inputs))))
+            (@@ (gnu packages commencement) %boot0-inputs))))
 
 (define %bootstrap-search-paths
   ;; Search path specifications that go with %BOOTSTRAP-INPUTS.
   (append-map (match-lambda
                ((name package _ ...)
                 (package-native-search-paths package)))
-              (@@ (gnu packages base) %boot0-inputs)))
+              (@@ (gnu packages commencement) %boot0-inputs)))
 
 (define network-reachable?
   (false-if-exception (getaddrinfo "www.gnu.org" "80" AI_NUMERICSERV)))
@@ -77,9 +75,24 @@
          (file-exists? out-path)
          (valid-path? %store out-path))))
 
+(test-assert "url-fetch, file"
+  (let* ((file (search-path %load-path "guix.scm"))
+         (hash (call-with-input-file file port-sha256))
+         (out  (url-fetch %store file 'sha256 hash)))
+    (and (file-exists? out)
+         (valid-path? %store out))))
+
+(test-assert "url-fetch, file URI"
+  (let* ((file (search-path %load-path "guix.scm"))
+         (hash (call-with-input-file file port-sha256))
+         (out  (url-fetch %store
+                          (string-append "file://" (canonicalize-path file))
+                          'sha256 hash)))
+    (and (file-exists? out)
+         (valid-path? %store out))))
+
 (test-assert "gnu-build-system"
-  (and (build-system? gnu-build-system)
-       (eq? gnu-build (build-system-builder gnu-build-system))))
+  (build-system? gnu-build-system))
 
 (unless network-reachable? (test-skip 1))
 (test-assert "gnu-build"
@@ -88,9 +101,9 @@
                     "0wqd8sjmxfskrflaxywc7gqw7sfawrfvdxd9skxawzfgyy0pzdz6"))
          (tarball  (url-fetch %store url 'sha256 hash
                               #:guile %bootstrap-guile))
-         (build    (gnu-build %store "hello-2.8" tarball
-                              %bootstrap-inputs
-                              #:implicit-inputs? #f
+         (build    (gnu-build %store "hello-2.8"
+                              `(("source" ,tarball)
+                                ,@%bootstrap-inputs)
                               #:guile %bootstrap-guile
                               #:search-paths %bootstrap-search-paths))
          (out      (derivation->output-path build)))
