@@ -28,10 +28,11 @@ readlink_base ()
     basename `readlink "$1"`
 }
 
+module_dir="t-guix-package-$$"
 profile="t-profile-$$"
 rm -f "$profile"
 
-trap 'rm "$profile" "$profile-"[0-9]* ; rm -rf t-home-'"$$" EXIT
+trap 'rm "$profile" "$profile-"[0-9]* ; rm -rf "$module_dir" t-home-'"$$" EXIT
 
 # Use `-e' with a non-package expression.
 if guix package --bootstrap -e +;
@@ -57,7 +58,7 @@ test "`guix package --search-paths -p "$profile" | wc -l`" = 0
 # Check whether we have network access.
 if guile -c '(getaddrinfo "www.gnu.org" "80" AI_NUMERICSERV)' 2> /dev/null
 then
-    boot_make="(@@ (gnu packages base) gnu-make-boot0)"
+    boot_make="(@@ (gnu packages commencement) gnu-make-boot0)"
     boot_make_drv="`guix build -e "$boot_make" | grep -v -e -debug`"
     guix package --bootstrap -p "$profile" -i "$boot_make_drv"
     test -L "$profile-2-link"
@@ -79,13 +80,6 @@ then
 
     test "`guix package -p "$profile" -I 'g.*e' | cut -f1`" = "guile-bootstrap"
 
-    # Search.
-    LC_MESSAGES=C
-    export LC_MESSAGES
-    test "`guix package -s "An example GNU package" | grep ^name:`" = \
-        "name: hello"
-    test -z "`guix package -s "n0t4r341p4ck4g3"`"
-
     # List generations.
     test "`guix package -p "$profile" -l | cut -f1 | grep guile | head -n1`" \
         = "  guile-bootstrap"
@@ -93,6 +87,8 @@ then
     # Exit with 1 when a generation does not exist.
     if guix package -p "$profile" --list-generations=42;
     then false; else true; fi
+    if guix package -p "$profile" --switch-generation=99;
+    then false; else true; fi
 
     # Remove a package.
     guix package --bootstrap -p "$profile" -r "guile-bootstrap"
@@ -107,6 +103,12 @@ then
     test "`readlink_base "$profile"`" = "$profile-1-link"
     test -x "$profile/bin/guile" && ! test -x "$profile/bin/make"
 
+    # Switch to the rolled generation and switch back.
+    guix package -p "$profile" --switch-generation=2
+    test "`readlink_base "$profile"`" = "$profile-2-link"
+    guix package -p "$profile" --switch-generation=-1
+    test "`readlink_base "$profile"`" = "$profile-1-link"
+
     # Move to the empty profile.
     for i in `seq 1 3`
     do
@@ -139,10 +141,12 @@ then
     grep "`guix build -e "$boot_make"`" "$profile/manifest"
 
     # Make a "hole" in the list of generations, and make sure we can
-    # roll back "over" it.
+    # roll back and switch "over" it.
     rm "$profile-1-link"
     guix package --bootstrap -p "$profile" --roll-back
     test "`readlink_base "$profile"`" = "$profile-0-link"
+    guix package -p "$profile" --switch-generation=+1
+    test "`readlink_base "$profile"`" = "$profile-2-link"
 
     # Make sure LIBRARY_PATH gets listed by `--search-paths'.
     guix package --bootstrap -p "$profile" -i guile-bootstrap -i gcc-bootstrap
@@ -179,6 +183,19 @@ guix package -p "$profile" -A 'gui.*e' | grep guile
 # Check whether `--show' returns something sensible.
 guix package --show=guile | grep "^name: guile"
 
+# Ensure `--show' doesn't fail for packages with non-package inputs.
+guix package --show=texlive
+
+# Search.
+LC_MESSAGES=C
+export LC_MESSAGES
+test "`guix package -s "An example GNU package" | grep ^name:`" = \
+    "name: hello"
+test -z "`guix package -s "n0t4r341p4ck4g3"`"
+
+# Make sure `--search' can display all the packages.
+guix package --search="" > /dev/null
+
 # There's no generation older than 12 months, so the following command should
 # have no effect.
 generation="`readlink_base "$profile"`"
@@ -249,3 +266,26 @@ set -o pipefail || true
 guix package -A g | head -1 2> "$HOME/err1"
 guix package -I | head -1 2> "$HOME/err2"
 test "`cat "$HOME/err1" "$HOME/err2"`" = ""
+
+# Make sure '-L' extends the package module search path.
+mkdir "$module_dir"
+
+cat > "$module_dir/foo.scm"<<EOF
+(define-module (foo)
+  #:use-module (guix packages)
+  #:use-module (gnu packages emacs))
+
+(define-public x
+  (package (inherit emacs)
+    (name "emacs-foo-bar")
+    (version "42")))
+EOF
+
+guix package -A emacs-foo-bar -L "$module_dir" | grep 42
+guix package -i emacs-foo-bar-42 -n -L "$module_dir"
+
+# Same thing using the 'GUIX_PACKAGE_PATH' environment variable.
+GUIX_PACKAGE_PATH="$module_dir"
+export GUIX_PACKAGE_PATH
+guix package -A emacs-foo-bar | grep 42
+guix package -i emacs-foo-bar-42 -n
