@@ -17,7 +17,9 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (test-nar)
+  #:use-module (guix tests)
   #:use-module (guix nar)
+  #:use-module (guix serialization)
   #:use-module (guix store)
   #:use-module ((guix hash)
                 #:select (open-sha256-port open-sha256-input-port))
@@ -134,19 +136,10 @@
                     input
                     lstat))
 
-(define (make-random-bytevector n)
-  (let ((bv (make-bytevector n)))
-    (let loop ((i 0))
-      (if (< i n)
-          (begin
-            (bytevector-u8-set! bv i (random 256))
-            (loop (1+ i)))
-          bv))))
-
 (define (populate-file file size)
   (call-with-output-file file
     (lambda (p)
-      (put-bytevector p (make-random-bytevector size)))))
+      (put-bytevector p (random-bytevector size)))))
 
 (define (rm-rf dir)
   (file-system-fold (const #t)                    ; enter?
@@ -166,13 +159,6 @@
   (string-append (dirname (search-path %load-path "pre-inst-env"))
                  "/test-nar-" (number->string (getpid))))
 
-;; XXX: Factorize.
-(define %seed
-  (seed->random-state (logxor (getpid) (car (gettimeofday)))))
-
-(define (random-text)
-  (number->string (random (expt 2 256) %seed) 16))
-
 (define-syntax-rule (let/ec k exp...)
   ;; This one appeared in Guile 2.0.9, so provide a copy here.
   (let ((tag (make-prompt-tag)))
@@ -291,7 +277,7 @@
 (test-assert "restore-file-set (missing signature)"
   (let/ec return
     (with-store store
-      (let* ((file  (add-text-to-store store "foo" "Hello, world!"))
+      (let* ((file  (add-text-to-store store "foo" (random-text)))
              (dump  (call-with-bytevector-output-port
                      (cute export-paths store (list file) <>
                            #:sign? #f))))
