@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -16,10 +16,15 @@
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-
 (define-module (test-packages)
+  #:use-module (guix tests)
   #:use-module (guix store)
-  #:use-module (guix utils)
+  #:use-module ((guix utils)
+                ;; Rename the 'location' binding to allow proper syntax
+                ;; matching when setting the 'location' field of a package.
+                #:renamer (lambda (name)
+                            (cond ((eq? name 'location) 'make-location)
+                                  (else name))))
   #:use-module (guix hash)
   #:use-module (guix derivations)
   #:use-module (guix packages)
@@ -28,25 +33,20 @@
   #:use-module (guix build-system gnu)
   #:use-module (gnu packages)
   #:use-module (gnu packages base)
+  #:use-module (gnu packages guile)
   #:use-module (gnu packages bootstrap)
-  #:use-module (srfi srfi-11)
+  #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-34)
   #:use-module (srfi srfi-64)
   #:use-module (rnrs io ports)
+  #:use-module (ice-9 regex)
   #:use-module (ice-9 match))
 
 ;; Test the high-level packaging layer.
 
 (define %store
-  (false-if-exception (open-connection)))
-
-(when %store
-  ;; Make sure we build everything by ourselves.
-  (set-build-options %store #:use-substitutes? #f))
-
-
-(test-begin "packages")
+  (open-connection-for-tests))
 
 (define-syntax-rule (dummy-package name* extra-fields ...)
   (package (name name*) (version "0") (source #f)
@@ -55,6 +55,24 @@
            (home-page #f) (license #f)
            extra-fields ...))
 
+
+(test-begin "packages")
+
+(test-assert "printer with location"
+  (string-match "^#<package foo-0 foo.scm:42 [[:xdigit:]]+>$"
+                (with-output-to-string
+                  (lambda ()
+                    (write
+                     (dummy-package "foo"
+                       (location (make-location "foo.scm" 42 7))))))))
+
+(test-assert "printer without location"
+  (string-match "^#<package foo-0 [[:xdigit:]]+>$"
+                (with-output-to-string
+                  (lambda ()
+                    (write
+                     (dummy-package "foo" (location #f)))))))
+
 (test-assert "package-field-location"
   (let ()
     (define (goto port line column)
@@ -106,6 +124,27 @@
                    ("d" ,d) ("d/x" "something.drv"))
                  (pk 'x (package-transitive-inputs e))))))
 
+(test-equal "package-transitive-supported-systems"
+  '(("x" "y" "z")                                 ;a
+    ("x" "y")                                     ;b
+    ("y")                                         ;c
+    ("y")                                         ;d
+    ("y"))                                        ;e
+  (let* ((a (dummy-package "a" (supported-systems '("x" "y" "z"))))
+         (b (dummy-package "b" (supported-systems '("x" "y"))
+               (inputs `(("a" ,a)))))
+         (c (dummy-package "c" (supported-systems '("y" "z"))
+               (inputs `(("b" ,b)))))
+         (d (dummy-package "d" (supported-systems '("x" "y" "z"))
+               (inputs `(("b" ,b) ("c" ,c)))))
+         (e (dummy-package "e" (supported-systems '("x" "y" "z"))
+               (inputs `(("d" ,d))))))
+    (list (package-transitive-supported-systems a)
+          (package-transitive-supported-systems b)
+          (package-transitive-supported-systems c)
+          (package-transitive-supported-systems d)
+          (package-transitive-supported-systems e))))
+
 (test-skip (if (not %store) 8 0))
 
 (test-assert "package-source-derivation, file"
@@ -282,11 +321,18 @@
 (test-assert "search paths"
   (let* ((p (make-prompt-tag "return-search-paths"))
          (s (build-system
-             (name "raw")
+             (name 'raw)
              (description "Raw build system with direct store access")
-             (build (lambda* (store name source inputs
-                                    #:key outputs system search-paths)
-                      search-paths))))
+             (lower (lambda* (name #:key source inputs system target
+                                   #:allow-other-keys)
+                      (bag
+                        (name name)
+                        (system system) (target target)
+                        (build-inputs inputs)
+                        (build
+                         (lambda* (store name inputs
+                                         #:key outputs system search-paths)
+                           search-paths)))))))
          (x (list (search-path-specification
                    (variable "GUILE_LOAD_PATH")
                    (directories '("share/guile/site/2.0")))
@@ -329,7 +375,7 @@
 
 (test-assert "package-cross-derivation, no cross builder"
   (let* ((b (build-system (inherit trivial-build-system)
-              (cross-build #f)))
+              (lower (const #f))))
          (p (package (inherit (dummy-package "p"))
               (build-system b))))
     (guard (c ((package-cross-build-system-error? c)
@@ -337,12 +383,132 @@
       (package-cross-derivation %store p "mips64el-linux-gnu")
       #f)))
 
+(test-equal "package-derivation, direct graft"
+  (package-derivation %store gnu-make)
+  (let ((p (package (inherit coreutils)
+             (replacement gnu-make))))
+    (package-derivation %store p)))
+
+(test-equal "package-cross-derivation, direct graft"
+  (package-cross-derivation %store gnu-make "mips64el-linux-gnu")
+  (let ((p (package (inherit coreutils)
+             (replacement gnu-make))))
+    (package-cross-derivation %store p "mips64el-linux-gnu")))
+
+(test-assert "package-grafts, indirect grafts"
+  (let* ((new   (dummy-package "dep"
+                  (arguments '(#:implicit-inputs? #f))))
+         (dep   (package (inherit new) (version "0.0")))
+         (dep*  (package (inherit dep) (replacement new)))
+         (dummy (dummy-package "dummy"
+                  (arguments '(#:implicit-inputs? #f))
+                  (inputs `(("dep" ,dep*))))))
+    (equal? (package-grafts %store dummy)
+            (list (graft
+                    (origin (package-derivation %store dep))
+                    (replacement (package-derivation %store new)))))))
+
+(test-assert "package-grafts, indirect grafts, cross"
+  (let* ((new    (dummy-package "dep"
+                   (arguments '(#:implicit-inputs? #f))))
+         (dep    (package (inherit new) (version "0.0")))
+         (dep*   (package (inherit dep) (replacement new)))
+         (dummy  (dummy-package "dummy"
+                   (arguments '(#:implicit-inputs? #f))
+                   (inputs `(("dep" ,dep*)))))
+         (target "mips64el-linux-gnu"))
+    (equal? (package-grafts %store dummy #:target target)
+            (list (graft
+                    (origin (package-cross-derivation %store dep target))
+                    (replacement
+                     (package-cross-derivation %store new target)))))))
+
+(test-assert "package-grafts, indirect grafts, propagated inputs"
+  (let* ((new   (dummy-package "dep"
+                  (arguments '(#:implicit-inputs? #f))))
+         (dep   (package (inherit new) (version "0.0")))
+         (dep*  (package (inherit dep) (replacement new)))
+         (prop  (dummy-package "propagated"
+                  (propagated-inputs `(("dep" ,dep*)))
+                  (arguments '(#:implicit-inputs? #f))))
+         (dummy (dummy-package "dummy"
+                  (arguments '(#:implicit-inputs? #f))
+                  (inputs `(("prop" ,prop))))))
+    (equal? (package-grafts %store dummy)
+            (list (graft
+                    (origin (package-derivation %store dep))
+                    (replacement (package-derivation %store new)))))))
+
+(test-assert "package-derivation, indirect grafts"
+  (let* ((new   (dummy-package "dep"
+                  (arguments '(#:implicit-inputs? #f))))
+         (dep   (package (inherit new) (version "0.0")))
+         (dep*  (package (inherit dep) (replacement new)))
+         (dummy (dummy-package "dummy"
+                  (arguments '(#:implicit-inputs? #f))
+                  (inputs `(("dep" ,dep*)))))
+         (guile (package-derivation %store (canonical-package guile-2.0)
+                                    #:graft? #f)))
+    (equal? (package-derivation %store dummy)
+            (graft-derivation %store "dummy-0"
+                              (package-derivation %store dummy #:graft? #f)
+                              (package-grafts %store dummy)
+
+                              ;; Use the same Guile as 'package-derivation'.
+                              #:guile guile))))
+
+(test-equal "package->bag"
+  `("foo86-hurd" #f (,(package-source gnu-make))
+    (,(canonical-package glibc)) (,(canonical-package coreutils)))
+  (let ((bag (package->bag gnu-make "foo86-hurd")))
+    (list (bag-system bag) (bag-target bag)
+          (assoc-ref (bag-build-inputs bag) "source")
+          (assoc-ref (bag-build-inputs bag) "libc")
+          (assoc-ref (bag-build-inputs bag) "coreutils"))))
+
+(test-equal "package->bag, cross-compilation"
+  `(,(%current-system) "foo86-hurd"
+    (,(package-source gnu-make))
+    (,(canonical-package glibc)) (,(canonical-package coreutils)))
+  (let ((bag (package->bag gnu-make (%current-system) "foo86-hurd")))
+    (list (bag-system bag) (bag-target bag)
+          (assoc-ref (bag-build-inputs bag) "source")
+          (assoc-ref (bag-build-inputs bag) "libc")
+          (assoc-ref (bag-build-inputs bag) "coreutils"))))
+
+(test-assert "package->bag, propagated inputs"
+  (let* ((dep    (dummy-package "dep"))
+         (prop   (dummy-package "prop"
+                   (propagated-inputs `(("dep" ,dep)))))
+         (dummy  (dummy-package "dummy"
+                   (inputs `(("prop" ,prop)))))
+         (inputs (bag-transitive-inputs (package->bag dummy #:graft? #f))))
+    (match (assoc "prop/dep" inputs)
+      (("prop/dep" package)
+       (eq? package dep)))))
+
+(test-assert "bag->derivation"
+  (parameterize ((%graft? #f))
+    (let ((bag (package->bag gnu-make))
+          (drv (package-derivation %store gnu-make)))
+      (parameterize ((%current-system "foox86-hurd")) ;should have no effect
+        (equal? drv (bag->derivation %store bag))))))
+
+(test-assert "bag->derivation, cross-compilation"
+  (parameterize ((%graft? #f))
+    (let* ((target "mips64el-linux-gnu")
+           (bag    (package->bag gnu-make (%current-system) target))
+           (drv    (package-cross-derivation %store gnu-make target)))
+      (parameterize ((%current-system "foox86-hurd") ;should have no effect
+                     (%current-target-system "foo64-linux-gnu"))
+        (equal? drv (bag->derivation %store bag))))))
+
 (unless (false-if-exception (getaddrinfo "www.gnu.org" "80" AI_NUMERICSERV))
   (test-skip 1))
 (test-assert "GNU Make, bootstrap"
   ;; GNU Make is the first program built during bootstrap; we choose it
   ;; here so that the test doesn't last for too long.
-  (let ((gnu-make (@@ (gnu packages base) gnu-make-boot0)))
+  (let ((gnu-make (@@ (gnu packages commencement) gnu-make-boot0)))
     (and (package? gnu-make)
          (or (location? (package-location gnu-make))
              (not (package-location gnu-make)))
