@@ -16,15 +16,15 @@
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-
 (define-module (test-store)
+  #:use-module (guix tests)
   #:use-module (guix store)
   #:use-module (guix utils)
   #:use-module (guix hash)
   #:use-module (guix base32)
   #:use-module (guix packages)
   #:use-module (guix derivations)
-  #:use-module (guix nar)
+  #:use-module (guix serialization)
   #:use-module (gnu packages)
   #:use-module (gnu packages bootstrap)
   #:use-module (ice-9 match)
@@ -40,17 +40,7 @@
 ;; Test the (guix store) module.
 
 (define %store
-  (false-if-exception (open-connection)))
-
-(when %store
-  ;; Make sure we build everything by ourselves.
-  (set-build-options %store #:use-substitutes? #f))
-
-(define %seed
-  (seed->random-state (logxor (getpid) (car (gettimeofday)))))
-
-(define (random-text)
-  (number->string (random (expt 2 256) %seed) 16))
+  (open-connection-for-tests))
 
 
 (test-begin "store")
@@ -168,6 +158,31 @@
            (> freed 0)
            (not (file-exists? p))))))
 
+(test-assert "add-text-to-store vs. delete-paths"
+  ;; Before, 'add-text-to-store' would return PATH2 without noticing that it
+  ;; is no longer valid.
+  (with-store store
+    (let* ((text    (random-text))
+           (path    (add-text-to-store store "delete-me" text))
+           (deleted (delete-paths store (list path)))
+           (path2   (add-text-to-store store "delete-me" text)))
+      (and (string=? path path2)
+           (equal? deleted (list path))
+           (valid-path? store path)
+           (file-exists? path)))))
+
+(test-assert "add-to-store vs. delete-paths"
+  ;; Same as above.
+  (with-store store
+    (let* ((file    (search-path %load-path "guix.scm"))
+           (path    (add-to-store store "delete-me" #t "sha256" file))
+           (deleted (delete-paths store (list path)))
+           (path2   (add-to-store store "delete-me" #t "sha256" file)))
+      (and (string=? path path2)
+           (equal? deleted (list path))
+           (valid-path? store path)
+           (file-exists? path)))))
+
 (test-assert "references"
   (let* ((t1 (add-text-to-store %store "random1"
                                 (random-text)))
